      SUBROUTINE IM4(IN1981,OUT198,NVSEEA,UEXCE4,RSDD)
C
C IM4
C
C Calculates new sets of IM credits for
C IM programs using Remote Sensing Devices (RSD) 
C from the existing 1981 and newer model years vehicles credits
C
C Called by INPUT
C
C Calls no subroutines
C
C Input:
C by user:  none
C common block(s):  OP1
C data file(s):  file whose name is passed in IN1981  
C subroutine arguments:  IN1981, OUT198, NVSEEA, UEXCE4, RSDD
C
C Output:
C by screen:  none
C common blocks(s):  none
C data file(s):  file whose name is passed in OUT198
C subroutine arguments:  none
C
C Array subscripts:
C
C ACREDT(18,3,24) - ACREDT(ITECH,IP,IBY)
C CUTS(4)         - CUTS(ITECH)
C EFF(3)          - EFF(IP)
C EXCESS(3,15,3)  - EXCESS(ITECH,cutpoint,IP)
C NCREDT(24)      - NCREDT(IBY)
C NVSEEA(25)      - NVSEEA(IBY)
C SMART(4)        - SMART(ISMART)
C UEXCE4(3)       - UEXCE4(IP)
C VMT(25)         - VMT(IBY)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -  
C ACREDT  R   Array of annual credits read from the input file
C AGE     I   Age at which a veh. first becomes subject to RSD program
C CCUTCO  R   CO cut point read from an input file annual Smart line
C CCUTHC  R   HC cut point read from an input file annual Smart line
C CCUTNO  R   NOx cut point read from an input file annual Smart line
C CRDCOM  C   Char. string of comments from the end of a credit line
C CUTS    R   Array of RSD CO test cutpoints for vehicle groups
C              pre-1975, 1975-1980, and post-1980, Clean Screen NOx Cutpoint
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C ETCFLG  I   Etc. flag, may be used for something in the future.
C EXCESS  R   See routines R1 and R2
C FLAG    I   The next Smart line to be examined for annual data is
C              FLAG+1 Smart lines from the top of the input file
C HYBFLG  I   Hybrid program flag
C IBY     I   Counter for Benefit Years
C ILINE   I   Counter for Smart lines
C IMFLG   I   I/M flag:  1 if no RSD program modifications done on
C              IMDATA; 2 if data was changed
C IN1981  C   Character string name of the IMDATA.D type input filename
C IP      I   Counter for pollutants
C IREC    I   Counter for credit lines
C ISMART  I   Counter for digits in the Smart control strip
C ITECH   I   Counter for model years
C NCREDT  R   Array of new credits
C NUMBER  I   Total number of vehicles subject to the I/M program.
C NVSEEA  R   Fraction of vehicles seen by RSD, annual program
C OLDFLG  I   If old data, OLDFLG=1, if new, 0.
C OPTION  I   RSD program option -- see RSDDRV
C OUT198  C   Char. string name of the RSDDATA.D type output filename
C RSDD    C   Char. string name of the input data file
C SCAN    I   Number of valid veh. measurements per month at RSD sites
C SMART   I   Array holding the first four digits of an annual Smart
C              line (the Smart control strip):  altitude 1=Low 2=High; 
C              frequency 1=annual 2=biennial; technology 1=TECH1&2
C              2=TECH4+; test type 1=Idle 2=2500/Idle 3=Loaded/Idle
C              4=IM240 Test
C THREE   C   Character string name for the flags HYBFLG, IMFLG, and
C              ETCFLG if they exist, otherwise it contains part of the
C               comment line
C TIMES   I   Minimum number of times a vehicle must be scanned between
C              inspections to be eligible for targetting
C UEXCE4  R   Effectiveness of RSD, for Tech type 4+
C VMT     I   Vehicle miles travelled by age
C
C
C Notes:  Tech 1 refers to pre-1975 vehicles, Tech 2 to those from
C         1975-1980, and Tech 4+ to those of 1981 and later.
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 22-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 19-Mar-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C
C -----------------
C DECLARE VARIABLES
C -----------------
C
      CHARACTER CRDCOM*19, IN1981*40, OUT198*40, RSDD*40, THREE*3
C
      INTEGER AGE, ETCFLG, FLAG, HYBFLG, IBY, ILINE, IMFLG, IP
      INTEGER IREC, ISMART, ITECH, NUMBER, OLDFLG, OPTION, SCAN
      INTEGER SMART(4), TIMES, VMT(25)
C
      REAL ACREDT(18,3,24), CCUTHC, CCUTCO, CCUTNO
      REAL CUTS(4), EFF(3), EXCESS(3,15,3), NCREDT(24)
      REAL NVSEEA(25), UEXCE4(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
C
      WRITE(*,200)
 200  FORMAT(/,  ' Starting to alter 1981 and newer model ',
     &            'years vehicles I/M credits to include ',/,
     &           ' Remote Sensing Devices credits ',/,
     &           ' ---------------------------------------',
     &            '------------------------------------- ')
C
C ----------
C OPEN FILES
C ----------
C
      OPEN(UNIT=2,FILE=IN1981,ERR=300,STATUS='OLD')
      OPEN(UNIT=3,FILE=OUT198,ERR=305)
C
C ------------------
C START PROCESS LOOP
C ------------------
C
C Set FLAG=0.  This means that the first Smart line in the file is the
C line to check to see if it is one marking annual data.
C
      FLAG=0
C
C Set OLDFLG=0.  This means that data is new, i.e., it has HYBFLG,
C IMFLG, and ETCFLG.  If it is 1, it means that these don't exist and
C the data is old data.
C
      OLDFLG=0
C
 50   CONTINUE
C
C The following section of code jumps ahead in the data file to the
C first Smart line after the last Smart line marking annual data.
C Jumping ahead means reading one or more sets (a Smart line, 18 year
C sets composed of an HC line, a CO line, and a NOx line--55 lines in 
C all) of data so that the next record to be read will be a Smart line.
C
      DO 10 ILINE=1,FLAG
C
        DO 15 IREC=1,55
          READ(2,100,END=20)
 100      FORMAT(1X)
 15     CONTINUE
C
 10   CONTINUE
C
C Read the Smart control strip, cut point values and description line
C
 30   CONTINUE
C
      READ(2,102,END=20,ERR=310)(SMART(ISMART),ISMART=1,4),
     &                          CCUTHC,CCUTCO,CCUTNO,THREE
 102  FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,A3)
C
      READ(THREE,105,ERR=22)HYBFLG,IMFLG,ETCFLG
 105  FORMAT(3I1)
C
      GO TO 23
C
 22   CONTINUE
C
C An error in reading flags from THREE means that they aren't there;
C thus input file is old-type data.
C
      OLDFLG=1
C
 23   CONTINUE
C
C Increment FLAG, since the next Smart line that can mark annual data
C must be below the current Smart line
C
      FLAG=FLAG+1
C
C Check to see if the current Smart line marks annual data
C
      IF (SMART(2).NE.1) THEN
C
C Not annual; jump forward to the next Smart line and read it
C
        DO 25 IREC=1,54
          READ(2,100,END=20)
C100      FORMAT(1X)
 25     CONTINUE
C       
        GO TO 30
      END IF
C
C The current Smart line marks annual data.  Echo the annual Smart   
C line to the new file.
C
C Execute the following if OLDFLG is not 1; the following is for new
C data
C
      IF (OLDFLG.NE.1) THEN
C
C Halt processing if the annual Smart line has a value
C of IMFLG that is not one, because this means that the annual
C data has already been changed due to RSD effects, and making more
C than one change on the same data would result in nonsense.
C
        IF ( (IMFLG.NE.1).AND.(IMFLG.NE.0) ) THEN
          GO TO 332
        END IF
C
        WRITE(3,215,ERR=312)(SMART(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,HYBFLG,ETCFLG,OPTION,RSDD
 215    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,I1,'2',I1,1X,'New ',
     &         'annual credits, Option = ',I1,', Program type = 4, ',
     &         'input data file ',A40)
      ELSE
C
C For old data, can't examine IMFLG--just write it as '2'; write  HYBFLG
C and ETCFLG as blanks.
C
        WRITE(3,216,ERR=312)(SMART(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,OPTION,RSDD
 216    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,' 2 ',1X,'New ',
     &         'annual credits, Option = ',I1,', Program type = 4, ',
     &         'input data file ',A40)
      ENDIF
C
C Read the annual credits.
C
      PRINT *,'Reading old annual credits and writing new annual ',
     & 'credits'
C
C Loop for the 18 model years stored in the record.
C
      DO 35 ITECH=1,18
C
C Loop for the 3 pollutants (HC, CO, and NOX) in the record.
C
        DO 36 IP=1,3
C
C Read the 24 age credit values
C
          READ(2,110,END=315,ERR=320)(ACREDT(ITECH,IP,IBY),IBY=1,24),
     &                               CRDCOM
 110      FORMAT (24F5.3,A19)
C
C Calculate the new annual credit.
C
C Note:  new annual credit = annual credit * F * E
C
            DO 37 IBY=1,24
C
              NCREDT(IBY) =
     & ACREDT(ITECH,IP,IBY) * NVSEEA(IBY) * UEXCE4(IP)
C
 37       CONTINUE
C
          WRITE(3,220,ERR=325)(NCREDT(IBY),IBY=1,24),CRDCOM
 220      FORMAT(24F5.3,A19)
C
 36     CONTINUE
C
 35   CONTINUE
C
C Now go back up to the procedure for finding the next annual Smart
C line that has not been processed yet.
C
      REWIND(2)
C
      GO TO 50
C
C --------------
C ERROR MESSAGES
C --------------
C
 300  CONTINUE
      WRITE(*,301)IN1981       
 301  FORMAT(/,  ' ERROR OPENING INPUT FILE ',A40)
      GO TO 55
C
 305  CONTINUE
      WRITE(*,306)OUT198       
 306  FORMAT(/,  ' ERROR OPENING OUTPUT FILE ',A40)
      GO TO 55
C
 310  CONTINUE
      WRITE(*,311)IN1981       
 311  FORMAT(/,  ' ERROR READING SMART LINE FROM INPUT ',
     &            'FILE ',A40)
      GO TO 55
C
 312  CONTINUE
      WRITE(*,313)OUT198       
 313  FORMAT(/,  ' ERROR WRITING ANNUAL SMART LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 55
C
 315  CONTINUE
      WRITE(*,316)IN1981       
 316  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING ',
     &            'ANNUAL CREDITS FROM INPUT FILE ',/,
     &           ' ',A40)
      GO TO 55
C
 320  CONTINUE
      WRITE(*,321)IN1981       
 321  FORMAT(/,  ' ERROR READING ANNUAL CREDITS FROM INPUT ',
     &            'FILE ',A40)
      GO TO 55
C
 325  CONTINUE
      WRITE(*,326)OUT198       
 326  FORMAT(/,  ' ERROR WRITING ANNUAL CREDIT LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 55
C
 332  CONTINUE
      WRITE(*,333)       
 333  FORMAT(/,  ' ERROR CANNOT APPLY RSD EFFECTS TO DATA ',
     &            'THAT HAS ALREADY BEEN CHANGED ')
      GO TO 55
C
C --------------
C END PROCEDURES
C --------------
C
 55   CONTINUE
      WRITE(*,355)       
 355  FORMAT(/,  ' CONVERSION ENDED ABNORMALLY',/)
      GO TO 60
C
 20   CONTINUE
      WRITE(*,245)       
 245  FORMAT(/,  ' Conversion ended normally',/)
C
 60   CONTINUE
C
      CLOSE (3)
      CLOSE (2)
C
      RETURN
      END
      SUBROUTINE FSEEN2(NVSEEA,NVSEEB)
C
C The FSEEN2 subroutine calculates NSEENA and NSEENB, arrays of the
C fractions of vehicles seen by RSD in an annual or biennial IM
C program, respectively.  It uses a method that adjusts the
C by-vehicle-age theoretical results (assuming a Poisson distribution)
C by altering the overall average remote sensing sampling rate by
C the ratio of the VMT for the particular age over the VMT for the
C newest vehicle age.
C
C Called by subroutine R1
C
C Input:
C by user:  none
C common blocks:  OP1
C data file(s): none
C subroutine arguments: none
C
C Output:
C by screen:
C common blocks:
C data file(s):  none used
C subroutine arguments:  NVSEEA, NVSEEB
C
C Array subscripts:
C
C EFF(3)         - EFF(pollutant)
C EXCESS(3,15,3) - EXCESS(Tech type, cutpoint, pollutant)
C FACTRL(11)     - FACTRL(ISCAN)
C NVSEEA(24)     - NVSEEA(IBY)
C NVSEEB(24)     - NVSEEB(IBY)
C VMT(25)        - VMT(IBY)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C AGE     I   The age at which a car first becomes subject to the program
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C EXCESS  R   Array of user supplied RSD excess identified fractions
C              dependent upon Tech type, CO cut point, and pollutant,
C              used in Options 1 and 2
C FACTRL  R   Factorial look-up table containing in each element the
C              factorial of one less than the element's array index 
C FRACA   R   Fraction of vehicles in annual program that are seen a
C              chosen number of times or more; VMT adjusted Poisson
C              prediction
C FRACB   R   Fraction of vehicles in biennial program that are seen a
C              chosen number of times or more; VMT adjusted Poisson
C              prediction
C IBY     I   Counter for Benefit Year Age
C ISCAN   I   Counter for number of scans
C NUMBER  I   Total number of vehicles subject to the inspection program
C NVSEEA  R   New version of FVSEEN after taking into account VMT ratio
C              adjustment and age exemptions
C NVSEEB  R   New version of FVSEEN after taking into account VMT ratio
C              adjustment and age exemptions
C OPTION  I   Option number 1, 2, or 3--see RSDDRV
C RNUMBE  R   Real value of NUMBER
C RSCAN   R   Real value of SCAN
C RVMT1   R   Real value of VMT(1)
C SCAN    I   Times per month the RSD sites scanned valid vehicles.
C TIMES   I   Number of times a vehicle must be scanned to be eligible
C              for targetting
C VMT     I   Vehicle miles traveled, by age, per year
C
C
C Notes:
C         
C 07-Sept-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 20-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C -----------------
C DECLARE VARIABLES
C -----------------
C
      INTEGER AGE, IBY, ISCAN, NUMBER, OPTION, SCAN, TIMES, VMT(25)
C
      REAL CUTS(4), EFF(3), EXCESS(3,15,3), FACTRL(11), FRACA, FRACB
      REAL NVSEEA(24), NVSEEB(24), RVMT1
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
C
C ------------------------------
C DATA STATEMENT INITIALIZATIONS
C ------------------------------
C
      DATA FACTRL/ 1., 1., 2., 6., 24., 120., 720., 5040., 40320., 
     &             362880., 3628800. /
C
C ----------------------------------------
C SET UP FRACTIONS OF NEWEST VEHICLES SEEN
C ----------------------------------------
C
C Set NUMBER, SCAN, and VMT(1) to real values
C
      RNUMBE=FLOAT(NUMBER)
      RSCAN=FLOAT(SCAN)
      RVMT1=FLOAT(VMT(1))
C
      DO 10 IBY=1,24
C
C Evaluate annual and biennial program fractions for every benefit
C year
C
C FRACA, the adjusted Poisson prediction for annual programs and
C FRACB, the adjusted Poisson prediction for biennial programs
C are found using the following:
C 1) average number of times a vehicle subject to the program is
C scanned by RSD (which is the total valid scans made at the RSD sites
C during the I/M period, which is two years for biennial programs,
C divided by the total number of vehicles in the program, SCAN divided
C by NUMBER; see Note below); and
C 2) number of valid scans a particular vehicle is required to have
C before it can be examined to determine if it should go to I/M;
C statistics provides an expression which can be used to find the
C predicted (assuming that cars were passing by the RSD in a completely
C random fashion, which is not actually the case) value for the fraction
C of the program cars scanned a chosen number of times.  Also, the  
C expression may be used (as it is here) to find the fraction scanned
C the chosen number of times or more.
C 3) the VMT ratio, which is VMT(IBY)/VMT(1), and is used to adjust the
C theoretical Poisson prediction toward fewer scans for older cars by
C being multiplied by the average scans factor wherever it appears.
C
C Set FRACA and FRACB to one.  These are the fractions of vehicles
C scanned zero or more times.
C
      FRACA=1.
      FRACB=1.
C
C If clean screening is selected (ACTION=5), then coverage must be
C set to two times seen, regardless of user input. TIMES=2
C
      DO 20 ISCAN=1,TIMES
C
C Subtract from the current values of FRACA and FRACB the fraction of
C vehicles scanned ISCAN-1 times.  The result is the fraction of
C vehicles scanned ISCAN or more times.  (FACTRL is an array containing
C factorial values of its indicies-less-one.)
C (Note:  intuitively, SCAN, the number of valid RSD scans per month
C  would be multiplied by 24 [months] to get the total number of valid
C  RSD scans over a two year biennial I/M program period, but EPA has
C  determined that 18 [months] provides a more accurate estimate of the
C  actual situation.)
C
        FRACA=FRACA-
     &        ( (RSCAN*12./RNUMBE*FLOAT(VMT(IBY))/RVMT1)**(ISCAN-1) )*
     &        ( EXP(-RSCAN*12./RNUMBE*FLOAT(VMT(IBY))/RVMT1) )/
     &        ( FACTRL(ISCAN) )
        FRACB=FRACB-
     &        ( (RSCAN*18./RNUMBE*FLOAT(VMT(IBY))/RVMT1)**(ISCAN-1) )*
     &        ( EXP(-RSCAN*18./RNUMBE*FLOAT(VMT(IBY))/RVMT1) )/
     &        ( FACTRL(ISCAN) )
 20   CONTINUE
C
C Take age exemptions into account.
C
        IF (IBY.LT.AGE) THEN
          NVSEEA(IBY)=0.
          NVSEEB(IBY)=0.
        ELSE
          NVSEEA(IBY)=FRACA
          NVSEEB(IBY)=FRACB
        END IF
C
 10   CONTINUE
C
      RETURN
      END
      SUBROUTINE IM1(IN1981,OUT198,NVSEEB,UEXCE4,RSDD)
C
C IM1
C
C Calculates new sets of IM credits for
C IM programs using Remote Sensing Devices (RSD) 
C from the existing 1981 and newer model years vehicles credits
C
C Called by INPUT
C
C Calls no subroutines
C
C Input:
C by user:  none
C common block(s):  OP1
C data file(s):  file whose name is passed in IN1981
C subroutine arguments:  IN1981, OUT198, NVSEEB, UEXCE4, RSDD
C
C Output:
C by screen:  none
C common blocks(s):  none
C data file(s):  file whose name is passed in OUT198
C subroutine arguments:  none
C
C Array subscripts:
C
C ACREDT(24,3,18) - ACREDT(IBY,IP,IMY)
C BCREDT(24)      - BCREDT(IBY)
C CUTS(4)         - CUTS(ITECH)
C EFF(3)          - EFF(IP)
C EXCESS(3,15,3)  - EXCESS(ITECH,cutpoint,IP)
C NCREDT(24)      - NCREDT(IBY)
C NVSEEB(25)      - NVSEEB(IBY)
C SMARK(4)        - SMARK(ISMART)
C SMART(4)        - SMART(ISMART)
C UEXCE4(3)       - UEXCE4(IP)
C VMT(25)         - VMT(IBY)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -  
C ACREDT  R   Array of annual credits read from the input file
C AGE     I   Age at which a veh. first becomes subject to RSD program
C BCREDT  R   Array of biennial credits read from the input file
C CCUTCO  R   CO cut point read from an input file annual Smart line
C CCUTHC  R   HC cut point read from an input file annual Smart line
C CCUTNO  R   NOx cut point read from an input file annual Smart line
C CKUTCO  R   CO cut point read from an input file biennial Smart line
C CKUTHC  R   HC cut point read from an input file biennial Smart line
C CKUTNO  R   NOx cut point read from an input file biennial Smart line
C CRDCOM  C   Char. string of comments from the end of a credit line 
C CUTS    R   Array of RSD CO test cutpoints for vehicle groups
C              pre-1975, 1975-1980, and post-1980, Clean Screen NOx Cutpoint
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5 (not used here)
C ETCFLG  I   Etc. flag, may be used for something in the future
C EXCESS  R   See routines R1 and R2
C FLAG    I   The next Smart line to be examined for annual data is
C              FLAG+1 Smart lines from the top of the input file
C HYBFLG  I   Hybrid program flag
C IBY     I   Counter for Benefit Years
C ILINE   I   Counter for Smart lines
C IMFLG   I   I/M flag:  1 if no RSD program modifications done on
C              IMDATA; 2 if data was changed
C IMNAME  C   Character string of comments from the end of an annual
C              Smart line
C IMY     I   Counter for model year
C IN1981  C   Character string name of the IMDATA.D type input filename
C IP      I   Counter for pollutants
C IREC    I   Counter for credit lines
C ISMART  I   Counter for digits in the Smart control strip
C ITECH   I   Counter for Tech type: 1 is 1, 2 is 2, and 3 is 4+
C NCREDT  R   Array of new biennial credits
C NUMBER  I   Total number of vehicles subject to the I/M program.
C NVSEEB  R   Fraction of vehicles seen by RSD, biennial, function of
C              benefit year
C OLDFLG  I   If old data, OLDFLG=1, if new, 0.
C OPTION  I   Option--see RSDDRV
C OUT198  C   Char. string name of the RSDDATA.D type output filename
C RSDD    C   Char. string name of the input data file
C SCAN    I   Number of valid veh. measurements per month at RSD sites
C SMARK   I   Array holding the first four digits of a biennial Smart
C              line (the Smart control strip):  altitude 1=Low 2=High; 
C              frequency 1=annual 2=biennial; technology 1=TECH1&2
C              2=TECH4+; test type 1=Idle 2=2500/Idle 3=Loaded/Idle
C              4=IM240 Test
C SMART   I   Array holding the 1st four digits of an annual Smart line
C TIMES   I   Minimum number of times a vehicle must be scanned between
C              inspections to be eligible for targetting
C UEXCE4  R   Effectiveness of RSD machines at detecting high emitters,
C              function of pollutant for Tech 4+ vehicles
C VMT     I   Vehicle miles travelled by age
C
C
C Notes:  Tech 1 refers to pre-1975 vehicles, Tech 2 to those from
C         1975-1980, and Tech 4+ to those of 1981 and later.
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 22-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 19-Mar-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C -----------------
C DECLARE VARIABLES
C -----------------
C
      CHARACTER CRDCOM*19, IMNAME*80, IN1981*40, OUT198*40, RSDD*40
C
      INTEGER AGE, ETCFLG, FLAG, HYBFLG, IBY, ILINE, IMFLG, IMY, IP
      INTEGER IREC, ISMART, NUMBER, OLDFLG, OPTION, SCAN, SMARK(4)
      INTEGER SMART(4), TIMES, VMT(25)
C
      REAL ACREDT(24,3,18), BCREDT(24), CCUTHC, CCUTCO, CCUTNO
      REAL CKUTHC, CKUTCO, CKUTNO, CUTS(4), EFF(3), EXCESS(3,15,3)
      REAL NCREDT(24), NVSEEB(25), UEXCE4(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
C
      WRITE(*,200)
 200  FORMAT(/,  ' Starting to alter 1981 and newer model ',
     &            'years vehicles I/M credits to include ',/,
     &           ' Remote Sensing Devices credits ',/,
     &           ' ---------------------------------------',
     &            '------------------------------------- ')
C
C ----------
C OPEN FILES
C ----------
C
      OPEN(UNIT=2,FILE=IN1981,ERR=300,STATUS='OLD')
      OPEN(UNIT=3,FILE=OUT198,ERR=305)
C
C ------------------
C START PROCESS LOOP
C ------------------
C
C Set FLAG=0.  This means that the first Smart line in the file is the
C line to check to see if it is one marking annual data.
C
      FLAG=0
C
C Set OLDFLG=0.  This means that data is new, i.e., it has HYBFLG,
C IMFLG, and ETCFLG.  If it is 1, it means that these don't exist and
C the data is old data.
C
      OLDFLG=0
C
 50   CONTINUE
C
C The following section of code jumps ahead in the data file to the
C first Smart line after the last Smart line marking annual data.
C Jumping ahead means reading one or more sets (a Smart line, 18 year
C sets composed of an HC line, a CO line, and a NOx line--55 lines in 
C all) of data so that the next record to be read will be a Smart line.
C
      DO 10 ILINE=1,FLAG
C
        DO 15 IREC=1,55
          READ(2,100,END=20)
 100      FORMAT(1X)
 15     CONTINUE
C
 10   CONTINUE
C
C Read the Smart control strip, cut point values and description line
C
 30   CONTINUE
C
      READ(2,102,END=20,ERR=310) (SMART(ISMART),ISMART=1,4),
     &     CCUTHC,CCUTCO,CCUTNO,IMNAME
 102  FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,A80)
C
      READ(IMNAME,105,ERR=22)HYBFLG,IMFLG,ETCFLG
 105  FORMAT(3I1)
C
      GO TO 23
C
 22   CONTINUE
C
C An error in reading flags from IMNAME means that they aren't there;
C thus input data is old-type data.
C
      OLDFLG=1
C
 23   CONTINUE
C
C Reading a Smart line; looking for annual data
C
C Increment FLAG, since the next Smart line that can mark annual data
C must be below the current Smart line
C
      FLAG=FLAG+1
C
C Check to see if the current Smart line marks annual data
C
      IF (SMART(2).NE.1) THEN
C
C Not annual; jump forward to the next Smart line and read it
C
        DO 25 IREC=1,54
          READ(2,100,END=20)
C100      FORMAT(1X)
 25     CONTINUE
C       
        GO TO 30
      END IF
C
C The current Smart line marks annual data.  Echo the annual Smart   
C line to the new file
C
C Execute the following if OLDFLG is not 1; the following is for new
C data.
C
      IF (OLDFLG.NE.1) THEN
C
C Halt processing if the annual Smart line has a value
C of IMFLG that is not one, because this means that the annual
C data has already been changed due to RSD effects, and making more
C than one change on the same data would result in nonsense.
C
        IF ( (IMFLG.NE.1).AND.(IMFLG.NE.0) ) THEN
          GO TO 332
        END IF
C
        WRITE(3,215)(SMART(ISMART),ISMART=1,4),CCUTHC,CCUTCO,CCUTNO,
     &              HYBFLG,ETCFLG,OPTION,RSDD
 215    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,I1,'2',I1,' New ',
     &         'annual credits, Option = ',I1,', Program type = 1, ',
     &         'input data file ',A40)
      ELSE
C
C For old data, can't examine IMFLG--just write it as '2'; write HYBFLG
C and ETCFLG as blanks.
C
        WRITE(3,216)(SMART(ISMART),ISMART=1,4),CCUTHC,CCUTCO,CCUTNO,
     &              OPTION,RSDD
 216    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,' 2 ',1X,'New ',
     &         'annual credits, Option = ',I1,', Program type = 1, ',
     &         'input data file ',A40)
      ENDIF
C
C Read the annual data--loop for the 18 model years stored in the record
C and
C
      PRINT *,'Reading old annual credits and echoing old annual ',
     & 'credits'
C
      DO 35 IMY=1,18
C
C loop for the 3 pollutants (HC, CO, and NOX) in the record--
C
        DO 36 IP=1,3
          READ(2,110,END=315,ERR=320)(ACREDT(IBY,IP,IMY),IBY=1,24),
     &                               CRDCOM
 110      FORMAT(24F5.3,A19)
C
C and write the data to the new file
C
          WRITE(3,220,ERR=325)(ACREDT(IBY,IP,IMY),IBY=1,24),CRDCOM
 220      FORMAT(24F5.3,A19)
 36     CONTINUE
C
 35   CONTINUE
C
C Go back to beginning of the data file to begin the search for the
C biennial Smart line corresponding to the above annual Smart line
C
      REWIND(2)
C
C Read current Smart line
C
 40   CONTINUE
C
C If old data, don't try to read flags after cutpoints
C
      IF (OLDFLG.EQ.1) THEN
C
        READ(2,112,END=330,ERR=310)(SMARK(ISMART),ISMART=1,4),CKUTHC,
     &                             CKUTCO,CKUTNO
 112    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1)
      ELSE
C
C New data, so read the flags
C
        READ(2,115,END=330,ERR=310)(SMARK(ISMART),ISMART=1,4),CKUTHC,
     &                             CKUTCO,CKUTNO,HYBFLG,IMFLG,ETCFLG
 115    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,3I1)
      ENDIF
C
C Reading a Smart line; looking for biennial data
C
C If it is not the matching biennial Smart line, read the next Smart
C line
C
      IF ( (SMARK(1).NE.SMART(1)) .OR. (SMARK(2).NE.2) .OR.
     &     (SMARK(3).NE.SMART(3)) .OR. (SMARK(4).NE.SMART(4)) .OR.
     &     (CCUTHC  .NE.  CKUTHC) .OR. (CCUTCO  .NE.  CKUTCO) .OR.
     &     (CCUTNO  .NE.  CKUTNO) ) THEN
C       
        DO 38 IREC=1,54
          READ(2,100,END=20)
C100      FORMAT(1X)
 38     CONTINUE
C
        GO TO 40
      END IF
C
C Now that a match has been found, output new biennial results;
C write new biennial credit Smart line.
C
C Execute the following if OLDFLG is not 1; the following is for new
C data.
C
      IF (OLDFLG.NE.1) THEN
C
C But halt processing if the matching biennial Smart line has a value
C of IMFLG that is not one, because this means that the biennial
C data has already been changed due to RSD effects, and making more
C than one change on the same data would result in nonsense.
C
        IF ( (IMFLG.NE.1).AND.(IMFLG.NE.0) ) THEN
          GO TO 332
        END IF
C
C Found matching biennial data; writing new credits
C
        WRITE(3,235,ERR=335)(SMARK(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,HYBFLG,ETCFLG,OPTION,RSDD
 235    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,I1,'2',I1,1X,'New ',
     &         'biennial credits, Option = ',I1,', Program type = 1, ',
     &         'input data file ',A40)
      ELSE
C
C For old data, can't examine IMFLG--just write it as '2'; write HYBFLG
C and ETCFLG as blanks.
C
        WRITE(3,236,ERR=335)(SMARK(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,OPTION,RSDD
 236    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,' 2 ',1X,'New ',
     &         'biennial credits, Option = ',I1,', Program type = 1, ',
     &         'input data file ',A40)
      ENDIF
C
C Read the biennial credits.
C
      PRINT *,'Reading old biennial credits and writing new biennial ',
     & 'credits'
C
C Loop for the 18 model years stored in the record.
C
      DO 45 IMY=1,18
C
C Loop for the 3 pollutants (HC, CO, and NOX) in the record.
C
        DO 46 IP=1,3
C
C Loop for the 24 age credit values
C
          READ(2,120,END=340,ERR=345)(BCREDT(IBY),IBY=1,24),CRDCOM
 120      FORMAT(24F5.3,A19)
C
C Calculate the new biennial credit.
C
          DO 48 IBY=1,24
C
              NCREDT(IBY) = BCREDT(IBY) + ( ACREDT(IBY,IP,IMY)
     &                      - BCREDT(IBY) ) * NVSEEB(IBY) * UEXCE4(IP)
C
 48       CONTINUE
C
          WRITE(3,240,ERR=325)(NCREDT(IBY),IBY=1,24),CRDCOM
 240      FORMAT(24F5.3,A19)
C
 46    CONTINUE
C
 45   CONTINUE
C
C Now go back up to the procedure for finding the next annual Smart
C line that has not been processed yet.
C
      REWIND(2)
C
      GO TO 50
C
C --------------
C ERROR MESSAGES
C --------------
C
 300  CONTINUE
      WRITE(*,301)IN1981       
 301  FORMAT(/,  ' ERROR OPENING INPUT FILE ',A40)
      GO TO 55
C
 305  CONTINUE
      WRITE(*,306)OUT198       
 306  FORMAT(/,  ' ERROR OPENING OUTPUT FILE ',A40)
      GO TO 55
C
 310  CONTINUE
      WRITE(*,311)IN1981       
 311  FORMAT(/,  ' ERROR READING SMART LINE FROM INPUT ',
     &            'FILE ',A40)
      GO TO 55
C
 315  CONTINUE
      WRITE(*,316)IN1981       
 316  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING ',
     &            'ANNUAL CREDITS FROM INPUT FILE ',/,
     &           ' ',A40)
      GO TO 55
C
 320  CONTINUE
      WRITE(*,321)IN1981       
 321  FORMAT(/,  ' ERROR READING ANNUAL CREDITS FROM INPUT ',
     &            'FILE ',A40)
      GO TO 55
C
 325  CONTINUE
      WRITE(*,326)OUT198       
 326  FORMAT(/,  ' ERROR WRITING ANNUAL CREDIT LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 55
C
 330  CONTINUE
      WRITE(*,331)IN1981       
 331  FORMAT(/,  ' ERROR NO MATCHING BIENNIAL DATA IN ',
     &            'INPUT FILE ',A40)
      GO TO 55
C
 332  CONTINUE
      WRITE(*,333)       
 333  FORMAT(/,  ' ERROR CANNOT APPLY RSD EFFECTS TO DATA ',
     &            'THAT HAS ALREADY BEEN CHANGED ')
      GO TO 55
C
 335  CONTINUE
      WRITE(*,336)OUT198       
 336  FORMAT(/,  ' ERROR WRITING BIENNIAL SMART LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 55
C
 340  CONTINUE
      WRITE(*,341)IN1981       
 341  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING ',
     &            'BIENNIAL CREDITS FROM INPUT FILE ',/,
     &           ' ',A40)
      GO TO 55
C
 345  CONTINUE
      WRITE(*,346)IN1981       
 346  FORMAT(/,  ' ERROR READING BIENNIAL CREDIT FROM ',
     &            'INPUT FILE ',A40)
C
C -----------------
C END OF PROCEDURES
C -----------------
C
 55   CONTINUE
      WRITE(*,350)       
 350  FORMAT(/,  ' CONVERSION ENDED ABNORMALLY',/)
      GO TO 60
C
 20   CONTINUE
      WRITE(*,245)       
 245  FORMAT(/,  ' Conversion ended normally',/)
C
 60   CONTINUE
C
      CLOSE (3)
      CLOSE (2)
C
      RETURN
      END
      SUBROUTINE TECH4(INT12,OUTT12,NVSEEA,UEXCE1,UEXCE2,RSDD)
C
C TECH4
C
C Calculates new sets of IM credits for
C IM programs using Remote Sensing Devices (RSD)
C from the existing Tech 1 & 2 credits
C
C Called by INPUT
C
C Calls no subroutines
C
C Input:
C by user:  none
C common block(s):  OP1
C data file(s):  file whose name is passed in INT12 
C subroutine arguments:  INT12, OUTT12, NVSEEA, UEXCE1, UEXCE2, RSDD
C
C Output:
C by screen:  none
C common block(s):  none
C data file(s):  file whose name is passed in OUTT12
C subroutine arguments:  none
C
C Array subscripts:
C
C CR12CO(19,20,5,2) - CR12CO(IBY,IAGE1,ISTR,ITECH)
C CR12HC(19,20,5,2) - CR12HC(IBY,IAGE1,ISTR,ITECH)
C CUTS(4)           - CUTS(ITECH)
C EFF(3)            - EFF(IP)
C EXCESS(3,15,3)    - EXCESS(ITECH,cutpoint,pollutant)
C NVSEEA(25)        - NVSEEA(age of vehicle)
C UEXCE1(3)         - UEXCE1(pollutant:  1=HC, 2=CO, & 3=NOx)
C UEXCE2(3)         - UEXCE2(pollutant:  1=HC, 2=CO, & 3=NOx)
C VMT(25)           - VMT(IBY)
C
C  Local variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C AGE     I   Age at which a veh. first becomes subject to RSD program
C ANNUAL  R   temporary Annual credit
C CR12CO  R   Array of Tech 1 & 2 CO IM credits
C CR12HC  R   Array of Tech 1 & 2 HC IM credits
C CUTCO   R   Smart line original CO cutpoint
C CUTHC   R   Smart line original HC cutpoint
C CUTNO   R   Smart line original NO cutpoint
C CUTS    R   Array of RSD CO cutpoints by Tech type, 1, 2, and 4+
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C ETCFLG  I   An extra flag in IMDATA.FOR, in TECH12.FOR, it serves as the
C              IMLFG (see below) for Tech 2 data
C EXCESS  R   See routines R1 and R2
C HYBFLG  I   Hybrid program flag
C IAGE    I   Counter for age when first inspected 
C IBY     I   Counter for Benefit Years
C IBY     I   Counter for Benefit Years
C ILINE   I   Counter for Smart lines
C IMFLG   I   Tech 1 I/M flag:  1 if no RSD program modifications done on
C              Tech 1 part of TECH12.D; 2 if Tech 1 data was changed
C INT12   C   Character string name of the TECH12.D type input file
C ISMART  I   Counter for Smart strip
C ISTR    I   Counter for Stringency
C ITECH   I   Counter for Tech type
C NUMBER  I   Total number of veh. subject to inspection program
C NVSEEA  R   Fraction of vehicles seen by RSD, annual program
C OLDFLG  I   If old data, OLDFLG=1, if new, 0.
C OPTION  I   Option--see RSDDRV
C OUTT12  C   Character string name of the TECDATA.D type output file
C SCAN    I   Number of valid veh. measurements per month at RSD sites
C SMART   I   Array of the Smart strip values
C RSDD    C   Char. string name for input data file
C THREE   C   Character string name for the flags HYBFLG, IMFLG, and
C              ETCFLG if they exist, otherwise it contains part of the
C              comment line
C TIMES   I   Minimum number of times a vehicle must be scanned between
C              inspections to be eligible for targetting.
C UEXCE1  R   Effectiveness of RSD, Tech type 1 vehicles
C UEXCE2  R   Effectiveness of RSD, Tech type 2 vehicles
C VMT     I   Vehicle miles travelled by age
C
C Notes:  Annual and biennial information is stored in an upper and
C         lower triangular fashion.
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 17-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 15-Apr-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
      CHARACTER INT12*40, OUTT12*40, RSDD*40, THREE*3
C
      INTEGER AGE, ETCFLG, HYBFLG, IAGE, IBY, IMFLG, ISMART, ISTR
      INTEGER ITECH, NUMBER, OLDFLG, OPTION, SCAN, SMART(4), TIMES
      INTEGER VMT(25)
C
      REAL ANNUAL, CR12CO(19,20,5,2), CR12HC(19,20,5,2)
      REAL CUTCO, CUTHC, CUTNO, CUTS(4), EFF(3), EXCESS(3,15,3)
      REAL NVSEEA(25), UEXCE1(3), UEXCE2(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
C
C If old data, OLDFLG is set to 1; first initialize OLDFLG to 0
C
      OLDFLG=0
C
      WRITE(*,200)
 200  FORMAT(/,  ' Starting to alter 1974 and older model ',
     &            'years and 1975 through 1980 model years ',/,
     &           ' vehicles I/M credits to include Remote ',
     &            'Sensing Devices credits',/,
     &           ' ---------------------------------------',
     &            '---------------------------------------')
C
C Open filename in INT12 for input as unit 12
C Open filename in OUTT12 for output as unit 13
C
      OPEN(12,FILE=INT12, ERR=300,STATUS='OLD')
      OPEN(13,FILE=OUTT12,ERR=310)
C
 90   CONTINUE
C
      READ(12,100,END=97,ERR=320) (SMART(ISMART),ISMART=1,4),
     &     CUTHC,CUTCO,CUTNO,THREE
  100 FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,A3)
C
      READ(THREE,105,ERR=15) HYBFLG,IMFLG,ETCFLG
  105 FORMAT(3I1)
C
      GO TO 16
C
 15   CONTINUE
C
C When there is a misread of the flags, the data is of the old type;
C set OLDFLG to 1 and skip the check on IMFLG
C
      OLDFLG=1
      GO TO 17
C
 16   CONTINUE
C
C If IMFLG is not one, this means that Tech 1 or Tech 2 data has been
C changed using RSD effects.  Issue error and halt.
C
      IF ( (IMFLG.NE.1).AND.(IMFLG.NE.0) ) THEN
        GO TO 325
      END IF
C
 17   CONTINUE
C
C Read in Annual and Biennial credits for HC
C Loop for the two (2) ITECHs stored in the record.
C
      DO 10 ITECH=1,2
C
C Loop for the five (5) stringency values in the record.
C
        DO 12 ISTR=1,5
C
C Loop for the values in the record
C
          DO 14 IAGE1=1,20

            READ(12,110,END=330,ERR=335)
     & (CR12HC(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
  110       FORMAT(19F4.3)
  14      CONTINUE
C
  12    CONTINUE

  10  CONTINUE
C
C Read in Annual and Biennial credits for CO
C
      DO 20 ITECH=1,2
C
        DO 22 ISTR=1,5
C
          DO 24 IAGE1=1,20
            READ(12,110,END=340,ERR=345)
     & (CR12CO(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
 24       CONTINUE
C
 22     CONTINUE

 20   CONTINUE
C
C Process the data and then write it to the output file
C
      DO 30 ITECH=1,2
C
        DO 32 ISTR=1,5
C
          DO 34 IBY=1,19
C
            DO 36 IAGE=1,19
C
C Only let the benefit year counter IBY and the age at first
C inspection counter be in the upper triangular region of Annual
C data.  (Another way of looking at this is that the actual age of a
C vehicle is its age at first inspection plus the time elapsed since its
C first inspection--current benefit year minus first benefit year.
C The actual age is thus IAGE+IBY-1.  Since actual age cannot exceed 
C 19 years, IAGE+IBY-1 must be .LE. 19.)
C 
              IF ((IBY+IAGE).GT.20) THEN
                GO TO 34
              END IF
C
C HC credits
C
              ANNUAL=CR12HC(IBY,IAGE,ISTR,ITECH)
C
              IF (ITECH.EQ.1) THEN
C
                CR12HC(IBY,IAGE,ISTR,ITECH) = ANNUAL *
     & NVSEEA(IAGE+IBY-1) * UEXCE1(1)
C
C Note:  new annual credit = annual credit * F * E
C
                CR12HC(20-IBY,21-IAGE,ISTR,ITECH) = 0.0
C
C Note:  biennial credit is zero for Program Type 4, Tech 1 & 2
C
              ELSE
C
C ITECH is 2
C
                CR12HC(IBY,IAGE,ISTR,ITECH) = ANNUAL *
     & NVSEEA(IAGE+IBY-1) * UEXCE2(1)
C
                CR12HC(20-IBY,21-IAGE,ISTR,ITECH) = 0.0
C
              END IF
C
C Note that NVSEEA and NVSEEB are functions of the actual age of
C the vehicle.  See above.
C
C CO credits
C
              ANNUAL=CR12CO(IBY,IAGE,ISTR,ITECH)
C
              IF (ITECH.EQ.1) THEN
C
                CR12CO(IBY,IAGE,ISTR,ITECH) = ANNUAL *
     & NVSEEA(IAGE+IBY-1) * UEXCE1(2)
C
                CR12CO(20-IBY,21-IAGE,ISTR,ITECH) = 0.0
C
              ELSE
C
C ITECH is 2
C
                CR12CO(IBY,IAGE,ISTR,ITECH) = ANNUAL *
     & NVSEEA(IAGE+IBY-1) * UEXCE2(2)
C
                CR12CO(20-IBY,21-IAGE,ISTR,ITECH) = 0.0
C
              END IF
C
 36         CONTINUE
C
 34       CONTINUE
C
 32     CONTINUE
C
 30   CONTINUE
C
C Write processed data to the output file; first rewrite Smart line.
C
C If OLDFLG is not 1, then the data is of the new type; output the
C following
C
      IF (OLDFLG.NE.1) THEN
        WRITE(13,240,ERR=350)(SMART(ISMART),ISMART=1,4),CUTHC,CUTCO,
     & CUTNO,HYBFLG,ETCFLG,OPTION,RSDD
  240   FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,I1,'2',I1,' New ',
     &         'credits, Option = ',I1,', Program type = 4, ',
     &         'input data file ',A40)
      ELSE
C
C Data is of the old type
C
        WRITE(13,245,ERR=350)(SMART(ISMART),ISMART=1,4),CUTHC,CUTCO,
     & CUTNO,OPTION,RSDD
  245  FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,' 2 ',' New ',
     &         'credits, Option = ',I1,', Program type = 4, ',
     &         'input data file ',A40)
      ENDIF
C
C Write the HC data
C
      DO 40 ITECH=1,2
C
        DO 42 ISTR=1,5
C
          DO 44 IAGE1=1,20
C
            WRITE(13,250,ERR=350)
     & (CR12HC(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
  250       FORMAT(19F4.3)
  44      CONTINUE
C
  42    CONTINUE

  40  CONTINUE
C
C Write the CO data
C
      DO 50 ITECH=1,2
C
        DO 52 ISTR=1,5
C
          DO 54 IAGE1=1,20
C
            WRITE(13,250,ERR=350)
     & (CR12CO(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
 54       CONTINUE
C
 52     CONTINUE

 50   CONTINUE
C
C Loop back to the beginning to read next Smart line and associated data
C
      GO TO 90
C
C ---------------------------
C CONSOLIDATED ERROR MESSAGES
C ---------------------------
C
 300  CONTINUE
      WRITE(*,301)INT12
 301  FORMAT(/,  ' ERROR OPENING INPUT FILE ',A40)
      GOTO 96
C
 310  CONTINUE
      WRITE(*,311)OUTT12
 311  FORMAT(/,  ' ERROR OPENING OUTPUT FILE ',A40)
      GOTO 96
C
 320  CONTINUE
      WRITE(*,321)INT12
 321  FORMAT(/,  ' ERROR READING SMART LINE FROM INPUT ',
     &            'FILE ',A40)
      GOTO 96
C
 325  CONTINUE
      WRITE(*,326)
 326  FORMAT(/,  ' ERROR CANNOT APPLY RSD EFFECTS--DATA ',
     &            'HAVE ALREADY BEEN CHANGED')
      GOTO 96
C
 330  CONTINUE
      WRITE(*,331)INT12
 331  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING HC ',
     &            'CREDITS FROM INPUT FILE ',A40)
      GOTO 96
C
 335  CONTINUE
      WRITE(*,336)INT12
 336  FORMAT(/,  ' ERROR READING HC CREDITS FROM INPUT ',
     &            'FILE ',A40)
      GOTO 96
C
 340  CONTINUE
      WRITE(*,341)INT12
 341  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING CO ',
     &            'CREDITS FROM INPUT FILE ',A40)
      GOTO 96
C
 345  CONTINUE
      WRITE(*,346)INT12
 346  FORMAT(/,  ' ERROR READING CO CREDITS FROM INPUT ',
     &            'FILE ',A40)
      GOTO 96
C
 350  CONTINUE
      WRITE(*,351)OUTT12
 351  FORMAT(/,  ' ERROR WRITING TO OUTPUT FILE ',A40)
      GOTO 96
C
C ---------------------------------
C CLOSE DATA FILES AND EXIT PROGRAM
C ---------------------------------
C
 96   WRITE(*,'(A)')'0CONVERSION ENDED ABNORMALLY.'
      GOTO 98
C
 97   WRITE(*,'(A)')'0Conversion ended normally.'
C
 98   CONTINUE
C
      CLOSE (13)
      CLOSE (12)
C
      RETURN
      END
      SUBROUTINE IM2(IN1981,OUT198,NVSEEA,UEXCE4,NVSEEB,RSDD)
C
C IM2
C
C Calculates new sets of IM credits for
C IM programs using Remote Sensing Devices (RSD) 
C from the existing 1981 and newer model years vehicles credits
C
C Called by INPUT
C
C Calls no subroutines
C
C Input:
C by user:  none
C common block(s):  OP1
C data file(s):  file whose name is passed in IN1981  
C subroutine arguments:  IN1981, OUT198, NVSEEA, UEXCE4, NVSEEB, RSDD
C
C Output:
C by screen:  none
C common blocks(s):  none
C data file(s):  file whose name is passed in OUT198
C subroutine arguments:  none
C
C Array subscripts:
C
C ACREDT(18,3,24) - ACREDT(ITECH,IP,IBY)
C BCREDT(24)      - BCREDT(IBY)
C CUTS(4)         - CUTS(ITECH)
C EFF(3)          - EFF(IP)
C EXCESS(3,15,3)  - EXCESS(ITECH,cutpoint,IP)
C NCREDT(24)      - NCREDT(IBY)
C NVSEEA(25)      - NVSEEA(IBY)
C NVSEEB(25)      - NVSEEB(IBY)
C SMARK(4)        - SMARK(ISMART)
C SMART(4)        - SMART(ISMART)
C UEXCE4(3)       - UEXCE4(IP)
C VMT(25)         - VMT(IBY)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -  
C ACREDT  R   Array of annual credits read from the input file
C AGE     I   Age at which a veh. first becomes subject to RSD program
C BCREDT  R   Array of biennial credits read from the input file
C CCUTCO  R   CO cut point read from an input file annual Smart line
C CCUTHC  R   HC cut point read from an input file annual Smart line
C CCUTNO  R   NOx cut point read from an input file annual Smart line
C CKUTCO  R   CO cut point read from an input file biennial Smart line
C CKUTHC  R   HC cut point read from an input file biennial Smart line
C CKUTNO  R   NOx cut point read from an input file biennial Smart line
C CRDCOM  C   Char. string of comments from the end of a credit line 
C CUTS    R   Array of RSD CO test cutpoints for vehicle groups
C              pre-1975, 1975-1980, and post-1980, Clean Screen NOx Cutpoint
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C ETCFLG  I   Etc. flag, may be used for something in the future.
C EXCESS  R   See routines R1 and R2
C FLAG    I   The next Smart line to be examined for annual data is
C              FLAG+1 Smart lines from the top of the input file
C HYBFLG  I   Hybrid program flag
C IBY     I   Counter for Benefit Years
C ILINE   I   Counter for Smart lines
C IMFLG   I   I/M flag:  1 if no RSD program modifications done on
C              IMDATA; 2 if data was changed
C IN1981  C   Character string name of the IMDATA.D type input filename
C IP      I   Counter for pollutants
C IREC    I   Counter for credit lines
C ISMART  I   Counter for digits in the Smart control strip
C ITECH   I   Counter for model years
C NCREDT  R   Array of new credits
C NUMBER  I   Total number of vehicles subject to the I/M program.
C NVSEEA  R   Fraction of vehicles seen by RSD, annual program
C NVSEEB  R   Fraction of vehicles seen by RSD, biennial program
C OPTION  I   Option--see RSDDRV
C OLDFLG  I   If old data, OLDFLG=1, if new, 0.
C OUT198  C   Char. string name of the RSDDATA.D type output filename
C RSDD    C   Char. string name of input data file
C SCAN    I   Number of valid veh. measurements per month at RSD sites
C SMARK   I   Array holding the first four digits of a biennial Smart
C              line (the Smart control strip):  altitude 1=Low 2=High; 
C              frequency 1=annual 2=biennial; technology 1=TECH1&2
C              2=TECH4+; test type 1=Idle 2=2500/Idle 3=Loaded/Idle
C              4=IM240 Test
C SMART   I   Array holding the 1st four digits of an annual Smart line
C THREE   C   Character string name for the flags HYBFLG, IMFLG, and
C              ETCFLG if they exist, otherwise it contains part of the
C               comment line
C TIMES   I   Minimum number of times a vehicle must be scanned between
C              inspections to be eligible for targetting
C UEXCE4  R   RSD effectiveness for Tech 4+ vehicles
C VMT     I   Vehicle miles travelled by age
C
C
C Notes:  Tech 1 refers to pre-1975 vehicles, Tech 2 to those from
C         1975-1980, and Tech 4+ to those of 1981 and later.
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 22-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 19-Mar-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C
C -----------------
C DECLARE VARIABLES
C -----------------
C
      CHARACTER CRDCOM*19, IN1981*40, OUT198*40, RSDD*40, THREE*3
C
      INTEGER AGE, ETCFLG, FLAG, HYBFLG, IBY, ILINE, IMFLG, IP, IREC
      INTEGER ISMART, ITECH, NUMBER, OLDFLG, OPTION, SCAN, SMARK(4)
      INTEGER SMART(4), TIMES, VMT(25)
C
      REAL ACREDT(18,3,24), BCREDT(24), CCUTHC, CCUTCO, CCUTNO, CKUTHC
      REAL CKUTCO, CKUTNO, CUTS(4), EFF(3), EXCESS(3,15,3), NCREDT(24)
      REAL NVSEEA(25), NVSEEB(25), UEXCE4(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
C
      WRITE(*,200)
 200  FORMAT(/,  ' Starting to alter 1981 and newer model ',
     &            'years vehicles I/M credits to include ',/,
     &           ' Remote Sensing Devices credits ',/,
     &           ' ---------------------------------------',
     &            '------------------------------------- ')
C
C ----------
C OPEN FILES
C ----------
C
      OPEN(UNIT=2,FILE=IN1981,ERR=300,STATUS='OLD')
      OPEN(UNIT=3,FILE=OUT198,ERR=305)
C
C ------------------
C START PROCESS LOOP
C ------------------
C
C Set FLAG=0.  This means that the first Smart line in the file is the
C line to check to see if it is one marking annual data.
C
      FLAG=0
C
C Set OLDFLG=0.  This means that data is new, i.e., it has HYBFLG,
C IMFLG, and ETCFLG.  If it is 1, it means that these don't exist and
C the data is old data.
C
      OLDFLG=0
C
 50   CONTINUE
C
C The following section of code jumps ahead in the data file to the
C first Smart line after the last Smart line marking annual data.
C Jumping ahead means reading one or more sets (a Smart line, 18 year
C sets composed of an HC line, a CO line, and a NOx line--55 lines in 
C all) of data so that the next record to be read will be a Smart line.
C
      DO 10 ILINE=1,FLAG
C
        DO 15 IREC=1,55
          READ(2,100,END=20)
 100      FORMAT(1X)
 15     CONTINUE
C
 10   CONTINUE
C
C Read the Smart control strip, cut point values and description line
C
 30   CONTINUE
C
      READ(2,102,END=20,ERR=310)(SMART(ISMART),ISMART=1,4),
     &                          CCUTHC,CCUTCO,CCUTNO,THREE
 102  FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,A3)
C
      READ(THREE,105,ERR=22)HYBFLG,IMFLG,ETCFLG
 105  FORMAT(3I1)
C
      GO TO 23
C
 22   CONTINUE
C
C An error in reading flags from THREE means that they aren't there;
C thus IMDATA.D is old-type data.
C
      OLDFLG=1
C
 23   CONTINUE
C
C Reading a Smart line; looking for annual data
C
C Increment FLAG, since the next Smart line that can mark annual data
C must be below the current Smart line
C
      FLAG=FLAG+1
C
C Check to see if the current Smart line marks annual data
C
      IF (SMART(2).NE.1) THEN
C
C Not annual; jump forward to the next Smart line and read it
C
        DO 25 IREC=1,54
          READ(2,100,END=20)
C100      FORMAT(1X)
 25     CONTINUE
C       
        GO TO 30
      END IF
C
C The current Smart line marks annual data.  Echo the annual Smart   
C line to the new file
C
C Execute the following if OLDFLG is not 1; the following is for new
C data
C
      IF (OLDFLG.NE.1) THEN
C
C Halt processing if the annual Smart line has a value
C of IMFLG that is not one, because this means that the annual
C data has already been changed due to RSD effects, and making more
C than one change on the same data would result in nonsense.
C
        IF ( (IMFLG.NE.1).AND.(IMFLG.NE.0) ) THEN
          GO TO 332
        END IF
C
        WRITE(3,215,ERR=312)(SMART(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,HYBFLG,ETCFLG,OPTION,RSDD
 215    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,I1,'2',I1,1X,'New ',
     &         'annual credits, Option = ',I1,', Program type = 2, ',
     &         'input data file ',A40)
      ELSE
C
C For old data, can't examine IMFLG--just write it as '2'; write  HYBFLG
C and ETCFLG as blanks.
C
        WRITE(3,216,ERR=312)(SMART(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,OPTION,RSDD
 216    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,' 2 ',1X,'New ',
     &         'annual credits, Option = ',I1,', Program type = 2, ',
     &         'input data file ',A40)
      ENDIF
C
C Read the annual credits.
C
      PRINT *,'Reading old annual credits / writing new annual ',
     & 'credits'
C
C Loop for the 18 model years stored in the record.
C
      DO 35 ITECH=1,18
C
C Loop for the 3 pollutants (HC, CO, and NOX) in the record.
C
        DO 36 IP=1,3
C
C Read the 24 age credit values
C
          READ(2,110,END=315,ERR=320)(ACREDT(ITECH,IP,IBY),IBY=1,24),
     &                               CRDCOM
 110      FORMAT (24F5.3,A19)
C
C Calculate the new annual credit.
C
C Note:  new annual credit = Test-only annual credit * F * E +
C Test-and-repair annual credit * (1-F*E).  Test-and-repair
C credit is EFF(IP) of Test-only credit.  The data from
C the input file is Test-only credit.
C
            DO 37 IBY=1,24
C
              NCREDT(IBY) =
     & ACREDT(ITECH,IP,IBY) * NVSEEA(IBY) * UEXCE4(IP) +
     & ACREDT(ITECH,IP,IBY) * EFF(IP) *
     & ( 1.0 - NVSEEA(IBY) * UEXCE4(IP) )
C
 37       CONTINUE
C
C * Note:  In a Test-and-repair program, mechanic training credits must
C   be properly set to their Test-and-repair values in MOBILE.  The only
C   way to do this is to explicitly run the Test-and-repair option in
C   MOBIL.  However, the IM credits get reduced by EFF(IP) in MOBILE
C   under this option.  Therefore, in routines IM2 and TECH2, the last
C   step in calculating the new annual and biennial credits is to
C   divide them each by EFF(IP), so that they have the proper values
C   when they are reduced in MOBILE.
C
          WRITE(3,220,ERR=325)(NCREDT(IBY)/EFF(IP),IBY=1,24),CRDCOM
 220      FORMAT(24F5.3,A19)
C
 36     CONTINUE
C
 35   CONTINUE
C
C Go back to beginning of the data file to begin the search for the
C biennial Smart line corresponding to the above annual Smart line
C
      REWIND(2)
C
C Read current Smart line
C
 40   CONTINUE
C
C If old data, don't try to read the flags after the cutpoints
C
      IF (OLDFLG.EQ.1) THEN
        READ(2,112,END=330,ERR=310)(SMARK(ISMART),ISMART=1,4),CKUTHC,
     &                             CKUTCO,CKUTNO
 112    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1)
      ELSE
        READ(2,115,END=330,ERR=310)(SMARK(ISMART),ISMART=1,4),CKUTHC,
     &                             CKUTCO,CKUTNO,HYBFLG,IMFLG,ETCFLG
 115    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,3I1)
      ENDIF
C
C Reading a Smart line; looking for biennial data
C
C If it is not the matching biennial Smart line, read the next Smart
C line
C
      IF ( (SMARK(1).NE.SMART(1)) .OR. (SMARK(2).NE.2) .OR.
     &     (SMARK(3).NE.SMART(3)) .OR. (SMARK(4).NE.SMART(4)) .OR.
     &     (CCUTHC  .NE.  CKUTHC) .OR. (CCUTCO  .NE.  CKUTCO) .OR.
     &     (CCUTNO  .NE.  CKUTNO) ) THEN
C       
        DO 38 IREC=1,54
          READ(2,100,END=20)
C100      FORMAT(1X)
 38     CONTINUE
C
        GO TO 40
      END IF
C
C Now that a match has been found, output new biennial results;
C write new biennial credit Smart line.
C
C Execute the following if OLDFLG is not 1; the following is for new
C data.
C
      IF (OLDFLG.NE.1) THEN
C
C But halt processing if the matching biennial Smart line has a value
C of IMFLG that is not one, because this means that the biennial
C data has already been changed due to RSD effects, and making more
C than one change on the same data would result in nonsense.
C
        IF ( (IMFLG.NE.1).AND.(IMFLG.NE.0) ) THEN
          GO TO 332
        END IF
C
C Found matching biennial data; writing new credits
C
        WRITE(3,235,ERR=335)(SMARK(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,HYBFLG,ETCFLG,OPTION,RSDD
 235    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,I1,'2',I1,1X,'New ',
     &         'biennial credits, Option = ',I1,', Program type = 2, ',
     &         'input data file ',A40)
      ELSE
C
C For old data, can't examine IMFLG--just write it as '2'; write HYBFLG
C and ETCFLG as blanks.
C
        WRITE(3,236,ERR=335)(SMARK(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,OPTION,RSDD
 236    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,' 2 ',1X,'New ',
     &         'biennial credits, Option = ',I1,', Program type = 2, ',
     &         'input data file ',A40)
      ENDIF
C
C Read the biennial credits.
C
      PRINT *,'Reading old biennial credits / writing new biennial ',
     & 'credits'
C
C Loop for the 18 model years stored in the record.
C
      DO 45 ITECH=1,18
C
C Loop for the 3 pollutants (HC, CO, and NOX) in the record.
C
        DO 46 IP=1,3
C
C Read the 24 age credit values
C
          READ(2,120,END=340,ERR=345)(BCREDT(IBY),IBY=1,24),CRDCOM
 120      FORMAT(24F5.3,A19)
C
C Calculate the new biennial credit.
C
C Note:  new biennial credit = Test-only annual credit * F * E +
C Test-and-repair biennial credit * (1-F*E).  Test-and-repair
C credit is EFF(IP) of Test-only credit.  The data from
C the input file is Test-only credit.
C
          DO 48 IBY=1,24
C
            NCREDT(IBY) =
     & ACREDT(ITECH,IP,IBY) * NVSEEB(IBY) * UEXCE4(IP) +
     & BCREDT(IBY) * EFF(IP) * ( 1.0 - NVSEEB(IBY) * UEXCE4(IP) )
C
 48       CONTINUE
C
C * Note:  (see * Note above)
C
          WRITE(3,240,ERR=350)(NCREDT(IBY)/EFF(IP),IBY=1,24),CRDCOM
 240      FORMAT(24F5.3,A19)
C
 46     CONTINUE
C
 45   CONTINUE
C
C Now go back up to the procedure for finding the next annual Smart
C line that has not been processed yet.
C
      REWIND(2)
C
      GO TO 50
C
C --------------
C ERROR MESSAGES
C --------------
C
 300  CONTINUE
      WRITE(*,301)IN1981       
 301  FORMAT(/,  ' ERROR OPENING INPUT FILE ',A40)
      GO TO 55
C
 305  CONTINUE
      WRITE(*,306)OUT198       
 306  FORMAT(/,  ' ERROR OPENING OUTPUT FILE ',A40)
      GO TO 55
C
 310  CONTINUE
      WRITE(*,311)IN1981       
 311  FORMAT(/,  ' ERROR READING SMART LINE FROM INPUT ',
     &            'FILE ',A40)
      GO TO 55
C
 312  CONTINUE
      WRITE(*,313)OUT198       
 313  FORMAT(/,  ' ERROR WRITING ANNUAL SMART LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 55
C
 315  CONTINUE
      WRITE(*,316)IN1981       
 316  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING ',
     &            'ANNUAL CREDITS FROM INPUT FILE ',/,
     &           ' ',A40)
      GO TO 55
C
 320  CONTINUE
      WRITE(*,321)IN1981       
 321  FORMAT(/,  ' ERROR READING ANNUAL CREDITS FROM INPUT ',
     &            'FILE ',A40)
      GO TO 55
C
 325  CONTINUE
      WRITE(*,326)OUT198       
 326  FORMAT(/,  ' ERROR WRITING ANNUAL CREDIT LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 55
C
 330  CONTINUE
      WRITE(*,331)IN1981       
 331  FORMAT(/,  ' ERROR NO MATCHING BIENNIAL DATA IN ',
     &            'INPUT FILE ',A40)
      GO TO 55
C
 332  CONTINUE
      WRITE(*,333)       
 333  FORMAT(/,  ' ERROR CANNOT APPLY RSD EFFECTS TO DATA ',
     &            'THAT HAS ALREADY BEEN CHANGED ')
      GO TO 55
C
 335  CONTINUE
      WRITE(*,336)OUT198       
 336  FORMAT(/,  ' ERROR WRITING BIENNIAL SMART LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 55
C
 340  CONTINUE
      WRITE(*,341)IN1981       
 341  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING ',
     &            'BIENNIAL CREDITS FROM INPUT FILE ',/,
     &           ' ',A40)
      GO TO 55
C
 345  CONTINUE
      WRITE(*,346)IN1981       
 346  FORMAT(/,  ' ERROR READING BIENNIAL CREDIT FROM ',
     &            'INPUT FILE ',A40)
      GO TO 55
C
 350  CONTINUE
      WRITE(*,351)OUT198       
 351  FORMAT(/,  ' ERROR WRITING BIENNIAL CREDIT LINE TO ',
     &            'OUTPUT FILE ',A40)
C
C --------------
C END PROCEDURES
C --------------
C
 55   CONTINUE
      WRITE(*,355)       
 355  FORMAT(/,  ' CONVERSION ENDED ABNORMALLY',/)
      GO TO 60
C
 20   CONTINUE
      WRITE(*,245)       
 245  FORMAT(/,  ' Conversion ended normally',/)
C
 60   CONTINUE
C
      CLOSE (3)
      CLOSE (2)
C
      RETURN
      END
      SUBROUTINE IM3(IN1981,IN198H,OUT198,NVSEEA,UEXCE4,NVSEEB,RSDD)
C
C IM3
C
C Calculates new sets of IM credits for
C IM programs using Remote Sensing Devices (RSD) 
C from the existing 1981 and newer model years vehicles credits
C
C Called by INPUT
C
C Calls no subroutines
C
C Input:
C by user:  none
C common block(s):  OP1
C data file(s):  files whose names are passed in IN1981 and IN198H  
C subroutine arguments:  IN1981, IN198H, OUT198, NVSEEA, UEXCE4, NVSEEB,
C                        RSDD
C
C Output:
C by screen:  none
C common blocks(s):  none
C data file(s):  file whose name is passed in OUT198
C subroutine arguments:  none
C
C Array subscripts:
C
C ACREDT(18,3,24) - ACREDT(IMY,IP,IBY)
C CUTS(4)         - CUTS(ITECH)
C EFF(3)          - EFF(IP)
C EXCESS(3,15,3)  - EXCESS(ITECH,cutpoint,IP)
C HACRDT(24)      - HACRDT(IBY)
C HBCRDT(24)      - HBCRDT(IBY)
C NCREDT(24)      - NCREDT(IBY)
C NVSEEA(25)      - NVSEEA(age of vehicle)
C NVSEEB(25)      - NVSEEB(age of vehicle)
C SMARK(4)        - SMARK(ISMART)
C SMART(4)        - SMART(ISMART)
C UEXCE4(3)       - UEXCE4(pollutant:  1=HC, 2=CO, & 3=NOx)
C VMT(25)         - VMT(IBY)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -  
C ACREDT  R   Array of annual credits read from the input file
C AGE     I   Age at which a veh. first becomes subject to RSD program
C CCUTCO  R   CO cut point read from an input file annual Smart line
C CCUTHC  R   HC cut point read from an input file annual Smart line
C CCUTNO  R   NOx cut point read from an input file annual Smart line
C CKUTCO  R   CO cut point read from an input file biennial Smart line
C CKUTHC  R   HC cut point read from an input file biennial Smart line
C CKUTNO  R   NOx cut point read from an input file biennial Smart line
C CRDCOM  C   Char. string of comments from the end of a credit line 
C CUTS    R   Array of RSD CO cutpoints by Tech type:  1, 2, 4+
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C ETCFLG  I   Etc. flag, may be used for something in the future.
C EXCESS  R   See routines R1 and R2
C HACRDT  R   Array of annual Retest-hybrid credits read from the
C              Hybrid-retest input file
C HBCRDT  R   Array of biennial Retest-hybrid credits read from the 
C              Hybrid-retest input file
C HYBFLG  I   Hybrid program flag
C IBY     I   Counter for Benefit Years
C IMY     I   Counter for model year
C IMFLG   I   I/M flag:  1 if no RSD program modifications done on
C              IMDATA; 2 if data was changed
C IN1981  C   Character string name of the IMDATA.D type input filename
C IN198H  C   Character string name of the IMH.D type input filename
C IP      I   Counter for pollutants
C IREC    I   Counter for credit lines
C ISMART  I   Counter for digits in the Smart control strip
C ITECH   I   Counter for Tech type:  1, 2, and 4+
C NCREDT  R   Array of new credits
C NVSEEA  R   Fraction of vehicles seen by RSD, annual program
C NVSEEB  R   Fraction of vehicles seen by RSD, biennial program
C NUMBER  I   Total number of vehicles subject to the I/M program
C OLDFLG  I   If old data, OLDFLG=1, if new, 0.
C OPTION  I   Option--see RSDDRV
C OUT198  C   Char. string name of the RSDDATA.D type output filename
C RSDD    C   Char. string name of the input data file
C SCAN    I   Number of valid veh. measurements per month at RSD sites
C SMARK   I   Array holding the first four digits of a biennial Smart
C              line (the Smart control strip):  altitude 1=Low 2=High; 
C              frequency 1=annual 2=biennial; technology 1=TECH1&2
C              2=TECH4+; test type 1=Idle 2=2500/Idle 3=Loaded/Idle
C              4=IM240 Test
C SMART   I   Array holding the 1st four digits of an annual Smart line
C THREE   C   Character string name for the flags HYBFLG, IMFLG, and
C              ETCFLG if they exist, otherwise it contains part of the
C              comment line
C TIMES   I   Minimum number of times a vehicle must be scanned between
C              inspections to be eligible for targetting
C UEXCE4  R   RSD effectiveness for Tech type 4+
C VMT     I   Vehicle miles travelled by age
C
C
C Notes:  Tech 1 refers to pre-1975 vehicles, Tech 2 to those from
C         1975-1980, and Tech 4+ to those of 1981 and later.
C 10-July-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 19-Mar-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C -----------------
C DECLARE VARIABLES
C -----------------
C
      CHARACTER CRDCOM*19, IN1981*40, IN198H*40, OUT198*40, RSDD*40
      CHARACTER THREE*3
C
      INTEGER AGE, ETCFLG, HYBFLG, IBY, IMFLG, IP, IREC, ISMART
      INTEGER NUMBER, OLDFLG, OPTION, SCAN, SMARK(4), SMART(4), TIMES
      INTEGER VMT(25)
C
      REAL ACREDT(18,3,24), CCUTHC, CCUTCO, CCUTNO, CKUTHC, CKUTCO
      REAL CKUTNO, CUTS(4), EFF(3), EXCESS(3,15,3), HACRDT(24)
      REAL HBCRDT(24), NCREDT(24), NVSEEA(25), NVSEEB(25), UEXCE4(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
C
C Initialize OLDFLG to 0, new data.
C
      OLDFLG=0
C
      WRITE(*,200)
 200  FORMAT(/,  ' Starting to alter 1981 and newer model ',
     &            'years vehicles I/M credits to include ',/,
     &           ' Remote Sensing Devices credits',/,
     &           ' ---------------------------------------',
     &            '------------------------------------- ')
C
C ----------
C OPEN FILES
C ----------
C
      OPEN(UNIT=2,FILE=IN1981,ERR=300,STATUS='OLD')
      OPEN(UNIT=4,FILE=IN198H,ERR=302,STATUS='OLD')
      OPEN(UNIT=3,FILE=OUT198,ERR=305)
C
C ------------------
C START PROCESS LOOP
C ------------------
C
 70   CONTINUE
C
C At this point, either processing has just started, and file IN1981
C (and file IN198H) have not been read yet, or
C annual data from file IN1981, annual data from file IN198H
C and biennial data from file IN198H have just been
C processed, and the code is about to search the next record below
C the last annual IN1981 data block in order to find the next
C annual IN1981 data block.
C
C Read the current Smart control strip, cut point values and 
C description line from file IN1981.  If the end of
C the file is arrived at, this means that no more credit blocks are
C available in IN1981 and processing will end
C without any warnings.  This means that the amount of information in
C sent to the output file will match the amount in IN1981.
C
 30   CONTINUE
C
      READ(2,100,END=20,ERR=310)(SMART(ISMART),ISMART=1,4),
     &                          CCUTHC,CCUTCO,CCUTNO,THREE
 100  FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,A3)
C
      READ(THREE,102,ERR=22) HYBFLG,IMFLG,ETCFLG
 102  FORMAT(3I1)
C
      GO TO 23
C
 22   CONTINUE
C
C An error in reading flags from THREE means that they aren't there;
C thus IN1981 is old-type data
C
      OLDFLG=1
C
 23   CONTINUE
C
C Reading a Smart line -- looking for annual data in input file
C
      IF (SMART(2).NE.1) THEN
C
C Not annual; jump forward to the next Smart line and read it
C
        DO 25 IREC=1,54
          READ(2,105,END=20)
 105      FORMAT(1X)
 25     CONTINUE
C       
        GO TO 30
      END IF
C
C Execute the following if OLDFLG is not 1; the following is for new
C data.
C
      IF (OLDFLG.NE.1) THEN
C
C Halt processing if the annual Smart line found has a value
C of IMFLG that is not one, because this means that the annual
C data has already been changed due to RSD effects, and making more
C than one change on the same data would result in nonsense.
C
        IF ( (IMFLG.NE.1).AND.(IMFLG.EQ.0) ) THEN
          GO TO 315
        END IF
C
      END IF
C
C Found Test-only annual data -- reading annual credits from input file
C
C Read (and save in array ACREDT for later use) the annual credits.
C
      PRINT *,'Reading old test-only annual credits'
C
C Loop for the 18 model years stored in the record.
C
      DO 35 IMY=1,18
C
C Loop for the 3 pollutants (HC, CO, and NOX) in the record.
C
        DO 36 IP=1,3
C
C Read the 24 age credit values
C
          READ(2,110,END=320,ERR=325)(ACREDT(IMY,IP,IBY),IBY=1,24),
     &                               CRDCOM
 110      FORMAT(24F5.3,A19)
C
 36     CONTINUE
C
 35   CONTINUE
C
C Done reading in annual credits from input file
C
C Search for the corresponding annual Smart line in file IN198H
C
      REWIND(4)
C
 40   CONTINUE
C
C Hybrid data is not changed by this code, thus there is no reason to
C read in or change the flags.  Don't read into the flag area.
C
      READ(4,103,END=330,ERR=335)(SMARK(ISMART),ISMART=1,4),
     &                           CKUTHC,CKUTCO,CKUTNO
 103  FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1)
C
C Reading a Smart line -- looking for annual data in input file
C
C Check to see if it is the matching annual Smart line.  If it is not, 
C jump ahead and read the next Smart line.  (Note that, since an annual
C Smart line is being searched for, and the SMART array contains annual
C information, it is appropriate to compare SMARK(2) to SMART(2), since
C these arrays are 1 for annual and 2 for biennial.)
C
      IF ( (SMARK(1).NE.SMART(1)) .OR. (SMARK(2).NE.SMART(2)) .OR.
     &     (SMARK(3).NE.SMART(3)) .OR. (SMARK(4).NE.SMART(4)) .OR.
     &     (CCUTHC  .NE.  CKUTHC) .OR. (CCUTCO  .NE.  CKUTCO) .OR.
     &     (CCUTNO  .NE.  CKUTNO) ) THEN
C       
        DO 45 IREC=1,54
          READ(4,105,END=330)
C105      FORMAT(1X)
 45     CONTINUE
C
        GO TO 40
      END IF
C
C Found matching Retest-hybrid annual Smart line -- reading annual
C credits from input file
C
C At this point, the matching annual Smart line has been found.
C Write the new annual Smart line to the output file.
C
C If old data, write out IMFLG as '2' and the others as blanks
C
      IF (OLDFLG.EQ.1) THEN
C
        WRITE(3,218,ERR=345)(SMARK(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,OPTION,RSDD
 218    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,' 2 ',1X,'New ',
     &         'annual credits, Option = ',I1,', Program type = 3, ',
     &         'input data file ',A40)
      ELSE
C
C New data; write IMFLG as '2' and echo the others
C
        WRITE(3,220,ERR=345)(SMARK(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,HYBFLG,ETCFLG,OPTION,RSDD
 220    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,I1,'2',I1,1X,'New ',
     &         'annual credits, Option = ',I1,', Program type = 3, ',
     &         'input data file ',A40)
      END IF
C
      PRINT *,'Reading retest-hybrid annual credits and writing new ',
     & 'annual credits'
C
C Write the new annual credits.
C
C Loop for the 18 model years stored in the record.
C
      DO 50 IMY=1,18
C
C Loop for the 3 pollutants (HC, CO, and NOX) in the record.
C
        DO 52 IP=1,3
C
C Read the 24 age credit values
C
          READ(4,110,END=350,ERR=355)(HACRDT(IBY),IBY=1,24),CRDCOM
C110      FORMAT (24F5.3,A19)
C
C Calculate the new annual credit.
C
C Note:  new annual credit = Test-only annual credit * F * E +
C Hybrid-retest annual credit * (1-F*E).  The data from
C file IN1981 is Test-only credit.
C
          DO 54 IBY=1,24
C
            NCREDT(IBY) =
     & ACREDT(IMY,IP,IBY) * NVSEEA(IBY) * UEXCE4(IP) +
     & HACRDT(IBY) * ( 1.0 - NVSEEA(IBY) * UEXCE4(IP) )
C
 54       CONTINUE
C
          WRITE(3,110,ERR=360)(NCREDT(IBY),IBY=1,24),CRDCOM
C110      FORMAT(24F5.3,A19)
C
 52     CONTINUE
C
 50   CONTINUE
C
C Go back to beginning of file IN198H to begin the
C search for the biennial Smart line corresponding to the above 
C annual Smart line
C
      REWIND(4)
C
C Read current Smart line
C
 60   CONTINUE
C
C Again, hybrid data is not changed by this code, thus there is no
C reason to read in or change the flags.  Don't read into the flag area.
C
      READ(4,103,END=365,ERR=370)(SMART(ISMART),ISMART=1,4),CCUTHC,
     &                           CCUTCO,CCUTNO
C103  FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1)
C
C Reading a Smart line -- looking for biennial data in input file
C
C Check to see if it is the matching biennial Smart line.  If it is not, 
C jump ahead and read the next Smart line.  (Note that SMART(2) is 1
C for annual and 2 for biennial.)
C
      IF ( (SMART(1).NE.SMARK(1)) .OR. (SMART(2).NE.2) .OR.
     &     (SMART(3).NE.SMARK(3)) .OR. (SMART(4).NE.SMARK(4)) .OR.
     &     (CCUTHC  .NE.  CKUTHC) .OR. (CCUTCO  .NE.  CKUTCO) .OR.
     &     (CCUTNO  .NE.  CKUTNO) ) THEN
C       
        DO 55 IREC=1,54
          READ(4,105,END=365)
C105      FORMAT(1X)
 55     CONTINUE
C
        GO TO 60
      END IF
C
C Found matching Retest-hybrid biennial Smart line -- reading biennial
C credits from input file
C
C At this point, the matching biennial Smart line has been found.
C Write the new biennial Smart line to the output file.
C
C If old data, write out IMFLG as '2' and the others as blanks
C
      IF (OLDFLG.EQ.1) THEN
C
        WRITE(3,234,ERR=380)(SMART(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,OPTION,RSDD
 234    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,' 2 ',1X,'New ',
     &         'biennial credits, Option = ',I1,', Program type = 3, ',
     &         'input data file ',A40)
      ELSE
C
C New data; write out IMFLG as '2' and echo the others
C
        WRITE(3,235,ERR=380)(SMART(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,HYBFLG,ETCFLG,OPTION,RSDD
 235    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,I1,'2',I1,1X,'New ',
     &         'biennial credits, Option = ',I1,', Program type = 3, ',
     &         'input data file ',A40)
      END IF
C
      PRINT *,'Reading retest-hybrid biennial credits and writing ',
     & 'new biennial credits'
C
C Write the new biennial credits.
C
C Loop for the 18 model years stored in the record.
C
      DO 65 IMY=1,18
C
C Loop for the 3 pollutants (HC, CO, and NOX) in the record.
C
        DO 67 IP=1,3
C
C Read the 24 age credit values
C
          READ(4,110,END=385,ERR=390)(HBCRDT(IBY),IBY=1,24),CRDCOM
C110      FORMAT (24F5.3,A19)
C
C Calculate the new biennial credit.
C
C Note:  new biennial credit = Test-only annual credit * F * E +
C Hybrid-retest biennial credit * (1-F*E).  The data from
C file IN1981 is Test-only credit.
C
          DO 69 IBY=1,24
C
            NCREDT(IBY) =
     & ACREDT(IMY,IP,IBY) * NVSEEB(IBY) * UEXCE4(IP) +
     & HBCRDT(IBY) * ( 1.0 - NVSEEB(IBY) * UEXCE4(IP) )
C
 69       CONTINUE
C
          WRITE(3,110,ERR=395)(NCREDT(IBY),IBY=1,24),CRDCOM
C110      FORMAT(24F5.3,A19)
C
 67     CONTINUE
C
 65   CONTINUE
C
C Now go back up to the procedure for finding the next annual Smart
C line that has not been processed yet.
C
      GO TO 70
C
C --------------
C ERROR MESSAGES
C --------------
C
 300  CONTINUE
      WRITE(*,301)IN1981       
 301  FORMAT(/,  ' ERROR OPENING TEST-ONLY CREDITS INPUT ',
     &            'FILE ',A40)
      GO TO 75
C
 302  CONTINUE
      WRITE(*,303)IN198H       
 303  FORMAT(/,  ' ERROR OPENING RETEST-HYBRID CREDITS ',
     &            'INPUT FILE ',A40)
      GO TO 75
C
 305  CONTINUE
      WRITE(*,306)OUT198       
 306  FORMAT(/,  ' ERROR OPENING OUTPUT FILE ',A40)
      GO TO 75
C
 310  CONTINUE
      WRITE(*,311)IN1981       
 311  FORMAT(/,  ' ERROR READING SMART LINE FROM TEST-ONLY ',
     &            'CREDITS INPUT FILE ',A40)
      GO TO 75
C
 315  CONTINUE
      WRITE(*,316)IN1981       
 316  FORMAT(/,  ' ERROR ANNUAL DATA BLOCK HAS ALREADY BEEN ',
     &            'CHANGED IN TEST-ONLY CREDITS ',/,
     &           ' INPUT FILE ',A40)
      GO TO 75
C
 320  CONTINUE
      WRITE(*,321)IN1981       
 321  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING ',
     &            'ANNUAL CREDITS FROM TEST-ONLY CREDITS ',/,
     &           ' INPUT FILE ',A40)
      GO TO 75
C
 325  CONTINUE
      WRITE(*,326)IN1981       
 326  FORMAT(/,  ' ERROR READING ANNUAL CREDITS FROM ',
     &            'TEST-ONLY CREDITS INPUT FILE ',/,
     &           ' ',A40)
      GO TO 75
C
 330  CONTINUE
      WRITE(*,331)IN198H       
 331  FORMAT(/,  ' END OF FILE BEFORE MATCHING ANNUAL ',
     &            'SMART LINE WAS FOUND IN RETEST-HYBRID ',/,
     &           ' CREDITS INPUT FILE ',A40)
      GO TO 75
C
 335  CONTINUE
      WRITE(*,336)IN198H       
 336  FORMAT(/,  ' ERROR READING ANNUAL SMART LINE FROM ',
     &            'RETEST-HYBRID CREDITS INPUT FILE ',/,
     &           ' ',A40)
      GO TO 75
C
 345  CONTINUE
      WRITE(*,346)OUT198       
 346  FORMAT(/,  ' ERROR WRITING NEW ANNUAL SMART LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 75
C
 350  CONTINUE
      WRITE(*,351)IN198H       
 351  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING ',
     &            'ANNUAL CREDITS FROM RETEST-HYBRID CREDITS ',/,
     &           ' INPUT FILE ',A40)
      GO TO 75
C
 355  CONTINUE
      WRITE(*,356)IN198H       
 356  FORMAT(/,  ' ERROR READING ANNUAL CREDITS FROM ',
     &            'RETEST-HYBRID CREDITS INPUT FILE ',/,
     &           ' ',A40)
      GO TO 75
C
 360  CONTINUE
      WRITE(*,361)OUT198       
 361  FORMAT(/,  ' ERROR WRITING NEW ANNUAL CREDIT LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 75
C
 365  CONTINUE
      WRITE(*,366)IN198H       
 366  FORMAT(/,  ' END OF FILE BEFORE MATCHING BIENNIAL ',
     &            'SMART LINE WAS FOUND IN RETEST-HYBRID ',/,
     &           ' CREDITS INPUT FILE ',A40)
      GO TO 75
C
 370  CONTINUE
      WRITE(*,371)IN198H       
 371  FORMAT(/,  ' ERROR READING BIENNIAL SMART LINE FROM ',
     &            'RETEST-HYBRID CREDITS INPUT FILE ',/,
     &           ' ',A40)
      GO TO 75
C
 380  CONTINUE
      WRITE(*,381)OUT198       
 381  FORMAT(/,  ' ERROR WRITING NEW BIENNIAL SMART LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 75
C
 385  CONTINUE
      WRITE(*,386)IN198H       
 386  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING ',
     &            'BIENNIAL CREDITS FROM RETEST-HYBRID CREDITS ',/,
     &           ' INPUT FILE ',A40)
      GO TO 75
C
 390  CONTINUE
      WRITE(*,391)IN198H       
 391  FORMAT(/,  ' ERROR READING BIENNIAL CREDITS FROM ',
     &            'RETEST-HYBRID CREDITS INPUT FILE ',/,
     &           ' ',A40)
      GO TO 75
C
 395  CONTINUE
      WRITE(*,396)OUT198       
 396  FORMAT(/,  ' ERROR WRITING NEW BIENNIAL CREDIT LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 75
C
C --------------
C END PROCEDURES
C --------------
C
 75   CONTINUE
      WRITE(*,397)       
 397  FORMAT(/,  ' CONVERSION ENDED ABNORMALLY',/)
      GO TO 80
C
 20   CONTINUE
      WRITE(*,245)
 245  FORMAT(/,  ' Conversion ended normally',/)
C
 80   CONTINUE
C
      CLOSE (3)
      CLOSE (4)
      CLOSE (2)
C
      RETURN
      END
      SUBROUTINE INPUT(RSDD)
C
C INPUT calls DATA2 in order to read in the information stored in file
C RSD.D, which supplies data needed to analyze any of the RSD options.
C It then calls R1, R2, or R3, depending on which option is chosen in
C order to find the fraction of vehicles "seen" by RSD, and the
C effectiveness of RSD in detecting the high emitters in the population
C it "sees".  These values are determined by the option chosen.
C Finally, it calls the IM# and TECH# pair of routines, where # is the
C RSD program number, ACTION.
C
C Called by RSDDRV (main)
C
C Calls subroutines DATA2; R1, R2, or R3; and IM1 and TECH1, IM2 and
C TECH2, IM3 and TECH3, IM4 and TECH4, or IM5 and TECH5
C
C Input: 
C by user:  none
C common blocks:  FILES, OP1, OP2, OP3
C data file(s): none
C subroutine arguments:  RSDD
C 
C Output:
C by screen:  none
C common blocks:  OP1, OP2, OP3
C data file(s):  none
C subroutine arguments:  none
C
C Array subscripts:
C
C ACUTS(4)       - ACUTS(ITECH)
C CUTS(4)        - CUTS(ITECH)
C EFF(3)         - EFF(IP)
C EOPT3(3,15,3)  - EOPT3(ITECH,cutpoint,IP)
C EXCESS(3,15,3) - EXCESS(ITECH,cutpoint,IP)
C NVSEEA(25)     - NVSEEA(benefit year)
C NVSEEB(25)     - NVSEEB(benefit year)
C UEXCE1(3)      - UEXCE1(pollutant)
C UEXCE2(3)      - UEXCE2(pollutant)
C UEXCE4(3)      - UEXCE4(pollutant)
C VMT(25)        - VMT(vehicle age)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C ACUTS   C   Array of character strings depending on the values of the
C              CUTS array: if an element of the CUTS array is 99.9, the
C              corresponding ACUTS element will be 'ASSUMES NO';
C              otherwise, it will be 'assumes an'
C ACTION  I   Program Type--see RSDDRV
C AGE     I   The age at which a car first becomes subject to the program
C CUTS    R   Array of RSD CO test cutpoints for vehicle groups 
C              pre-1975, 1975-1980, and post-1980, Clean Screen NOx Cutpoint
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C EOPT3   R   Array of user supplied RSD E values for Option 3
C              stored by Tech type, CO cutpoint, and pollutant (the same
C              way that values are stored in UEXCES in R1.FOR)
C EXCESS  R   Array of user supplied RSD excess detected fractions
C              stored by Tech type, CO cutpoint, and pollutant (the same
C              way that values are stored in UEXCES in R1.FOR)
C IAGE    I   Age counter
C IN1981  C   Character string name of the IMDATA.D type input file
C IN198H  C   Character string name of the HYBRID.IMC type input file
C INT12   C   Character string name of the TECH12.D type input file
C INT12H  C   ... name of Tech 1 & 2 Retest-Hybrid IM data input file
C ITECH   I   1 is tech type 1, 2 is 2, and 3 is 4
C NUMBER  I   Total number of vehicles subject to the inspection program
C NVSEEA  R   Fraction of vehicles seen by RSD, annual program
C NVSEEB  R   Fraction of vehicles seen by RSD, biennial program
C OPTION  I   Option--see RSDDRV
C OUT198  C   Character string name of the RSDDATA.D type output file
C OUT19H  C   Char. string name of the Tech4+ Retest-Hybrid output file
C OUTT12  C   Character string name of the TECDATA.D type output file
C OUTT1H  C   Char. string name of the Tech1&2 Retest-Hybrid output file
C INPPEF  C   Char. string name of the Pressure/Purge benefits input file
C INPPEH  C   Char. string name of the Hybrid Pressure/Purge input file
C OUTPPE  C   Char. string name of the Pressure/Purge benefits output file
C OUTPPH  C   Char. string name of the Hybrid Pressure/Purge output file
C RSDD    C   Char. string for name of the input data file
C SCAN    I   Number of times a vehicle must be scanned to be eligible
C              for targetting
C TIMES   I   Times per month the RSD sites scanned valid vehicles.
C UXECE1  R   Effectiveness of RSD, Tech type 1
C UEXCE2  R   Effectiveness of RSD, Tech type 2
C UEXCE4  R   Effectiveness of RSD, Tech type 4+
C VMT     I   Vehicle miles travelled per year, by age
C
C
C Notes:
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C 26-Feb-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 03-Jun-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C Disable clean-screening (Program 5.) temporarily
C 04-Feb-1998 David Brzezinski
C Re-Enable clean screening (Program 5) and change effectiveness array.
C
C
C Declare variables
C
      CHARACTER ACUTS(4)*10, IN1981*40, IN198H*40, INT12*40, INT12H*40
      CHARACTER OUT198*40, OUT19H*40, OUTT12*40, OUTT1H*40, RSDD*40
      CHARACTER INPPEF*40, INPPEH*40, OUTPPE*40, OUTPPH*40
C
      INTEGER ACTION, AGE, CFAIL(25), IAGE, ICUT, IP, ITECH, NUMBER
      INTEGER OPTION, RFAIL(25), SCAN, SENT(25), TIMES, TOTAL(25)
      INTEGER VMT(25)
      INTEGER CSSCEN(6), NEWPHS, NEWRSD
C
      REAL CUTS(4), EFF(3), EOPT3(3,15,3), EXCESS(3,15,3), NVSEEA(25)
      REAL NVSEEB(25), UEXCE1(3), UEXCE2(3)
      REAL UEXCE4(3)
C     REAL UEXCE5(3), UEXCE6(3)
      REAL UEX1(25,3), UEX2(25,3), UEX3(25,3), UEX4(25,3), UEX5(25,3)
      REAL CLEANX(3,4,3,2), CSCRN(25,4), VEPX(25,4,3), ACSCRN(25,4)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
      COMMON /OP2/SENT,TOTAL
      COMMON /OP3/CFAIL,RFAIL,EOPT3
      COMMON /FILES/IN1981,IN198H,INT12,INT12H,OUT198,OUT19H,OUTT12,
     &              OUTT1H, INPPEF, INPPEH, OUTPPE, OUTPPH
      COMMON /PPEFF/ NEWPHS, NEWRSD, CSCRN, CLEANX, VEPX, ACSCRN, CSSCEN
C
C Read in data from the input file, RSDD
C
      CALL DATA2(ACTION,RSDD,*99)
C
C The following is used for echo only:
C Make cutpoint notes
C
C Examine CO cutpoints; if a cutpoint was set to 99.9,
C make a note in ACUTS that processing of its
C associated tech type biennial credits will be skipped.
C
      DO 75 ITECH=1,3
C
        IF (CUTS(ITECH).EQ.99.9) THEN
          ACUTS(ITECH)='ASSUMES NO'
        ELSE
          ACUTS(ITECH)='assumes an'
        END IF
C
 75   CONTINUE
C
      IF ( (OPTION.EQ.1).AND.(ACTION.EQ.5) ) THEN
        PRINT *,'Program type 5 (clean screening) has only been'
        PRINT *,'defined for the case where two observations are'
        PRINT *,'required for each vehicle.'
        TIMES=2
      END IF
C
      IF ( (OPTION.EQ.3).AND.(ACTION.EQ.5) ) THEN
        PRINT *,'The combination of program parameters Option 3. and ',
     & 'Program Type 5. cannot'
        PRINT *,"be modeled.  Please refer to the Users' Guide."
        GO TO 99
      END IF
C
      PRINT *,'Option is ',OPTION
      PRINT *,'Program Type is ',ACTION
C
C Show data file variable values pertaining to option chosen
C
      IF (OPTION.EQ.1) THEN
        WRITE(*,270)NUMBER,SCAN,TIMES,CUTS(1),ACUTS(1),CUTS(2),ACUTS(2),
     &              CUTS(3),ACUTS(3),AGE,EFF(1),EFF(2),EFF(3)
 270    FORMAT(   ' Option #1 input data file information: ',/,
     &              1X,I9,'  Number of vehicles in program ',/,
     &              1X,I9,'  Valid vehicle measurements ',
     &              'per month ',/,
     &              8X,I2,'  Number of times a vehicle ',
     &              'must be scanned ',/,
     &              4X,F6.3,'  CO cutpoint for 1974 and ',
     &              'older model year vehicles; ',/,
     &                          15X,'(',A10,' RSD program ',
     &              'for 1974 and older model year vehicles) ',/,
     &              4X,F6.3,'  CO cutpoint for 1975 through ',
     &              '1980 model year vehicles; ',/,
     &                          15X,'(',A10,' RSD program ',
     &              'for 1975 - 1980 model year vehicles) ',/,
     &              4X,F6.3,'  CO cutpoint for 1981 and ',
     &              'newer model year vehicles; ',/,
     &                          15X,'(',A10,' RSD program ',
     &              'for 1981 and newer model year vehicles) ',/,
     &              8X,I2,'  Age at which a vehicle first ',
     &              'becomes subject to program ',/,
     &              6X,F4.2,'  Effectiveness of Test and Repair ',
     &              'program vs. Test Only, for HC ',/,
     &              6X,F4.2,'  Effectiveness of Test and Repair ',
     &              'program vs. Test Only, for CO ',/,
     &              6X,F4.2,'  Effectiveness of Test and Repair ',
     &              'program vs. Test Only, for NOx')
        WRITE(*,271)(IAGE,VMT(IAGE),IAGE=1,25)
 271    FORMAT(/,' Vehicle miles travelled summary (vehicle age, ',
     &         'vehicle miles/year)',5(/,10(1X,I5)))
        PRINT *,' '
C
C Write out RSD effectivenesses used in Options 1 and 2
C
        IF(ACTION.NE.5) WRITE (*,295)
 295    FORMAT(1X,'RSD Effectivenesses ',
     &            'for CO cutpoints increasing from 0.5% to 7.5%',/,
     &         1X,'HC',T28,'CO',T54,'NOx',/,
     &         1X,'Tech 1  ','Tech 2  ','Tech 4+ ',
     &          '  Tech 1  ','Tech 2  ','Tech 4+ ',
     &          '  Tech 1  ','Tech 2  ','Tech 4+ ')
C
        IF(ACTION.NE.5) THEN
        DO 89 ICUT=1,15
          WRITE (*,290)((EXCESS(ITECH,ICUT,IP),ITECH=1,3),IP=1,3)
 290      FORMAT (3(3(1X,F7.4),2X))
 89     CONTINUE
        ENDIF
C
        PRINT *,' '
      ELSE
C
        IF (OPTION.EQ.2) THEN
          WRITE(*,275)(IAGE,TOTAL(IAGE),SENT(IAGE),IAGE=1,25)
 275      FORMAT(' Option #2 input data file information:',
     &           /,' Vehicle age, number registered, number sent to ',
     &         'RSD IM program',5(/,5(2X,I2,1X,I6,1X,I4)))
          PRINT *,' '
C
C Write out RSD effectivenesses used in Options 1 and 2
C
          IF(ACTION.NE.5) WRITE (*,295)
C295      FORMAT(1X,'RSD Effectivenesses ',
C    &              'for CO cutpoints increasing from 0.5% to 7.5%',/,
C    &           1X,'HC',T28,'CO',T54,'NOx',/,
C    &           1X,'Tech 1  ','Tech 2  ','Tech 4+ ',
C    &            '  Tech 1  ','Tech 2  ','Tech 4+ ',
C    &            '  Tech 1  ','Tech 2  ','Tech 4+ ')
C
          IF(ACTION.NE.5) THEN
          DO 90 ICUT=1,15
            WRITE (*,290)((EXCESS(ITECH,ICUT,IP),ITECH=1,3),IP=1,3)
C290        FORMAT (3(3(1X,F7.4),2X))
 90       CONTINUE
          ENDIF
C
        ELSE
C
C OPTION is 3
C
          WRITE(*,280)(IAGE,CFAIL(IAGE),RFAIL(IAGE),IAGE=1,25)
 280      FORMAT(' Option #3 input data file information:',
     &          /,' Vehicle age, number failing IM now, number ',
     &          'expected to fail next cycle',5(/,5(2X,I2,1X,I6,1X,I4)))
          PRINT *,' '
C
          WRITE (*,296)
 296      FORMAT(1X,'RSD average benefits per failure ',
     &              'for CO cutpoints increasing from 0.5% to 7.5%',/,
     &           1X,'HC',T28,'CO',T54,'NOx',/,
     &           1X,'Tech 1  ','Tech 2  ','Tech 4+ ',
     &            '  Tech 1  ','Tech 2  ','Tech 4+ ',
     &            '  Tech 1  ','Tech 2  ','Tech 4+ ')
C
        DO 91 ICUT=1,15
          WRITE (*,290)((EOPT3(ITECH,ICUT,IP),ITECH=1,3),IP=1,3)
C290      FORMAT (3(3(1X,F7.4),2X))
 91     CONTINUE
        ENDIF
C
      ENDIF
C
C From option variable, choose method of calculating F and E
C
      IF (OPTION.EQ.1) THEN
        CALL R1(UEXCE1,NVSEEA,UEXCE2,NVSEEB,UEXCE4)
      ELSE
C
        IF (OPTION.EQ.2) THEN
          CALL R2(UEXCE1,NVSEEA,UEXCE2,NVSEEB,UEXCE4)
        ELSE
C
C Option is 3
C
          CALL R3(UEXCE1,NVSEEA,UEXCE2,NVSEEB,UEXCE4)
        ENDIF
C
      ENDIF
C
C Choose the IM# and TECH# pair where # corresponds to the action
C variable
C
      IF (ACTION.EQ.1) THEN
        CALL IM1(IN1981,OUT198,NVSEEB,UEXCE4,RSDD)
        CALL TECH1(INT12,OUTT12,NVSEEB,UEXCE1,UEXCE2,RSDD)
      ELSE
C
        IF (ACTION.EQ.2) THEN
          CALL IM2(IN1981,OUT198,NVSEEA,UEXCE4,NVSEEB,RSDD)
          CALL TECH2(INT12,OUTT12,NVSEEA,UEXCE1,NVSEEB,UEXCE2,RSDD)
        ELSE
C
          IF (ACTION.EQ.3) THEN
            CALL IM3(IN1981,IN198H,OUT198,NVSEEA,UEXCE4,NVSEEB,RSDD)
            CALL TECH3(INT12,INT12H,OUTT12,NVSEEA,UEXCE1,NVSEEB,UEXCE2,
     &                 RSDD)
          ELSE
C
            IF (ACTION.EQ.4) THEN
              CALL IM4(IN1981,OUT198,NVSEEA,UEXCE4,RSDD)
              CALL TECH4(INT12,OUTT12,NVSEEA,UEXCE1,UEXCE2,RSDD)
            ELSE
C
C ACTION=5 (Clean Screening)
C
              CALL R5(UEX1,UEX2,UEX3,UEX4,UEX5)
        CALL IM5(IN1981,OUT198,NVSEEA,UEX3,UEX4,UEX5,NVSEEB,RSDD)
              CALL TECH5(INT12,OUTT12,NVSEEA,UEX1,NVSEEB,UEX2,RSDD)
              CALL PP5(INPPEF,OUTPPE,NVSEEA,NVSEEB)
C
        CALL IM5(IN198H,OUT19H,NVSEEA,UEX3,UEX4,UEX5,NVSEEB,RSDD)
              CALL TECH5(INT12H,OUTT1H,NVSEEA,UEX1,NVSEEB,UEX2,RSDD)
              CALL PP5(INPPEH,OUTPPH,NVSEEA,NVSEEB)
            END IF
C
          END IF
C
        END IF
C
      END IF
C
 99   CONTINUE
      RETURN
      END
      PROGRAM RSDDRV
C
C RSDDRV is the driver for INPUT.  It queries the user for the input
C data file, whose default name is RSD.D.  The first two data "cards"
C in the data file provide the Option:
C
C 1. "Commitment to a Level of Effort"  Note that this option assumes
C      that the % of high emitters in the group of vehicles sampled
C      by RSD is the same as that of the whole fleet
C 2. "Commitment to a Specific Fleet Coverage"  Note that this option
C      assumes that the % of high emitters in the group sent via RSD to
C      the special I/M program is the same as that of the whole fleet
C 3. "Commitment to a Number of Failures"  Note that this option assumes
C      that there is a relationship between the emission level of the
C      cars chosen by RSD to go to the special RSD I/M program and the
C      RSD CO cutpoint chosen:  less stringent cutpoints mean worse
C      emitters.  Note:  cannot be used with Program 5.
C
C and the type of action taken on the information from RSD:
C
C 1. The resulting biennial data, when used in MOBILE (for a biennial
C program) (whether Test-and-repair or Test-only) actually models an I/M
C program where vehicles identified as high emitters by RSD participate
C in the annual I/M program, and the remainder participate in the
C biennial program.  The annual data is unchanged.
C
C 2. When the resulting annual data is used by MOBILE for a Test-and-
C repair program*, it actually models a program where vehicles
C identified as high emitters by RSD participate in an annual Test-only
C program and the remainder participate in an annual Test-and-repair
C program.  When the resulting biennial data is used by MOBILE for a
C Test-and-repair program*, it actually models a program where vehicles
C identified as high emitters by RSD participate in an annual Test-only
C program and the remainder participate in a biennial Test-and-repair
C program.
C * Note:  In a Test-and-repair program, mechanic training credits must
C   be properly set to their Test-and-repair values in MOBILE.  The only
C   way to do this is to explicitly run the Test-and-repair option in
C   MOBILE.  However, the IM credits get cut in half by MOBILE under
C   this option.  Therefore, in routines IM2 and TECH2, the last step in
C   calculating the new annual and biennial credits is to multiply them
C   each by two, so that they have the proper values when cut in half in
C   MOBILE.  See this note in IM2 and TECH2.
C
C 3. When the resulting annual data is used by MOBILE for a Test-only
C program, it actually models a program where vehicles identified as
C high emitters by RSD participate in an annual Test-only program and
C the remainder participate in an annual Retest-hybrid program.
C When the resulting biennial data is used by MOBILE for a Test-only
C program, it actually models a program where vehicles identified as
C high emitters by RSD participate in an annual Test-only program and
C the remainder participate in a biennial Retest-hybrid program.
C
C 4.  When the resulting annual data is used by MOBILE for a Test-only
C or a Test-and-repair program*, it actually models a program where
C vehicles identified as high emitters by RSD participate in the
C respective programs, but the remainder participate in no program.
C See * Note above.
C
C 5.  When the resulting annual or biennial data is used by MOBILE for a
C Test-only or a Test-and-repair program, it actually models a program
C where vehicles identified by RSD as non-high emitters are exempted
C from to participate in the IM program.  The remainder must go through
C the program.  Note:  cannot be used with Option 3.
C
C Calls subroutine INPUT
C
C Input: 
C by user:  RSDD
C data file(s):  none used
C 
C Output:
C no output
C data file(s):  none used
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C RSDD    C*40 Filename of the input data file
C
C
C Notes:
C 30-June-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C 23-Apr-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C
C Declare variables
C
      CHARACTER DEFALL*40, RSDD*40
C
C Identify code
C
      WRITE(UNIT=*,FMT=200)
 200  FORMAT(/,  ' Remote Sensing Device (RSD) DRAFT I/M ',
     &            'Credit Utility, February 27, 1998',/,
     &           ' --------------------------------------',
     &            '-----------------------------')
C
C Ask for input filename
C
      WRITE(UNIT=*,FMT=245)
 245  FORMAT(/, ' To select the default value for the ',
     &            'input below, press ENTER with no input:')
C
      WRITE(UNIT=*,FMT=246)
 246  FORMAT(/,  ' Enter the name of the RSD input data file: ',/,
     &           ' (default RSD.D) ')
      READ(UNIT=*,FMT=150)DEFALL
 150  FORMAT(A40)
      READ(UNIT=DEFALL,FMT=*,END=46,ERR=46)RSDD
      GOTO 47
 46   CONTINUE
      RSDD='RSD.D'
 47   CONTINUE
C
      CALL INPUT(RSDD)
C
      STOP
      END
      SUBROUTINE R1(UEXCE1,NVSEEA,UEXCE2,NVSEEB,UEXCE4)
C
C Subroutine R1 calculates the proper values of F (fraction of
C vehicles seen by RSD, NVSEEA and NVSEEB) and E (fraction of those
C vehicles that are sent on to the special IM program for RSD targetted
C emitters--also referred to as excess emissions identified, UEXCE1,
C UEXCE2, and UEXCE4) for option 1
C
C Subroutine calls:  FSEEN2
C
C Input: 
C by user:  none
C common blocks:  OP1
C data file(s): none
C subroutine arguments: none
C 
C Output:
C by screen:  none
C common blocks:  none
C data file(s):  none
C subroutine arguments:  UEXCE1, NVSEEA, UEXCE2, NVSEEB, UEXCE4
C
C Array subscripts:
C
C CUTS(4)        - CUTS(ITECH)
C EFF(3)         - EFF(IP)
C EXCESS(3,15,3) - EXCESS(Tech type,ICUT,IP)
C NVSEEA(24)     - NVSEEA(benefit year)
C NVSEEB(24)     - NVSEEB(benefit year)
C UEXCE1(3)      - UEXCE1(IP)
C UEXCE2(3)      - UEXCE2(IP)
C UEXCE4(3)      - UEXCE4(IP)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C AGE     I   Age at which a veh. first becomes subject to RSD program
C CUTS    R   Array of RSD CO test cutpoints for vehicle groups 
C              pre-1975, 1975-1980, and post-1980, Clean Screen NOx Cutpoint
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C EXCESS  R   Sacramento Study data for HC, CO, and NOx fractions of IM
C              excess identified for a particular cutpoint of CO for a
C              particular Tech type:  EXCESS( Tech type, ICUT,IP) if
C              default from DATA2--otherwise, this is user provided
C              information
C ICUT    I   Counter for cutpoint array index (ICUT=1, 2, ... , 8
C              corresponds to 0.5%, 1.0%, ... , 4.0% CO test cutpoints) 
C IP      I   Counter for pollutants
C NUMBER  I   Total number of vehicles subject to the inspection program
C NVSEEA  R   Fractions of vehicles seen by RSD in an annual program by
C              year; found in subroutine FSEEN
C NVSEEB  R   Fractions of vehicles seen by RSD in a biennial program by
C              year; found in subroutine FSEEN
C OPTION  I   Option--see RSDDRV
C RCUT    R   Real value of counter for cutpoint array index
C SCAN    I   Number of times a vehicle must be scanned to be eligible
C              for targetting
C TIMES   I   Times per month the RSD sites scanned valid vehicles.
C UEXCE1  R   HC, CO, and NOx fractions of IM excess identified by RSD,
C              calculated from EXCESS using user-supplied RSD CO test
C              cutpoints; used by TECH12 to modify pre-1975 data 
C UEXCE2  R   Like UEXCE1, but used by TECH12 to modify 1975-1980 data
C UEXCE4  R   Like UEXCE1, but used by IMDATA to modify post-1980 data
C
C
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 20-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C
C Declare variables
C
      INTEGER AGE, ICUT, IP, NUMBER, OPTION, SCAN, TIMES, VMT(25)
C
      REAL CUTS(4), EFF(3), EXCESS(3,15,3), NVSEEA(24), NVSEEB(24), RCUT
      REAL UEXCE1(3), UEXCE2(3), UEXCE4(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
C
C EXCESS is set up in the following way:
C
C Fortran first fastest convention for indices:  EXCESS(1,1,1), (2,1,1),
C (3,1,1), (1,2,1), ... , i.e., (Tech 1, 0.5%, HC), (Tech 2, 0.5%, HC),
C (Tech 4, 0.5%, HC), (Tech 1, 1.0%, HC), ...
C
C Set up excess emissions identified arrays
C
C Set up proper cutpoint data by interpolating the discrete values
C in array EXCESS(tech type, cutpoint, pollutant).  First evaluate
C pre-1975 (Tech 1) data,
C
      DO 81 IP=1,3
C
C If CUTS(1) = 99.9, fill the UEXCE1 array with 0. in order to
C indicate processing is to be skipped for pr-1975 (Tech 1) data
C
        IF (CUTS(1).EQ.99.9) THEN
          UEXCE1(IP)=0.
          GO TO 81
        END IF
C
C First, calculate the two cutpoint array indices corresponding to the
C data points in the array nearest to the given cutpoint:
C 0.5 <=> 1, 1.0 <=> 2, ... , 4.0 <=> 8, ... , 7.5 <=> 15
C
        ICUT=INT(CUTS(1)*2)
        RCUT=FLOAT(ICUT)
C
C If ICUT=15, avoid sending the array out of bounds:
C
        IF (ICUT.EQ.15) THEN
          UEXCE1(IP)=EXCESS(1,ICUT,IP)
          GO TO 81
        END IF
C
C ICUT is not 15, so interpolate:
C
        UEXCE1(IP)=EXCESS(1,ICUT,IP)+
     &             ( EXCESS(1,ICUT+1,IP) - EXCESS(1,ICUT,IP) )*
     &             ( CUTS(1) - RCUT/2 )/0.5
C
 81   CONTINUE
C
C ... then evaluate Tech 2 data,
C
      DO 82 IP=1,3
C
C If CUTS(2) = 99.9, fill the UEXCE2 array with 0. in order to
C indicate processing is to be skipped for 1975-1980 (Tech 2) data
C
        IF (CUTS(2).EQ.99.9) THEN
          UEXCE2(IP)=0.
          GO TO 82
        END IF
C
        ICUT=INT(CUTS(2)*2)
        RCUT=FLOAT(ICUT)
C
        IF (ICUT.EQ.15) THEN
          UEXCE2(IP)=EXCESS(2,ICUT,IP)
          GO TO 82
        END IF
C
        UEXCE2(IP)=EXCESS(2,ICUT,IP)+
     &             ( EXCESS(2,ICUT+1,IP) - EXCESS(2,ICUT,IP) )*
     &             ( CUTS(2) - RCUT/2 )/0.5
C
 82   CONTINUE
C
C ... and then evaluate post-1980 data.
C
      DO 84 IP=1,3
C
C If CUTS(3) = 99.9, fill the UEXCE2 array with 0. in order to
C indicate processing is to be skipped for post-1980 (Tech 4+) data
C
        IF (CUTS(3).EQ.99.9) THEN
          UEXCE4(IP)=0.
          GO TO 84
        END IF
C
        ICUT=INT(CUTS(3)*2)
        RCUT=FLOAT(ICUT)
C
        IF (ICUT.EQ.15) THEN
          UEXCE4(IP)=EXCESS(3,ICUT,IP)
          GO TO 84
        END IF
C
        UEXCE4(IP)=EXCESS(3,ICUT,IP)+
     &             ( EXCESS(3,ICUT+1,IP) - EXCESS(3,ICUT,IP) )*
     &             ( CUTS(3) - RCUT/2 )/0.5
C
 84   CONTINUE
C
C Set up fraction of newest vehicles seen
C
      CALL FSEEN2(NVSEEA,NVSEEB)
C
      RETURN
      END
      SUBROUTINE TECH1(INT12,OUTT12,NVSEEB,UEXCE1,UEXCE2,RSDD)
C
C TECH1
C
C Calculates new sets of IM credits for
C IM programs using Remote Sensing Devices (RSD)
C from the existing 1974 and older model years and 1975 through
C 1980 model years vehicles credits
C
C Called by INPUT
C
C Calls no subroutines
C
C Input:
C by user:  none
C common block(s):  OP1
C data file(s):  file whose name is passed in INT12 
C subroutine arguments:  INT12, OUTT12, NVSEEB, UEXCE1, UEXCE2, RSDD
C
C Output:
C by screen:  none
C common block(s):  none
C data file(s):  file whose name is passed in OUTT12
C subroutine arguments:  none
C
C Array subscripts:
C
C CR12CO(19,20,5,2) - CR12CO(IBY,IAGE1,ISTR,ITECH)
C CR12HC(19,20,5,2) - CR12HC(IBY,IAGE1,ISTR,ITECH)
C CUTS(4)           - CUTS(ITECH)
C EFF(3)            - EFF(IP)
C EXCESS(3,15,3)    - EXCESS(ITECH,cutpoint,pollutant)
C NVSEEB(25)        - NVSEEB(age of vehicle)
C UEXCE1(3)         - UEXCE1(pollutant:  1=HC, 2=CO, & 3=NOx)
C UEXCE2(3)         - UEXCE2(pollutant:  1=HC, 2=CO, & 3=NOx)
C VMT(25)           - VMT(IBY)
C
C  Local variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C AGE     I   Age at which a veh. first becomes subject to RSD program
C ANNUAL  R   temporary Annual credit
C BIENNL  R   temporary Biennial credit
C CR12CO  R   Array of 1974 and older model years (Tech 1) vehicles and
C              1975 through 1980 model years (Tech 2) vehicles CO IM
C              credits
C CR12HC  R   Array of 1974 and older model years (Tech 1) vehicles and 
C              1975 through 1980 model years (Tech 2) vehicles HC IM
C              credits
C CUTCO   R   Smart line original CO cutpoint
C CUTHC   R   Smart line original HC cutpoint
C CUTNO   R   Smart line original NO cutpoint
C CUTS    R   Array of RSD CO cutpoints by Tech type:  1, 2, and 4+
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5 (not used here)
C ETCFLG  I   An extra flag in IMDATA.FOR, in TECH12.FOR
C EXCESS  R   See routines R1 and R2
C HYBFLG  I   Hybrid program flag
C IAGE    I   Counter for age when first inspected 
C IBY     I   Counter for Benefit Years
C ILINE   I   Counter for Smart lines
C IMFLG   I   I/M flag:  1 if no RSD program modifications done on
C              TECH12.D; 2 if data was changed
C INT12   C   Character string name of the TECH12.D type input file
C ISMART  I   Counter for Smart strip
C ISTR    I   Counter for Stringency
C ITECH   I   Counter for Tech type
C NUMBER  I   Total number of veh. subject to inspection program
C NVSEEB  R   Array of fractions of vehicles seen by RSD by age,
C              biennial I/M program
C OLDFLG  I   If old data, OLDFLG=1, if new, 0.
C OPTION  I   Option--see RSDDRV
C OUTT12  C   Character string name of the TECDATA.D type output file
C RSDD    C   Char. string name of input data file
C SCAN    I   Number of valid veh. measurements per month at RSD sites
C SMART   I   Array of the Smart strip values
C THREE   C   Character string name for the flags HYBFLG, IMFLG, and
C              ETCFLG if they exist, otherwise it contains part of the
C              comment line
C TIMES   I  Minimum number of times a vehicle must be scanned between
C              inspections to be eligible for targetting.
C UEXCE1  R  Array of RSD effectiveness fractions for Tech 1 vehicles
C UEXCE2  R  Array of RSD effectiveness fractions for Tech 2 vehicles
C VMT     I  Vehicle miles travelled by age
C
C
C Notes:  Annual and biennial information is stored in an upper and
C         lower triangular fashion.
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 22-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C
      CHARACTER INT12*40, OUTT12*40, RSDD*40, THREE*3
C
      INTEGER AGE, ETCFLG, HYBFLG, IAGE, IBY, IMFLG, ISMART, ISTR, ITECH
      INTEGER NUMBER, OLDFLG, OPTION, SCAN, SMART(4), TIMES, VMT(25)
C
      REAL ANNUAL, BIENNL, CR12CO(19,20,5,2), CR12HC(19,20,5,2)
      REAL CUTCO, CUTHC, CUTNO, CUTS(4), EFF(3), EXCESS(3,15,3)
      REAL NVSEEB(25), UEXCE1(3), UEXCE2(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
C
C If old data, OLDFLG is set to 1; first initialize OLDFLG to 0
C
      OLDFLG=0
C
      WRITE(*,200)
 200  FORMAT(/,  ' Starting to alter 1974 and older model ',
     &            'years and 1975 through 1980 model years ',/,
     &           ' vehicles I/M credits to include Remote ',
     &            'Sensing Devices credits ',/,
     &           ' ---------------------------------------',
     &            '---------------------------------------')
C
C Open filename in INT12 for input as unit 12
C Open filename in OUTT12 for output as unit 13
C
      OPEN(12,FILE=INT12, ERR=300,STATUS='OLD')
      OPEN(13,FILE=OUTT12,ERR=310)
C
 90   CONTINUE
C
C Reading a Smart line
C
      READ(12,100,END=97,ERR=320) (SMART(ISMART),ISMART=1,4),
     &     CUTHC,CUTCO,CUTNO,THREE
  100 FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,A3)
C
      READ(THREE,105,ERR=15) HYBFLG,IMFLG,ETCFLG
  105 FORMAT(3I1)
C
      GO TO 16
C
 15   CONTINUE
C
C When there is a misread of the flags, the data is of the old type;
C set OLDFLG to 1 and skip the check on IMFLG
C
      OLDFLG=1
      GO TO 17
C
 16   CONTINUE
C
C If IMFLG is not one, this means that Tech 1 or Tech 2 data has been
C changed using RSD effects.  Issue error and halt.
C
      IF ( (IMFLG.NE.1).AND.(IMFLG.NE.0) ) THEN
        GO TO 325
      END IF
C
 17   CONTINUE
C
C Read in Annual and Biennial credits for HC
C Loop for the two (2) ITECHs stored in the record.
C
CC      PRINT *,'Reading old credits'
C
      DO 10 ITECH=1,2
C
C Loop for the five (5) stringency values in the record.
C
        DO 12 ISTR=1,5
C
C Loop for the values in the record
C
          DO 14 IAGE1=1,20

            READ(12,110,END=330,ERR=335)
     & (CR12HC(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
  110       FORMAT(19F4.3)
  14      CONTINUE
C
  12    CONTINUE

  10  CONTINUE
C
C Read in Annual and Biennial credits for CO
C
      DO 20 ITECH=1,2
C
        DO 22 ISTR=1,5
C
          DO 24 IAGE1=1,20
            READ(12,110,END=340,ERR=345)
     & (CR12CO(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
 24       CONTINUE
C
 22     CONTINUE

 20   CONTINUE
C
C Process the data and then write it to file TECDATA.D.
C
      DO 30 ITECH=1,2
C
        DO 32 ISTR=1,5
C
          DO 34 IBY=1,19
C
            DO 36 IAGE=1,19
C
C Only let the benefit year counter IBY and the age at first
C inspection counter be in the upper triangular region of Annual
C data.  (Another way of looking at this is that the actual age of a
C vehicle is its age at first inspection plus the time elapsed since its
C first inspection--current benefit year minus first benefit year.
C The actual age is thus IAGE+IBY-1.  Since actual age cannot exceed 
C 19 years, IAGE+IBY-1 must be .LE. 19.)
C
              IF ((IBY+IAGE).GT.20) THEN
                GO TO 34
              END IF
C
C HC credits
C
              ANNUAL=CR12HC(IBY,IAGE,ISTR,ITECH)
              BIENNL=CR12HC(20-IBY,21-IAGE,ISTR,ITECH)
C
              IF (ITECH.EQ.1) THEN
C
                CR12HC(20-IBY,21-IAGE,ISTR,ITECH)=BIENNL+
     & (ANNUAL-BIENNL)*NVSEEB(IAGE+IBY-1)*UEXCE1(1)
C
              ELSE
C
C ITECH is 2
C
                CR12HC(20-IBY,21-IAGE,ISTR,ITECH)=BIENNL+
     & (ANNUAL-BIENNL)*NVSEEB(IAGE+IBY-1)*UEXCE2(1)
C
              END IF
C
C Note that NVSEEB is a function of the actual age of the vehicle.
C See above.
C
C CO credits
C
              ANNUAL=CR12CO(IBY,IAGE,ISTR,ITECH)
              BIENNL=CR12CO(20-IBY,21-IAGE,ISTR,ITECH)
C
              IF (ITECH.EQ.1) THEN
C
                CR12CO(20-IBY,21-IAGE,ISTR,ITECH)=BIENNL+
     & (ANNUAL-BIENNL)*NVSEEB(IAGE+IBY-1)*UEXCE1(2)
C
              ELSE
C
C ITECH is 2
C
                CR12CO(20-IBY,21-IAGE,ISTR,ITECH)=BIENNL+
     & (ANNUAL-BIENNL)*NVSEEB(IAGE+IBY-1)*UEXCE2(2)
C
              END IF
C
 36         CONTINUE
C
 34       CONTINUE
C
 32     CONTINUE
C
 30   CONTINUE
C
C Echoing Smart line and associated annual credits and writing new
C biennial credits to output file
C
CC      PRINT *,'Writing new credits'
C
C If OLDFLG is not 1, then the data is of the new type; output the
C following
C
      IF (OLDFLG.NE.1) THEN
        WRITE(13,240,ERR=350)(SMART(ISMART),ISMART=1,4),CUTHC,CUTCO,
     & CUTNO,HYBFLG,ETCFLG,OPTION,RSDD
  240   FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,I1,'2',I1,' New ',
     &         'credits, Option = ',I1,', Program type = 1, ',
     &         'input data file ',A40)
      ELSE
C
C Data is of the old type 
C
        WRITE(13,245,ERR=350)(SMART(ISMART),ISMART=1,4),CUTHC,CUTCO,
     & CUTNO,OPTION,RSDD
  245   FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,' 2 ',' New ',
     &         'credits, Option = ',I1,', Program type = 1, ',
     &         'input data file ',A40)
      ENDIF
C
C Write the HC data
C
      DO 40 ITECH=1,2
C
        DO 42 ISTR=1,5
C
          DO 44 IAGE1=1,20
            WRITE(13,250,ERR=350)
     & (CR12HC(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
  250       FORMAT(19F4.3)
  44      CONTINUE
C
  42    CONTINUE

  40  CONTINUE
C
C Write the CO data
C
      DO 50 ITECH=1,2
C
        DO 52 ISTR=1,5
C
          DO 54 IAGE1=1,20
            WRITE(13,250,ERR=350)
     & (CR12CO(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
 54       CONTINUE
C
 52     CONTINUE

 50   CONTINUE
C
C Go back to the beginning to read next Smart line and associated data
C
      GO TO 90
C
C ---------------------------
C CONSOLIDATED ERROR MESSAGES
C ---------------------------
C
 300  CONTINUE
      WRITE(*,301)INT12       
 301  FORMAT(/,  ' ERROR OPENING INPUT FILE ',A40)
      GO TO 96
C
 310  CONTINUE
      WRITE(*,311)OUTT12       
 311  FORMAT(/,  ' ERROR OPENING OUTPUT FILE ',A40)
      GO TO 96
C
 320  CONTINUE
      WRITE(*,321)INT12       
 321  FORMAT(/,  ' ERROR READING SMART LINE FROM INPUT ',
     &            'FILE ',A40)
      GO TO 96
C
 325  CONTINUE
      WRITE(*,326)       
 326  FORMAT(/,  ' ERROR CANNOT APPLY RSD EFFECTS -- ',
     &            'DATA HAVE ALREADY BEEN CHANGED ')
      GO TO 96
C
 330  CONTINUE
      WRITE(*,331)INT12       
 331  FORMAT(/,  ' WHILE READING HC CREDITS, UNEXPECTEDLY ',
     &            'REACHED END OF INPUT FILE ',/,
     &           ' ',A40)
      GO TO 96
C
 335  CONTINUE
      WRITE(*,336)INT12       
 336  FORMAT(/,  ' ERROR READING HC CREDITS FROM INPUT ',
     &            'FILE ',A40)
      GO TO 96
C
 340  CONTINUE
      WRITE(*,341)INT12       
 341  FORMAT(/,  ' WHILE READING CO CREDITS, UNEXPECTEDLY ',
     &            'REACHED END OF INPUT FILE ',/,
     &           ' ',A40)
      GO TO 96
C
 345  CONTINUE
      WRITE(*,346)INT12       
 346  FORMAT(/,  ' ERROR READING CO CREDITS FROM INPUT ',
     &            'FILE ',A40)
      GO TO 96
C
 350  CONTINUE
      WRITE(*,351)OUTT12       
 351  FORMAT(/,  ' ERROR WRITING TO OUTPUT FILE ',A40)
      GO TO 96
C
C ---------------------------------
C CLOSE DATA FILES AND EXIT PROGRAM
C ---------------------------------
C
 96   CONTINUE
      WRITE(*,355)       
 355  FORMAT(/,  ' CONVERSION ENDED ABNORMALLY ')
      GO TO 98
C
 97   CONTINUE
      WRITE(*,255)       
 255  FORMAT(/,  ' Conversion ended normally ')
C
 98   CONTINUE
C
      CLOSE (13)
      CLOSE (12)
C
      RETURN
      END
      SUBROUTINE TECH2(INT12,OUTT12,NVSEEA,UEXCE1,NVSEEB,UEXCE2,RSDD)
C
C TECH2
C
C Calculates new sets of IM credits for
C IM programs using Remote Sensing Devices (RSD)
C from the existing Tech 1 & 2 credits
C
C Called by INPUT
C
C Calls subroutine CHRB
C
C Input:
C by user:  none
C common block(s):  OP1
C data file(s):  file whose name is passed in INT12 
C subroutine arguments:  INT12, OUTT12, NVSEEA, UEXCE1, NVSEEB, UEXCE2,
C                        RSDD
C
C Output:
C by screen:  none
C common block(s):  none
C data file(s):  file whose name is passed in OUTT12
C subroutine arguments:  none
C
C Array subscripts:
C
C CA12CO(19,20,5,2) - CA12CO(IBY,IAGE1,ISTR,ITECH)
C CR12CO(19,20,5,2) - CR12CO(IBY,IAGE1,ISTR,ITECH)
C CA12HC(19,20,5,2) - CA12HC(IBY,IAGE1,ISTR,ITECH)
C CR12HC(19,20,5,2) - CR12HC(IBY,IAGE1,ISTR,ITECH)
C CUTS(4)           - CUTS(ITECH)
C EFF(3)            - EFF(pollutant)
C EXCESS(3,15,3)    - EXCESS(ITECH,cutpoint,pollutant)
C NVSEEA(25)        - NVSEEA(age of vehicle)
C NVSEEB(25)        - NVSEEB(age of vehicle)
C UEXCE1(3)         - UEXCE1(pollutant:  1=HC, 2=CO, & 3=NOx)
C UEXCE2(3)         - UEXCE2(pollutant:  1=HC, 2=CO, & 3=NOx)
C VMT(25)           - VMT(IBY)
C
C  Local variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C AGE     I   Age at which a veh. first becomes subject to RSD program
C ANNUAL  R   temporary Annual credit
C BIENNL  R   temporary Biennial credit
C CA12CO  C   Array of Tech 1 & 2 CO IM credits, in character strings
C CR12CO  R   Array of Tech 1 & 2 CO IM credits
C CA12HC  C   Array of Tech 1 & 2 HC IM credits, in character strings
C CR12HC  R   Array of Tech 1 & 2 HC IM credits
C CUTCO   R   Smart line original CO cutpoint
C CUTHC   R   Smart line original HC cutpoint
C CUTNO   R   Smart line original NO cutpoint
C CUTS    R   Array of RSD CO cutpoints by Tech type, 1, 2, and 4+
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C ETCFLG  I   An extra flag in IMDATA.FOR, in TECH12.FOR, it serves as the
C              IMLFG (see below) for Tech 2 data
C EXCESS  R   See routines R1 and R2
C HYBFLG  I   Hybrid program flag
C IAGE    I   Counter for age when first inspected 
C IBY     I   Counter for Benefit Years
C ILINE   I   Counter for Smart lines
C IMFLG   I   Tech 1 I/M flag:  1 if no RSD program modifications done on
C              Tech 1 part of TECH12.D; 2 if Tech 1 data was changed
C INT12   C   Character string name of the TECH12.D type input file
C ISMART  I   Counter for Smart strip
C ISTR    I   Counter for Stringency
C ITECH   I   Counter for Tech type
C NUMBER  I   Total number of veh. subject to inspection program
C NVSEEA  R   Fraction of vehicles seen by RSD, annual programs
C NVSEEB  R   Fraction of vehicles seen by RSD, biennial programs
C OLDFLG  I   If old data, OLDFLG=1, if new, 0.
C OPTION  I   Option--see RSDDRV
C OUTT12  C   Character string name of the TECDATA.D type output file
C RSDD    C   Char. string name of input data file
C SCAN    I   Number of valid veh. measurements per month at RSD sites
C SMART   I   Array of the Smart strip values
C THREE   C   Character string name for the flags HYBFLG, IMFLG, and
C              ETCFLG if they exist, otherwise it contains part of the
C              comment line
C TIMES   I   Minimum number of times a vehicle must be scanned between
C              inspections to be eligible for targetting.
C UEXCE1  R   RSD effectiveness, Tech 1 vehicles
C UEXCE2  R   RSD effectiveness, Tech 2 vehicles
C VMT     I   Vehicle miles travelled by age
C
C Notes:  Annual and biennial information is stored in an upper and
C         lower triangular fashion.
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 22-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
      CHARACTER CA12CO(19,20,5,2)*4, CA12HC(19,20,5,2)*4
      CHARACTER INT12*40, OUTT12*40, RSDD*40, THREE*3
C
      INTEGER AGE, ETCFLG, HYBFLG, IAGE, IBY, IMFLG, ISMART, ISTR
      INTEGER ITECH, NUMBER, OLDFLG, OPTION, SCAN, SMART(4), TIMES
      INTEGER VMT(25)
C
      REAL ANNUAL, BIENNL, CR12CO(19,20,5,2), CR12HC(19,20,5,2)
      REAL CUTCO, CUTHC, CUTNO, CUTS(4), EFF(3), EXCESS(3,15,3)
      REAL NVSEEA(25), NVSEEB(25), UEXCE1(3), UEXCE2(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
C
C If old data, OLDFLG is set to 1; first initialize OLDFLG to 0
C
      OLDFLG=0
C
      WRITE(*,200)
 200  FORMAT(/,  ' Starting to alter 1974 and older model ',
     &            'years and 1975 through 1980 model years ',/,
     &           ' vehicles I/M credits to include Remote ',
     &            'Sensing Devices credits',/,
     &           ' ---------------------------------------',
     &            '---------------------------------------')
C
C Open filename in INT12 for input as unit 12
C Open filename in OUTT12 for output as unit 13
C
      OPEN(12,FILE=INT12, ERR=300,STATUS='OLD')
      OPEN(13,FILE=OUTT12,ERR=310)
C
 90   CONTINUE
C
      READ(12,100,END=97,ERR=320) (SMART(ISMART),ISMART=1,4),
     &     CUTHC,CUTCO,CUTNO,THREE
  100 FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,A3)
C
      READ(THREE,105,ERR=15) HYBFLG,IMFLG,ETCFLG
  105 FORMAT(3I1)
C
      GO TO 16
C
 15   CONTINUE
C
C When there is a misread of the flags, the data is of the old type;
C set OLDFLG to 1 and skip the check on IMFLG
C
      OLDFLG=1
      GO TO 17
C
 16   CONTINUE
C
C Reading a Smart line and associated data from input file
C
C If IMFLG is not one, this means that Tech 1 or Tech 2 data has been
C changed using RSD effects.  Issue error and halt.
C
      IF ( (IMFLG.NE.1).AND.(IMFLG.NE.0) ) THEN
        GO TO 325
      END IF
C
 17   CONTINUE
C
C Read in Annual and Biennial credits for HC
C Loop for the two (2) ITECHs stored in the record.
C
      DO 10 ITECH=1,2
C
C Loop for the five (5) stringency values in the record.
C
        DO 12 ISTR=1,5
C
C Loop for the values in the record
C
          DO 14 IAGE1=1,20

            READ(12,110,END=330,ERR=335)
     & (CR12HC(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
  110       FORMAT(19F4.3)
  14      CONTINUE
C
  12    CONTINUE

  10  CONTINUE
C
C Read in Annual and Biennial credits for CO
C
      DO 20 ITECH=1,2
C
        DO 22 ISTR=1,5
C
          DO 24 IAGE1=1,20
            READ(12,110,END=340,ERR=345)
     & (CR12CO(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
 24       CONTINUE
C
 22     CONTINUE

 20   CONTINUE
C
C Process the data and then write it to output file
C
      DO 30 ITECH=1,2
C
        DO 32 ISTR=1,5
C
          DO 34 IBY=1,19
C
            DO 36 IAGE=1,19
C
C Only let the benefit year counter IBY and the age at first
C inspection counter be in the upper triangular region of Annual
C data.  (Another way of looking at this is that the actual age of a
C vehicle is its age at first inspection plus the time elapsed since its
C first inspection--current benefit year minus first benefit year.
C The actual age is thus IAGE+IBY-1.  Since actual age cannot exceed 
C 19 years, IAGE+IBY-1 must be .LE. 19.)
C 
              IF ((IBY+IAGE).GT.20) THEN
                GO TO 34
              END IF
C
C HC credits
C
              ANNUAL=CR12HC(IBY,IAGE,ISTR,ITECH)
              BIENNL=CR12HC(20-IBY,21-IAGE,ISTR,ITECH)
C
              IF (ITECH.EQ.1) THEN
C
                CR12HC(IBY,IAGE,ISTR,ITECH) = (
     & ANNUAL * NVSEEA(IAGE+IBY-1) * UEXCE1(1) +
     & ANNUAL * EFF(1) * ( 1.0 - NVSEEA(IAGE+IBY-1) * UEXCE1(1) )
     & ) / EFF(1)
C
C Note:  new annual credit = Test-only annual credit * F * E +
C Test-and-repair annual credit * (1-F*E).  Test-and-repair
C credit is EFF(1) of Test-only credit, and the data from
C the input file is Test-only credit.
C
C***Note:  In a Test-and-repair program, mechanic training credits must
C   be properly set to their Test-and-repair values in MOBILE.  The only
C   way to do this is to explicitly run the Test-and-repair option in
C   MOBIL.  However, the HC IM credits get reduced by EFF(1) in MOBILE
C   under this option.  Therefore, in routines IM2 and TECH2, the last
C   step in calculating the new annual and biennial HC credits is to
C   divide them each by EFF(1), so that they have the proper values
C   when reduced in MOBILE.
C
                CR12HC(20-IBY,21-IAGE,ISTR,ITECH) = (
     & ANNUAL * NVSEEB(IAGE+IBY-1) * UEXCE1(1) +
     & BIENNL * EFF(1) * ( 1.0 - NVSEEB(IAGE+IBY-1) * UEXCE1(1) )
     & ) / EFF(1)
C
C Note:  new biennial credit = Test-only annual credit * F * E +
C Test-and-repair biennial credit * (1-F*E).  Test-and-repair
C credit is EFF(1) of Test-only credit.
C
C Convert to character string data.
C
                CALL CHRB( CR12HC(IBY,IAGE,ISTR,ITECH),
     & CA12HC(IBY,IAGE,ISTR,ITECH) )
                CALL CHRB( CR12HC(20-IBY,21-IAGE,ISTR,ITECH),
     & CA12HC(20-IBY,21-IAGE,ISTR,ITECH) )
C
              ELSE
C
C ITECH is 2
C
                CR12HC(IBY,IAGE,ISTR,ITECH) = (
     & ANNUAL * NVSEEA(IAGE+IBY-1) * UEXCE2(1) +
     & ANNUAL * EFF(1) * ( 1.0 - NVSEEA(IAGE+IBY-1) * UEXCE2(1) )
     & ) / EFF(1)
C
                CR12HC(20-IBY,21-IAGE,ISTR,ITECH) = (
     & ANNUAL * NVSEEB(IAGE+IBY-1) * UEXCE2(1) +
     & BIENNL * EFF(1) * ( 1.0 - NVSEEB(IAGE+IBY-1) * UEXCE2(1) )
     & ) / EFF(1)
C
C Convert to character string data.
C
                CALL CHRB( CR12HC(IBY,IAGE,ISTR,ITECH),
     & CA12HC(IBY,IAGE,ISTR,ITECH) )
                CALL CHRB( CR12HC(20-IBY,21-IAGE,ISTR,ITECH),
     & CA12HC(20-IBY,21-IAGE,ISTR,ITECH) )
C
              END IF
C
C Note that NVSEEA and NVSEEB are functions of the actual age of
C the vehicle.  See above.
C
C CO credits
C
              ANNUAL=CR12CO(IBY,IAGE,ISTR,ITECH)
              BIENNL=CR12CO(20-IBY,21-IAGE,ISTR,ITECH)
C
              IF (ITECH.EQ.1) THEN
C
                CR12CO(IBY,IAGE,ISTR,ITECH) = (
     & ANNUAL * NVSEEA(IAGE+IBY-1) * UEXCE1(2) +
     & ANNUAL * EFF(2) * ( 1.0 - NVSEEA(IAGE+IBY-1) * UEXCE1(2) )
     & ) / EFF(2)
C
                CR12CO(20-IBY,21-IAGE,ISTR,ITECH) = (
     & ANNUAL * NVSEEB(IAGE+IBY-1) * UEXCE1(2) +
     & BIENNL * EFF(2) * ( 1.0 - NVSEEB(IAGE+IBY-1) * UEXCE1(2) )
     & ) / EFF(2)
C
C Convert to character string data.
C
                CALL CHRB( CR12CO(IBY,IAGE,ISTR,ITECH),
     & CA12CO(IBY,IAGE,ISTR,ITECH) )
                CALL CHRB( CR12CO(20-IBY,21-IAGE,ISTR,ITECH),
     & CA12CO(20-IBY,21-IAGE,ISTR,ITECH) )
C
              ELSE
C
C ITECH is 2
C
                CR12CO(IBY,IAGE,ISTR,ITECH) = (
     & ANNUAL * NVSEEA(IAGE+IBY-1) * UEXCE2(2) +
     & ANNUAL * EFF(2) * ( 1.0 - NVSEEA(IAGE+IBY-1) * UEXCE2(2) )
     & ) / EFF(2)
C
C***Note:  (see***Note above, substitute CO for HC)
C
                CR12CO(20-IBY,21-IAGE,ISTR,ITECH) = (
     & ANNUAL * NVSEEB(IAGE+IBY-1) * UEXCE2(2) +
     & BIENNL * EFF(2) * ( 1.0 - NVSEEB(IAGE+IBY-1) * UEXCE2(2) )
     & ) / EFF(2)
C
C Convert to character string data.
C
                CALL CHRB( CR12CO(IBY,IAGE,ISTR,ITECH),
     & CA12CO(IBY,IAGE,ISTR,ITECH) )
                CALL CHRB( CR12CO(20-IBY,21-IAGE,ISTR,ITECH),
     & CA12CO(20-IBY,21-IAGE,ISTR,ITECH) )
C
              END IF
C
 36         CONTINUE
C
 34       CONTINUE
C
 32     CONTINUE
C
 30   CONTINUE
C
C Rewriting Smart line and associated new annual and new biennial
C credits to output file
C
C If OLDFLG is not 1, then the data is of the new type; output the
C following
C
      IF (OLDFLG.NE.1) THEN
        WRITE(13,240,ERR=350)(SMART(ISMART),ISMART=1,4),CUTHC,CUTCO,
     & CUTNO,HYBFLG,ETCFLG,OPTION,RSDD
  240   FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,I1,'2',I1,' New ',
     &         'credits, Option = ',I1,', Program type = 2, ',
     &         'input data file ',A40)
      ELSE
C
C Data is of the old type
C
        WRITE(13,245,ERR=350)(SMART(ISMART),ISMART=1,4),CUTHC,CUTCO,
     & CUTNO,OPTION,RSDD
  245  FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,' 2 ',' New ',
     &         'credits, Option = ',I1,', Program type = 2, ',
     &         'input data file ',A40)
      ENDIF
C
C Write the HC data (pollutant=1)
C
      DO 40 ITECH=1,2
C
        DO 42 ISTR=1,5
C
          DO 44 IAGE1=1,20
C
            WRITE(13,250,ERR=350)
     & (CA12HC(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
  250       FORMAT(19A4)
  44      CONTINUE
C
  42    CONTINUE

  40  CONTINUE
C
C Write the CO data (pollutant=2)
C
      DO 50 ITECH=1,2
C
        DO 52 ISTR=1,5
C
          DO 54 IAGE1=1,20
C
            WRITE(13,250,ERR=350)
     & (CA12CO(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
 54       CONTINUE
C
 52     CONTINUE

 50   CONTINUE
C
C Loop back to the beginning to read next Smart line and associated data
C
      GO TO 90
C
C ---------------------------
C CONSOLIDATED ERROR MESSAGES
C ---------------------------
C
 300  CONTINUE
      WRITE(*,301)INT12
 301  FORMAT(/,  ' ERROR OPENING INPUT FILE ',A40)
      GOTO 96
C
 310  CONTINUE
      WRITE(*,311)OUTT12
 311  FORMAT(/,  ' ERROR OPENING OUTPUT FILE ',A40)
      GOTO 96
C
 320  CONTINUE
      WRITE(*,321)INT12
 321  FORMAT(/,  ' ERROR READING SMART LINE FROM INPUT ',
     &            'FILE ',A40)
      GOTO 96
C
 325  CONTINUE
      WRITE(*,326)
 326  FORMAT(/,  ' ERROR CANNOT APPLY RSD EFFECTS--DATA ',
     &            'HAVE ALREADY BEEN CHANGED')
      GOTO 96
C
 330  CONTINUE
      WRITE(*,331)INT12
 331  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING HC ',
     &            'CREDITS FROM INPUT FILE ',A40)
      GOTO 96
C
 335  CONTINUE
      WRITE(*,336)INT12
 336  FORMAT(/,  ' ERROR READING HC CREDITS FROM INPUT ',
     &            'FILE ',A40)
      GOTO 96
C
 340  CONTINUE
      WRITE(*,341)INT12
 341  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING CO ',
     &            'CREDITS FROM INPUT FILE ',A40)
      GOTO 96
C
 345  CONTINUE
      WRITE(*,346)INT12
 346  FORMAT(/,  ' ERROR READING CO CREDITS FROM INPUT ',
     &            'FILE ',A40)
      GOTO 96
C
 350  CONTINUE
      WRITE(*,351)OUTT12
 351  FORMAT(/,  ' ERROR WRITING TO OUTPUT FILE ',A40)
      GOTO 96
C
C ---------------------------------
C CLOSE DATA FILES AND EXIT PROGRAM
C ---------------------------------
C
 96   WRITE(*,'(A)')'0CONVERSION ENDED ABNORMALLY.'
      GOTO 98
C
 97   WRITE(*,'(A)')'0Conversion ended normally.'
C
 98   CONTINUE
C
      CLOSE (13)
      CLOSE (12)
C
      RETURN
      END
      SUBROUTINE TECH3(INT12,INT12H,OUTT12,NVSEEA,UEXCE1,NVSEEB,UEXCE2,
     &                 RSDD)
C
C TECH3
C
C Calculates new sets of IM credits for
C IM programs using Remote Sensing Devices (RSD)
C from the existing Tech 1 & 2 credits
C
C Called by INPUT
C
C Calls no subroutines
C
C Input:
C by user:  none
C common block(s):  OP1
C data file(s):  files whose names are passed in INT12 and INT12H 
C subroutine arguments:  INT12, INT12H, OUTT12, NVSEEA, UEXCE1,
C                        NVSEEB, UEXCE2, RSDD
C
C Output:
C by screen:  none
C common block(s):  none used
C data file(s):  file whose name is passed in OUTT12
C subroutine arguments:  none
C
C Array subscripts:
C
C CRHCO(19,20,5,2)  - CRHCO(IBY,IAGE1,ISTR,ITECH)
C CRHHC(19,20,5,2)  - CRHHC(IBY,IAGE1,ISTR,ITECH)
C CR12CO(19,20,5,2) - CR12CO(IBY,IAGE1,ISTR,ITECH)
C CR12HC(19,20,5,2) - CR12HC(IBY,IAGE1,ISTR,ITECH)
C CUTS(4)           - CUTS(ITECH)
C EFF(3)            - EFF(IP)
C EXCESS(3,15,3)    - EXCESS(ITECH,cutpoint,pollutant)
C NVSEEA(25)        - NVSEEA(age of vehicle)
C NVSEEB(25)        - NVSEEB(age of vehicle)
C UEXCE1(3)         - UEXCE1(pollutant:  1=HC, 2=CO, & 3=NOx)
C UEXCE2(3)         - UEXCE2(pollutant:  1=HC, 2=CO, & 3=NOx)
C VMT(25)           - VMT(IBY)
C
C  Local variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C AGE     I   Age at which a veh. first becomes subject to RSD program
C ANNUAL  R   temporary Annual credit
C ANNUAH  R   temporary Annual credit, Retest-hybrid
C BIENNH  R   temporary Biennial credit, Retest-hybrid
C CRHCO   R   Array of Tech 1 & 2 CO IM credits from TC12H.D type file
C CRHHC   R   Array of Tech 1 & 2 HC IM credits from TC12H.D type file
C CRNCO   R   Array of new Tech 1 & 2 CO IM credits
C CRNHC   R   Array of new Tech 1 & 2 HC IM credits
C CR12CO  R   Array of Tech 1 & 2 CO IM credits
C CR12HC  R   Array of Tech 1 & 2 HC IM credits
C CKUTCO  R   Smart line original CO cutpoint from TC12H.D type file
C CKUTHC  R   Smart line original HC cutpoint from TC12H.D type file
C CKUTNO  R   Smart line original NO cutpoint from TC12H.D type file
C CUTCO   R   Smart line original CO cutpoint
C CUTHC   R   Smart line original HC cutpoint
C CUTNO   R   Smart line original NO cutpoint
C CUTS    R   Array of RSD CO cutpoints by Tech type:  1, 2, and 4+
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C ETCFLG  I   An extra flag in IMDATA.FOR, in TECH12.FOR, it serves as the
C              IMLFG (see below) for Tech 2 data
C EXCESS  R   See routines R1 and R2
C HYBFLG  I   Hybrid program flag
C IAGE    I   Counter for age when first inspected 
C IBY     I   Counter for Benefit Years
C ILINE   I   Counter for Smart lines
C IMFLG   I   Tech 1 I/M flag:  1 if no RSD program modifications done on
C              Tech 1 part of TECH12.D; 2 if Tech 1 data was changed
C INT12   C   Character string name of the TECH12.D type input file
C INT12H  C   Character string name of the TC12H.D type input file
C ISMART  I   Counter for Smart strip
C ISTR    I   Counter for Stringency
C ITECH   I   Counter for Tech type
C NUMBER  I   Total number of veh. subject to inspection program
C NVSEEA  R   Fraction of vehicles seen by RSD, annual program
C NVSEEB  R   Fraction of vehicles seen by RSD, biennial program
C OLDFLG  I   If old data, OLDFLG=1, if new, 0.
C OPTION  I   Option--see RSDDRV
C OUTT12  C   Character string name of the TECDATA.D type output file
C RSDD    C   Char. string name of the input data file
C SCAN    I   Number of valid veh. measurements per month at RSD sites
C SMARK   I   Array of the Smart strip values, retest-hybrid data
C SMART   I   Array of the Smart strip values, TECH12.D type data
C THREE   C   Character string name for the flags HYBFLG, IMFLG, and
C              ETCFLG if they exist, otherwise it contains part of the
C              comment line.
C TIMES   I   Minimum number of times a vehicle must be scanned between
C              inspections to be eligible for targetting
C UEXCE1  R   Effectiveness of RSD, Tech type 1 vehicles
C UEXCE2  R   Effectiveness of RSD, Tech type 2 vehicles
C VMT     I   Vehicle miles travelled by age
C
C
C Notes:  Annual and biennial information is stored in an upper and
C         lower triangular fashion.
C 10-July-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2 
C 22-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C
      CHARACTER INT12*40, INT12H*40, OUTT12*40, RSDD*40, THREE*3
C
      INTEGER AGE, ETCFLG, HYBFLG, IAGE, IBY, IMFLG, ISMART, ISTR
      INTEGER ITECH, NUMBER, OLDFLG, OPTION, SCAN, SMARK(4), SMART(4)
      INTEGER TIMES, VMT(25)
C
      REAL ANNUAL, ANNUAH, BIENNH, CKUTCO, CKUTHC, CKUTNO
      REAL CRHCO(19,20,5,2), CRHHC(19,20,5,2), CRNCO(19,20,5,2)
      REAL CRNHC(19,20,5,2), CR12CO(19,20,5,2), CR12HC(19,20,5,2)
      REAL CUTCO, CUTHC, CUTNO, CUTS(4), EFF(3), EXCESS(3,15,3)
      REAL NVSEEA(25), NVSEEB(25), UEXCE1(3), UEXCE2(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
C
C If old data, OLDFLG is set to 1; first initialize OLDFLG to 0
C
      OLDFLG=0
C
      WRITE(*,200)
 200  FORMAT(/,  ' Starting to alter 1974 and older model ',
     &            'years and 1975 through 1980 model years ',/,
     &           ' vehicles I/M credits to include Remote ', 
     &            'Sensing Devices credits ',/,
     &           ' ---------------------------------------',
     &            '---------------------------------------')
C
C Open filename in INT12 for input as unit 12
C Open filename in INT12H for input as unit 14
C Open filename in OUTT12 for output as unit 13
C
      OPEN(12,FILE=INT12, ERR=300,STATUS='OLD')
      OPEN(14,FILE=INT12H,ERR=305,STATUS='OLD')
      OPEN(13,FILE=OUTT12,ERR=310)
C
C Since the form of the data in Tech12 type files involves essentially 
C just one data block, these blocks can be read in at the same time.
C
 90   CONTINUE
C
      READ(12,100,END=97,ERR=320) (SMART(ISMART),ISMART=1,4),
     &     CUTHC,CUTCO,CUTNO,THREE
 100  FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,A3)
C
      READ(THREE,102,ERR=15) HYBFLG,IMFLG,ETCFLG
 102  FORMAT(3I1)
C
      GO TO 16
C
 15   CONTINUE
C
C When there is a misread of the flags, the data is of the old type;
C set OLDFLG to 1 and skip the check on IMFLG
C
      OLDFLG=1
C
 16   CONTINUE
C
C Since the hybrid file is unchanged, don't read into the flags area.
C
      READ(14,103,END=97,ERR=322) (SMARK(ISMART),ISMART=1,4),
     &     CKUTHC,CKUTCO,CKUTNO
 103  FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0)
C
C Reading Smart lines and associated data from test-only credits
C input file and Retest-hybrid credits input file
C
C If the Smart lines of the two input files do not agree, issue error
C and halt.
C
      IF ( (SMART(1).NE.SMARK(1)).OR.(SMART(2).NE.SMARK(2)).OR.
     &     (SMART(3).NE.SMARK(3)).OR.(SMART(4).NE.SMARK(4)).OR.
     &     (CUTCO.NE.CKUTCO)     .OR.(CUTHC.NE.CKUTHC)     .OR.
     &     (CUTNO.NE.CKUTNO) ) THEN 
        GO TO 324
      END IF
C
C Check IMFLG only if data is new
C
      IF (OLDFLG.EQ.0) THEN
C
C If IMFLG is not one, this means that Tech 1 or Tech 2 data
C has been already changed using RSD effects.  Issue error and halt.
C
        IF ( (IMFLG.NE.1).AND.(IMFLG.NE.0) ) THEN
          GO TO 326
        END IF
C
      END IF
C
C Read in Annual and Biennial credits for HC
C Loop for the two (2) ITECHs stored in the files.
C
      DO 10 ITECH=1,2
C
C Loop for the five (5) stringency values in the files.
C
        DO 12 ISTR=1,5
C
C Loop for the values in the records
C
          DO 14 IAGE1=1,20
C
C Read data from the ipu file INT12
C
            READ(12,110,END=330,ERR=334)
     & (CR12HC(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
 110       FORMAT(19F4.3)
C
C Read data from the input file INT12H
C
        READ(14,110,END=336,ERR=338)
     & (CRHHC(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
C110       FORMAT(19F4.3)
  14      CONTINUE
C
  12    CONTINUE

  10  CONTINUE
C
C Read in Annual and Biennial credits for CO
C
      DO 20 ITECH=1,2
C
        DO 22 ISTR=1,5
C
          DO 24 IAGE1=1,20
C
C Read in data from the input file INT12
C
            READ(12,110,END=340,ERR=344)
     & (CR12CO(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
C110        FORMAT(19F4.3)
C
C Read data from the input file INT12H
C
            READ(14,110,END=346,ERR=348)
     & (CRHCO(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
C110        FORMAT(19F4.3)
 24       CONTINUE
C
 22     CONTINUE

 20   CONTINUE
C
C Process the data and then write it to the output file
C Creating new Smart line and associated data
C
      DO 30 ITECH=1,2
C
        DO 32 ISTR=1,5
C
          DO 34 IBY=1,19
C
            DO 36 IAGE=1,19
C
C Only let the benefit year counter IBY and the age at first
C inspection counter be in the upper triangular region of Annual
C data.  (Another way of looking at this is that the actual age of a
C vehicle is its age at first inspection plus the time elapsed since its
C first inspection--current benefit year minus first benefit year.
C The actual age is thus IAGE+IBY-1.  Since actual age cannot exceed 
C 19 years, IAGE+IBY-1 must be .LE. 19.)
C
              IF ((IBY+IAGE).GT.20) THEN
                GO TO 34
              END IF
C
C HC credits
C
              ANNUAL=CR12HC(IBY,IAGE,ISTR,ITECH)
              ANNUAH=CRHHC(IBY,IAGE,ISTR,ITECH)
              BIENNH=CRHHC(20-IBY,21-IAGE,ISTR,ITECH)
C
              IF (ITECH.EQ.1) THEN
C
                CRNHC(IBY,IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEA(IAGE+IBY-1) * UEXCE1(1) +
     & ANNUAH * ( 1.0 - NVSEEA(IAGE+IBY-1) * UEXCE1(1) )
C
C Note:  new annual credit = Test-only annual credit * F * E +
C Hybrid-retest annual credit * (1-F*E).  The data from
C the input files consists of Test-only credit.
C
                CRNHC(20-IBY,21-IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEB(IAGE+IBY-1) * UEXCE1(1) +
     & BIENNH * ( 1.0 - NVSEEB(IAGE+IBY-1) * UEXCE1(1) )
C
C Note:  new biennial credit = Test-only annual credit * F * E +
C Hybrid-retest biennial credit * (1-F*E).
C
              ELSE
C
C ITECH is 2
C
                CRNHC(IBY,IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEA(IAGE+IBY-1) * UEXCE2(1) +
     & ANNUAH * ( 1.0 - NVSEEA(IAGE+IBY-1) * UEXCE2(1) )
C
                CRNHC(20-IBY,21-IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEB(IAGE+IBY-1) * UEXCE2(1) +
     & BIENNH * ( 1.0 - NVSEEB(IAGE+IBY-1) * UEXCE2(1) )
C
C
              END IF
C
C Note that NVSEEA and NVSEEB are functions of the actual age of
C the vehicle.  See above.
C
C CO credits
C
              ANNUAL=CR12CO(IBY,IAGE,ISTR,ITECH)
              ANNUAH=CRHCO(IBY,IAGE,ISTR,ITECH)
              BIENNH=CRHCO(20-IBY,21-IAGE,ISTR,ITECH)
C
              IF (ITECH.EQ.1) THEN
C
                CRNCO(IBY,IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEA(IAGE+IBY-1) * UEXCE1(2) +
     & ANNUAH * ( 1.0 - NVSEEA(IAGE+IBY-1) * UEXCE1(2) )
C
                CRNCO(20-IBY,21-IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEB(IAGE+IBY-1) * UEXCE1(2) +
     & BIENNH * ( 1.0 - NVSEEB(IAGE+IBY-1) * UEXCE1(2) )
C
              ELSE
C
C ITECH is 2
C
                CRNCO(IBY,IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEA(IAGE+IBY-1) * UEXCE2(2) +
     & ANNUAH * ( 1.0 - NVSEEA(IAGE+IBY-1) * UEXCE2(2) )
C
                CRNCO(20-IBY,21-IAGE,ISTR,ITECH) =
     & ANNUAL * NVSEEB(IAGE+IBY-1) * UEXCE2(2) +
     & BIENNH * ( 1.0 - NVSEEB(IAGE+IBY-1) * UEXCE2(2) )
C
              END IF
C
 36         CONTINUE
C
 34       CONTINUE
C
 32     CONTINUE
C
 30   CONTINUE
C
C Rewriting Smart line and associated new annual and new biennial
C credits to the output file
C
C If OLDFLG is not 1, then data is of the new type; output the
C following
C
      IF (OLDFLG.NE.1) THEN
        WRITE(13,240,ERR=350)(SMART(ISMART),ISMART=1,4),CUTHC,CUTCO,
     & CUTNO,HYBFLG,ETCFLG,OPTION,RSDD
  240   FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,I1,'2',I1,' New ',
     &         'credits, Option = ',I1,', Program type = 3, ',
     &         'input data file ',A40)
      ELSE
C
C Old type data
C
        WRITE(13,242,ERR=350)(SMART(ISMART),ISMART=1,4),CUTHC,CUTCO,
     & CUTNO,OPTION,RSDD
  242   FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,' 2 ',' New ',
     &         'credits, Option = ',I1,', Program type = 3, ',
     &         'input data file ',A40)
      END IF
C
C Write the HC data
C
      DO 40 ITECH=1,2
C
        DO 42 ISTR=1,5
C
          DO 44 IAGE1=1,20
            WRITE(13,250,ERR=350)
     & (CRNHC(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
  250       FORMAT(19F4.3)
  44      CONTINUE
C
  42    CONTINUE

  40  CONTINUE
C
C Write the CO data
C
      DO 50 ITECH=1,2
C
        DO 52 ISTR=1,5
C
          DO 54 IAGE1=1,20
            WRITE(13,250,ERR=350)
     & (CRNCO(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
 54       CONTINUE
C
 52     CONTINUE

 50   CONTINUE
C
C Done.
C
      GO TO 97
C
C ---------------------------
C CONSOLIDATED ERROR MESSAGES
C ---------------------------
C
 300  CONTINUE  
      WRITE(*,301)INT12
 301  FORMAT(/,  ' ERROR OPENING TEST-ONLY INPUT CREDITS ',
     &            'FILE ',A40)
      GOTO 96
C
 305  CONTINUE
      WRITE(*,306)INT12H
 306  FORMAT(/,  ' ERROR OPENING RETEST-HYBRID INPUT ',
     &            'CREDITS FILE ',A40)
      GOTO 96
C
 310  CONTINUE
      WRITE(*,311)OUTT12
 311  FORMAT(/,  ' ERROR OPENING OUTPUT FILE ',A40)
      GOTO 96
C
 320  CONTINUE
      WRITE(*,321)INT12
 321  FORMAT(/,  ' ERROR READING SMART LINE FROM TEST-ONLY ',
     &            'INPUT CREDITS FILE ',A40)
      GOTO 96
C
 322  CONTINUE
      WRITE(*,323)INT12H
 323  FORMAT(/,  ' ERROR READING SMART LINE FROM ',
     &            'RETEST-HYBRID INPUT CREDITS FILE ',/,
     &           ' ',A40)
      GOTO 96
C
 324  CONTINUE
      WRITE(*,325)
 325  FORMAT(/,  ' ERROR SMART LINES FROM THE TWO INPUT ',
     &            'FILES DO NOT MATCH')
      GOTO 96
C
 326  CONTINUE
      WRITE(*,327)INT12
 327  FORMAT(/,  ' ERROR TECH 1 OR TECH 2 DATA HAVE ',
     &            'ALREADY BEEN CHANGED IN TEST-ONLY INPUT ',/,
     &           ' CREDITS FILE ',A40)
      GOTO 96
C
 330  CONTINUE
      WRITE(*,331)INT12
 331  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING HC ',
     &            'CREDITS FROM TEST-ONLY INPUT FILE ',/,
     &           ' ',A40)
      GOTO 96
C
 334  CONTINUE
      WRITE(*,335)INT12
 335  FORMAT(/,  ' ERROR READING HC CREDITS FROM TEST-ONLY ',
     &            'INPUT FILE ',A40)
      GOTO 96
C
 336  CONTINUE
      WRITE(*,337)INT12H
 337  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING HC ',
     &            'CREDITS FROM RETEST-HYBRID INPUT FILE ',/,
     &           ' ',A40)
      GOTO 96
C
 338  CONTINUE
      WRITE(*,339)INT12H
 339  FORMAT(/,  ' ERROR READING HC CREDITS FROM ',
     &            'RETEST-HYBRID INPUT FILE ',A40)
      GOTO 96
C
 340  CONTINUE
      WRITE(*,341)INT12
 341  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING CO ',
     &            'CREDITS FROM TEST-ONLY INPUT FILE ',/,
     &           ' ',A40)
      GOTO 96
C
 344  CONTINUE
      WRITE(*,345)INT12
 345  FORMAT(/,  ' ERROR READING CO CREDITS FROM TEST-ONLY ',
     &            'INPUT FILE ',A40)
      GOTO 96
C
 346  CONTINUE
      WRITE(*,347)INT12H
 347  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING CO ',
     &            'CREDITS FROM RETEST-HYBRID INPUT FILE ',/,
     &           ' ',A40)
      GOTO 96
C
 348  CONTINUE
      WRITE(*,349)INT12H
 349  FORMAT(/,  ' ERROR READING CO CREDITS FROM ',
     &            'RETEST-HYBRID INPUT FILE ',A40)
      GOTO 96
C
 350  CONTINUE
      WRITE(*,351)OUTT12
 351  FORMAT(/,  ' ERROR WRITING TO OUTPUT FILE ',A40)
      GOTO 96
C
C ---------------------------------
C CLOSE DATA FILES AND EXIT PROGRAM
C ---------------------------------
C
 96   WRITE(*,'(A)')'0CONVERSION ENDED ABNORMALLY.'
      GOTO 98
C
 97   WRITE(*,'(A)')'0Conversion ended normally.'
C
 98   CONTINUE
C
      CLOSE (13)
      CLOSE (14)
      CLOSE (12)
C
      RETURN
      END
      SUBROUTINE R2(UEXCE1,NVSEEA,UEXCE2,NVSEEB,UEXCE4)
C
C Subroutine R2 calculates the proper values of E and F for
C option 2
C
C Subroutine calls:  none
C
C Input: 
C by user:  none
C common blocks:  OP1, OP2
C data file(s): none
C subroutine arguments: none
C 
C Output:
C by screen:  none
C common blocks:  none
C data file(s):  none
C subroutine arguments:  UEXCE1, NVSEEA, UEXCE2, NVSEEB, UEXCE4
C
C Array subscripts:
C
C CUTS(4)        - CUTS(ITECH)
C EFF(3)         - EFF(IP)
C EXCESS(3,15,3) - EXCESS(1 is Tech type 1, 2 is 2, & 3 is 4+,ICUT,IP)
C NVSEEA(25)     - NVSEEA(IBY)
C NVSEEB(25)     - NVSEEB(IBY)
C SENT(25)       - SENT(IBY)
C TOTAL(25)      - TOTAL(IBY)
C UEXCE1(3)      - UEXCE1(IP)
C UEXCE2(3)      - UEXCE2(IP)
C UEXCE4(3)      - UEXCE4(IP)
C VMT(25)        - VMT(IBY)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C AGE     I   Age at which a veh. first becomes subject to RSD program
C CUTS    R   Array of RSD CO test cutpoints for vehicle groups
C              pre-1975, 1975-1980, and post-1980, Clean Screen NOx Cutpoint
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C EXCESS  R   Sacramento Study data for HC, CO, and NOx fractions of IM
C              excess identified for a particular cutpoint of CO for a
C              particular Tech type:  EXCESS( Tech type, ICUT,IP) if
C              defaults in DATA2 were used--otherwise, this data is
C              provided by user
C IBY     I   Benefit year
C ICUT    I   Counter for cutpoint array index (ICUT=1, 2, ... , 8
C              corresponds to 0.5%, 1.0%, ... , 4.0% CO test cutpoints)
C IP      I   Counter for pollutants
C NVSEEA  R   Fractions of vehicles seen by RSD in an annual program by
C              year, provided by user
C NVSEEB  R   Fractions of vehicles seen by RSD in a biennial program by
C              year, povided by user
C OPTION  I   Option--see RSDDRV
C RCUT    R   Real value of counter for cutpoint array index
C SENT    I   No. of veh. sent to special IM via RSD (commitment) by age
C TOTAL   I   Total no. of veh. for each age
C UEXCE1  R   HC, CO, and NOx fractions of IM excess identified by RSD,
C              calculated from UEXCES using user-supplied RSD CO test
C              cutpoints; used by TECH12 to modify pre-1975 data
C UEXCE2  R   Like UEXCE1, but used by TECH12 to modify 1975-1980 data
C UEXCE4  R   Like UEXCE1, but used by IMDATA to modify post-1980 data
C VMT     I   Vehicle Miles Travelled (per year), by age
C
C
C Notes:
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 20-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C
C Declare variables
C
      INTEGER AGE, IBY, ICUT, IP, NUMBER, OPTION, SCAN, SENT(25), TIMES
      INTEGER TOTAL(25),VMT(25)
C
      REAL CUTS(4), EFF(3), EXCESS(3,15,3), NVSEEA(25), NVSEEB(25), RCUT
      REAL UEXCE1(3), UEXCE2(3), UEXCE4(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
      COMMON /OP2/SENT,TOTAL
C
C EXCESS is set up as follows
C
C Fortran first fastest convention for indices:  UEXCES(1,1,1), (2,1,1),
C (3,1,1), (1,2,1), ... , i.e., (Tech 1, 0.5%, HC), (Tech 2, 0.5%, HC),
C (Tech 4, 0.5%, HC), (Tech 1, 1.0%, HC), ...
C                  (1,1,1)  (2,1,1)  (3,1,1)  (1,2,1)  (2,2,1)  (3,2,1)
C
C Set up excess emissions identified arrays
C
C Set up proper cutpoint data by interpolating the discrete values
C in array EXCESS(tech type, cutpoint, pollutant).  First evaluate
C pre-1975 (Tech 1) data,
C
      DO 81 IP=1,3
C
C If CUTS(1) = 99.9, fill the UEXCE1 array with 0. in order to
C indicate processing is to be skipped for pr-1975 (Tech 1) data
C
        IF (CUTS(1).EQ.99.9) THEN
          UEXCE1(IP)=0.
          GO TO 81
        END IF
C
C First, calculate the two cutpoint array indices corresponding to the
C data points in the array nearest to the given cutpoint:
C 0.5 <=> 1, 1.0 <=> 2, ... , 4.0 <=> 8, ... , 7.5 <=> 15
C
        ICUT=INT(CUTS(1)*2)
        RCUT=FLOAT(ICUT)
C
C If ICUT=15, avoid sending the array out of bounds:
C
        IF (ICUT.EQ.15) THEN
          UEXCE1(IP)=EXCESS(1,ICUT,IP)
          GO TO 81
        END IF
C
C ICUT is not 15, so interpolate:
C
        UEXCE1(IP)=EXCESS(1,ICUT,IP)+
     &             ( EXCESS(1,ICUT+1,IP) - EXCESS(1,ICUT,IP) )*
     &             ( CUTS(1) - RCUT/2 )/0.5
C
 81   CONTINUE
C
C ... then evaluate Tech 2 data,
C
      DO 82 IP=1,3
C
C If CUTS(2) = 99.9, fill the UEXCE2 array with 0. in order to
C indicate processing is to be skipped for 1975-1980 (Tech 2) data
C
        IF (CUTS(2).EQ.99.9) THEN
          UEXCE2(IP)=0.
          GO TO 82
        END IF
C
        ICUT=INT(CUTS(2)*2)
        RCUT=FLOAT(ICUT)
C
        IF (ICUT.EQ.15) THEN
          UEXCE2(IP)=EXCESS(2,ICUT,IP)
          GO TO 82
        END IF
C
        UEXCE2(IP)=EXCESS(2,ICUT,IP)+
     &             ( EXCESS(2,ICUT+1,IP) - EXCESS(2,ICUT,IP) )*
     &             ( CUTS(2) - RCUT/2 )/0.5
C
 82   CONTINUE
C
C ... and then evaluate post-1980 data.
C
      DO 84 IP=1,3
C
C If CUTS(3) = 99.9, fill the UEXCE2 array with 0. in order to
C indicate processing is to be skipped for post-1980 (Tech 4+) data
C
        IF (CUTS(3).EQ.99.9) THEN
          UEXCE4(IP)=0.
          GO TO 84
        END IF
C
        ICUT=INT(CUTS(3)*2)
        RCUT=FLOAT(ICUT)
C
        IF (ICUT.EQ.15) THEN
          UEXCE4(IP)=EXCESS(3,ICUT,IP)
          GO TO 84
        END IF
C
        UEXCE4(IP)=EXCESS(3,ICUT,IP)+
     &             ( EXCESS(3,ICUT+1,IP) - EXCESS(3,ICUT,IP) )*
     &             ( CUTS(3) - RCUT/2 )/0.5
C
 84   CONTINUE
C
C Calculate F values, NVSEEA and NVSEEB
C
      DO 85 IBY=1,25
C
C Take age exemptions into account.
C
        IF (IBY.LT.INT(AGE)) THEN
          NVSEEA(IBY)=0.
        ELSE
          NVSEEA(IBY)=FLOAT(SENT(IBY))/FLOAT(TOTAL(IBY))
        ENDIF
C
        NVSEEB(IBY)=NVSEEA(IBY)
C
 85   CONTINUE
C
      RETURN
      END
      SUBROUTINE R3(UEXCE1,NVSEEA,UEXCE2,NVSEEB,UEXCE4)
C
C Subroutine R3 calculates the proper values of E and F for
C option 3
C
C Subroutine calls:  none
C
C Input: 
C by user:  none
C common blocks:  OP1, OP3
C data file(s): none
C subroutine arguments: none
C 
C Output:
C by screen:  none
C common blocks:  none
C data file(s):  none
C subroutine arguments:  UEXCE1, NVSEEA, UEXCE2, NVSEEB, UEXCE4
C
C Array subscripts:
C
C CFAIL(25)      - CFAIL(IBY)
C CUTS(4)        - CUTS(ITECH)
C EFF(3)         - EFF(IP)
C EOPT3(3,15,3)  - EOPT3(Tech type, ICUT, IP)
C EXCESS(3,15,3) - EXCESS(Tech type, ICUT, IP)
C NVSEEA(25)     - NVSEEA(IBY)
C NVSEEB(25)     - NVSEEB(IBY)
C RFAIL(25)      - RFAIL(IBY)
C UEXCE1(3)      - UEXCE1(IP)
C UEXCE2(3)      - UEXCE2(IP)
C UEXCE4(3)      - UEXCE4(IP)
C VMT(25)        - VMT(IBY)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C AGE     I   Age at which a veh. first becomes subject to RSD program
C CFAIL   I   No. of veh. by age that failed the current year's IM
C CUTS    R   Array of RSD CO test cutpoints for vehicle groups
C              pre-1975, 1975-1980, and post-1980, Clean Screen NOx Cutpoint
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C EOPT3   R   User supplied data for HC, CO, and NOx fractions of IM
C              excess identified for a particular cutpoint of CO for a
C              particular Tech type:  EOPT3( Tech type, ICUT,IP):  E
C              values for Option 3
C EXCESS  R   Like EOPT3, but for Options 1 and 2
C IBY     I   Benefit year
C ICUT    I   Counter for cutpoint array index (ICUT=1, 2, ... , 8
C              corresponds to 0.5%, 1.0%, ... , 4.0% CO test cutpoints)
C IP      I   Counter for pollutants
C MAXEX   R   Maximum of the excesses UEXCE1(IP), UEXCE2(IP), and
C              UEXCE4(IP) for the CO cutpoint in use
C NVSEEA  R   Fractions of vehicles seen by RSD in an annual program by
C              year, provided by user
C NVSEEB  R   Fractions of vehicles seen by RSD in a biennial program by
C              year, povided by user
C RCUT    R   Real value of counter for cutpoint array index
C RFAIL   I   Commitment for no. of veh. to fail the RSD IM program in
C              the upcoming year.
C UEXCE1  R   HC, CO, and NOx fractions of IM excess identified by RSD,
C              calculated from UEXCES using user-supplied RSD CO test
C              cutpoints; used by TECH12 to modify pre-1975 data
C UEXCE2  R   Like UEXCE1, but used by TECH12 to modify 1975-1980 data
C UEXCE4  R   Like UEXCE1, but used by IMDATA to modify post-1980 data
C VMT     I   Vehicle Miles Travelled (per year), by age
C
C
C Notes:
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 20-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C
C Declare variables
C
      INTEGER AGE, CFAIL(25), IBY, ICUT, IP, NUMBER, OPTION, RFAIL(25)
      INTEGER SCAN, TIMES, VMT(25)
C
      REAL CUTS(4), EFF(3), EOPT3(3,15,3), EXCESS(3,15,3), MAXEX
      REAL NVSEEA(25), NVSEEB(25), RCUT, UEXCE1(3), UEXCE2(3), UEXCE4(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
      COMMON /OP3/CFAIL,RFAIL,EOPT3
C
C Set up excess emissions identified arrays
C
C Set up proper cutpoint data by interpolating the discrete values
C in array EOPT3(tech type, cutpoint, pollutant).  First evaluate
C pre-1975 (Tech 1) data,
C
      DO 81 IP=1,3
C
C If CUTS(1) = 99.9, fill the UEXCE1 array with 0. in order to
C indicate processing is to be skipped for pr-1975 (Tech 1) data
C
        IF (CUTS(1).EQ.99.9) THEN
          UEXCE1(IP)=0.
          GO TO 81
        END IF
C
C First, calculate the two cutpoint array indices corresponding to the
C data points in the array nearest to the given cutpoint:
C 0.5 <=> 1, 1.0 <=> 2, ... , 4.0 <=> 8, ... , 7.5 <=> 15
C
        ICUT=INT(CUTS(1)*2)
        RCUT=FLOAT(ICUT)
C
C If ICUT=15, avoid sending the array out of bounds:
C
        IF (ICUT.EQ.15) THEN
          UEXCE1(IP)=EOPT3(1,ICUT,IP)
          GO TO 81
        END IF
C
C ICUT is not 15, so interpolate:
C
        UEXCE1(IP)=EOPT3(1,ICUT,IP)+
     &             ( EOPT3(1,ICUT+1,IP) - EOPT3(1,ICUT,IP) )*
     &             ( CUTS(1) - RCUT/2 )/0.5
C
 81   CONTINUE
C
C ... then evaluate Tech 2 data,
C
      DO 82 IP=1,3
C
C If CUTS(2) = 99.9, fill the UEXCE2 array with 0. in order to
C indicate processing is to be skipped for 1975-1980 (Tech 2) data
C
        IF (CUTS(2).EQ.99.9) THEN
          UEXCE2(IP)=0.
          GO TO 82
        END IF
C
        ICUT=INT(CUTS(2)*2)
        RCUT=FLOAT(ICUT)
C
        IF (ICUT.EQ.15) THEN
          UEXCE2(IP)=EOPT3(2,ICUT,IP)
          GO TO 82
        END IF
C
        UEXCE2(IP)=EOPT3(2,ICUT,IP)+
     &             ( EOPT3(2,ICUT+1,IP) - EOPT3(2,ICUT,IP) )*
     &             ( CUTS(2) - RCUT/2 )/0.5
C
 82   CONTINUE
C
C ... and then evaluate post-1980 data.
C
      DO 84 IP=1,3
C
C If CUTS(3) = 99.9, fill the UEXCE2 array with 0. in order to
C indicate processing is to be skipped for post-1980 (Tech 4+) data
C
        IF (CUTS(3).EQ.99.9) THEN
          UEXCE4(IP)=0.
          GO TO 84
        END IF
C
        ICUT=INT(CUTS(3)*2)
        RCUT=FLOAT(ICUT)
C
        IF (ICUT.EQ.15) THEN
          UEXCE4(IP)=EOPT3(3,ICUT,IP)
          GO TO 84
        END IF
C
        UEXCE4(IP)=EOPT3(3,ICUT,IP)+
     &             ( EOPT3(3,ICUT+1,IP) - EOPT3(3,ICUT,IP) )*
     &             ( CUTS(3) - RCUT/2 )/0.5
C
 84   CONTINUE
C
C
C Reset RFAIL values if necessary to cap the effectivenesses *
C fractions of vehicles seen values at 1.0.
C
      MAXEX = AMAX1( UEXCE1(1), UEXCE1(2), UEXCE1(3),
     &               UEXCE2(1), UEXCE2(2), UEXCE2(3),
     &               UEXCE4(1), UEXCE4(2), UEXCE4(3) )
C
      IF (MAXEX.NE.0.) THEN
C
C Check to see if any model year values of RFAIL are too high.
C
        DO 90 IBY=1,25
C
          IF ( MAXEX*FLOAT(RFAIL(IBY))/FLOAT(CFAIL(IBY)).GT.1. ) THEN
            WRITE(*,200)IBY,RFAIL(IBY),INT( FLOAT(CFAIL(IBY))/MAXEX )
 200        FORMAT(/,1X,'Input no. of IM failures via RSD (commitment)',
     & ' in model yr. ',I2,' is ',I4,/,' and is too large.  Resetting',
     & ' to ',I4)
            RFAIL(IBY)=INT( FLOAT(CFAIL(IBY))/MAXEX )
          ENDIF
C
 90     CONTINUE
C
      ENDIF
C
C
C
C Calculate F values
C
      DO 85 IBY=1,25
C
C Take age exemptions into account.
C
        IF (IBY.LT.INT(AGE)) THEN
          NVSEEA(IBY)=0.
        ELSE
          NVSEEA(IBY)=FLOAT(RFAIL(IBY))/FLOAT(CFAIL(IBY))
        END IF
C
        NVSEEB(IBY)=NVSEEA(IBY)
C
 85   CONTINUE
C
      RETURN
      END
      SUBROUTINE IM5(IN1981,OUT198,NVSEEA,UEX3,UEX4,UEX5,NVSEEB,RSDD)
C
C IM5 (Clean Screening)
C
C Calculates new sets of IM credits for
C IM programs using Remote Sensing Devices (RSD) 
C from the existing 1981 and newer model years vehicles credits
C
C Called by INPUT
C
C Calls no subroutines
C
C Input:
C by user:  none
C common block(s):  OP1
C data file(s):  file whose name is passed in IN1981  
C subroutine arguments:  IN1981, OUT198, NVSEEA, UEXCE4, 
C                        UEXCE5, UEXCE6, NVSEEB,RSDD
C
C Output:
C by screen:  none
C common blocks(s):  none
C data file(s):  file whose name is passed in OUT198
C subroutine arguments:  none
C
C Array subscripts:
C
C ACREDT(18,3,24) - ACREDT(ITECH,IP,IBY)
C BCREDT(24)      - BCREDT(IBY)
C CUTS(4)         - CUTS(ITECH)
C EFF(3)          - EFF(IP)
C EXCESS(3,15,3)  - EXCESS(ITECH,cutpoint,IP)
C NCREDT(24)      - NCREDT(IBY)
C NVSEEA(25)      - NVSEEA(IBY)
C NVSEEB(25)      - NVSEEB(IBY)
C SMARK(4)        - SMARK(ISMART)
C SMART(4)        - SMART(ISMART)
C UEXCE4(3)       - UEXCE4(IP)
C UEXCE5(3)       - UEXCE5(IP)
C UEXCE6(3)       - UEXCE6(IP)
C VMT(25)         - VMT(IBY)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -  
C ACREDT  R   Array of annual credits read from the input file
C AGE     I   Age at which a veh. first becomes subject to RSD program
C BCREDT  R   Array of biennial credits read from the input file
C CCUTCO  R   CO cut point read from an input file annual Smart line
C CCUTHC  R   HC cut point read from an input file annual Smart line
C CCUTNO  R   NOx cut point read from an input file annual Smart line
C CKUTCO  R   CO cut point read from an input file biennial Smart line
C CKUTHC  R   HC cut point read from an input file biennial Smart line
C CKUTNO  R   NOx cut point read from an input file biennial Smart line
C CRDCOM  C   Char. string of comments from the end of a credit line 
C CUTS    R   Array of RSD CO test cutpoints for vehicle groups
C              pre-1975, 1975-1980, and post-1980, Clean Screen NOx Cutpoint
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C ETCFLG  I   Etc. flag, may be used for something in the future.
C EXCESS  R   See routines R1 and R2
C FLAG    I   The next Smart line to be examined for annual data is
C              FLAG+1 Smart lines from the top of the input file
C HYBFLG  I   Hybrid program flag
C IBY     I   Counter for Benefit Years
C ILINE   I   Counter for Smart lines
C IMFLG   I   I/M flag:  1 if no RSD program modifications done on
C              IMDATA; 2 if data was changed
C IN1981  C   Character string name of the IMDATA.D type input filename
C IP      I   Counter for pollutants
C IREC    I   Counter for credit lines
C ISMART  I   Counter for digits in the Smart control strip
C ITECH   I   Counter for model years
C NCREDT  R   Array of new credits
C NUMBER  I   Total number of vehicles subject to the I/M program.
C NVSEEA  R   Fraction of vehicles seen by RSD, annual program
C NVSEEB  R   Fraction of vehicles seen by RSD, biennial program
C OLDFLG  I   If old data, OLDFLG=1, if new, 0.
C OPTION  I   Option--see RSDDRV
C OUT198  C   Char. string name of the RSDDATA.D type output filename
C RSDD    C   Char. string name of the input data file
C SCAN    I   Number of valid veh. measurements per month at RSD sites
C SMARK   I   Array holding the first four digits of a biennial Smart
C              line (the Smart control strip):  altitude 1=Low 2=High; 
C              frequency 1=annual 2=biennial; technology 1=TECH1&2
C              2=TECH4+; test type 1=Idle 2=2500/Idle 3=Loaded/Idle
C              4=IM240 Test
C SMART   I   Array holding the 1st four digits of an annual Smart line
C THREE   C   Character string name for the flags HYBFLG, IMFLG, and
C              ETCFLG if they exist, otherwise it contains part of the
C               comment line
C TIMES   I   Minimum number of times a vehicle must be scanned between
C              inspections to be eligible for targetting
C UEXCE4  R   RSD effectiveness for 1981-1985 vehicles
C UEXCE5  R   RSD effectiveness for 1986-1989 vehicles
C UEXCE6  R   RSD effectiveness for 1990+ vehicles
C VMT     I   Vehicle miles travelled by age
C XCESS   R   Local effectiveness from UEXCE
C
C
C Notes:  Tech 1 refers to pre-1975 vehicles, Tech 2 to those from
C         1975-1980, and Tech 4+ to those of 1981 and later.
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 22-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 19-Mar-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 13-Feb-1998 @ EPA-djb
C
C -----------------
C DECLARE VARIABLES
C -----------------
C
      CHARACTER CRDCOM*19, IN1981*40, OUT198*40, RSDD*40, THREE*3
C
      INTEGER AGE, ETCFLG, FLAG, HYBFLG, IBY, ILINE, IMFLG, IP, IREC
      INTEGER ISMART, ITECH, NUMBER, OLDFLG, OPTION, SCAN, SMARK(4)
      INTEGER SMART(4), TIMES, VMT(25)
      INTEGER CSSCEN(6), NEWPHS, NEWRSD
C
      REAL ACREDT(18,3,24), BCREDT(24), CCUTHC, CCUTCO, CCUTNO, CKUTHC
      REAL CKUTCO, CKUTNO, CUTS(4), EFF(3), EXCESS(3,15,3), NCREDT(24)
      REAL NVSEEA(25), NVSEEB(25)
C     REAL UEXCE4(3), UEXCE5(3), UEXCE6(3)
      REAL XCESS
C     REAL UEX1(25,3), UEX2(25,3)
      REAL UEX3(25,3), UEX4(25,3), UEX5(25,3)
      REAL CLEANX(3,4,3,2), CSCRN(25,4), VEPX(25,4,3), ACSCRN(25,4)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
      COMMON /PPEFF/ NEWPHS, NEWRSD, CSCRN, CLEANX, VEPX, ACSCRN, CSSCEN
C
      WRITE(*,200)
 200  FORMAT(/,  ' Starting to alter 1981 and newer model ',
     &            'years vehicles I/M credits to include ',/,
     &           ' Remote Sensing Devices credits ',/,
     &           ' ---------------------------------------',
     &            '------------------------------------- ')
C
C ----------
C OPEN FILES
C ----------
C
      OPEN(UNIT=2,FILE=IN1981,ERR=300,STATUS='OLD')
      OPEN(UNIT=3,FILE=OUT198,ERR=305)
C
C ------------------
C START PROCESS LOOP
C ------------------
C
C Set FLAG=0.  This means that the first Smart line in the file is the
C line to check to see if it is one marking annual data.
C
      FLAG=0
C
C Set OLDFLG=0.  This means that data is new, i.e., it has HYBFLG,
C IMFLG, and ETCFLG.  If it is 1, it means that these don't exist and
C the data is old data.
C
      OLDFLG=0
C
 50   CONTINUE
C
C The following section of code jumps ahead in the data file to the
C first Smart line after the last Smart line marking annual data.
C Jumping ahead means reading one or more sets (a Smart line, 18 year
C sets composed of an HC line, a CO line, and a NOx line--55 lines in 
C all) of data so that the next record to be read will be a Smart line.
C
      DO 10 ILINE=1,FLAG
C
        DO 15 IREC=1,55
          READ(2,100,END=20)
 100      FORMAT(1X)
 15     CONTINUE
C
 10   CONTINUE
C
C Read the Smart control strip, cut point values and description line
C
 30   CONTINUE
C
      READ(2,102,END=20,ERR=310)(SMART(ISMART),ISMART=1,4),
     &                          CCUTHC,CCUTCO,CCUTNO,THREE
 102  FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,A3)
C
      READ(THREE,105,ERR=22)HYBFLG,IMFLG,ETCFLG
 105  FORMAT(3I1)
C
      GO TO 23
C
 22   CONTINUE
C
C An error in reading flags from THREE means that they aren't there;
C thus the input file is old-type data.
C
      OLDFLG=1
C
 23   CONTINUE
C
C Reading a Smart line; looking for annual data
C
C Increment FLAG, since the next Smart line that can mark annual data
C must be below the current Smart line
C
      FLAG=FLAG+1
C
C Check to see if the current Smart line marks annual data
C
      IF (SMART(2).NE.1) THEN
C
C Not annual; jump forward to the next Smart line and read it
C
        DO 25 IREC=1,54
          READ(2,100,END=20)
C100      FORMAT(1X)
 25     CONTINUE
C       
        GO TO 30
      END IF
C
C The current Smart line marks annual data.  Echo the annual Smart   
C line to the new file
C
C Found annual data; writing new credits
C
C Execute the following if OLDFLG is not 1; the following is for new
C data
C
      IF (OLDFLG.NE.1) THEN
C
C Halt processing if the annual Smart line has a value
C of IMFLG that is not one, because this means that the annual
C data has already been changed due to RSD effects, and making more
C than one change on the same data would result in nonsense.
C
        IF ( (IMFLG.NE.1).AND.(IMFLG.NE.0) ) THEN
          GO TO 332
        END IF
C
        WRITE(3,215,ERR=312)(SMART(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,HYBFLG,ETCFLG,OPTION,RSDD
 215    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,I1,'2',I1,1X,'New ',
     &         'annual credits, Option = ',I1,', Program type = 5, ',
     &         'input data file ',A40)
      ELSE
C
C For old data, can't examine IMFLG--just write it as '2'; write  HYBFLG
C and ETCFLG as blanks.
C
        WRITE(3,216,ERR=312)(SMART(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,OPTION,RSDD
 216    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,' 2 ',1X,'New ',
     &         'annual credits, Option = ',I1,', Program type = 5, ',
     &         'input data file ',A40)
      ENDIF
C
C Read the annual credits.
C
      PRINT *,'Reading old annual credits ... writing new annual ',
     & 'credits'
C
C Loop for the 18 model years stored in the record.
C 1-5: 1981-1985
C 6-9: 1986-1989
C 10+: 1990+
C
      DO 35 ITECH=1,18
C
C Loop for the 3 pollutants (HC, CO, and NOX) in the record.
C
        DO 36 IP=1,3
C
C Read the 24 age credit values
C
          READ(2,110,END=315,ERR=320)(ACREDT(ITECH,IP,IBY),IBY=1,24),
     &                               CRDCOM
 110      FORMAT (24F5.3,A19)
C
C Calculate the new annual credit.
C
C Note:  new annual credit = annual credit  -
C annual credit * F * ( 1 - E )
C
            DO 37 IBY=1,24
C
C Determine which effectiveness to use for this model year
C
      IF(ITECH.LT.6) THEN
        XCESS=UEX3(IBY,IP)
        SEENA=NVSEEA(IBY)
        IF(CSSCEN(6).GT.4) SEENA=1.0
      END IF
      IF((ITECH.GT.5).AND.(ITECH.LT.10)) THEN
        XCESS=UEX4(IBY,IP)
        SEENA=NVSEEA(IBY)
        IF(CSSCEN(6).GT.4) SEENA=1.0
      END IF
      IF(ITECH.GT.9) THEN
        XCESS=UEX5(IBY,IP)
        SEENA=NVSEEA(IBY)
        IF(CSSCEN(6).GT.4) SEENA=1.0
      END IF
C
              NCREDT(IBY) = ACREDT(ITECH,IP,IBY) -
     & ACREDT(ITECH,IP,IBY) * SEENA * ( 1.0 - XCESS )
C      IF(ITECH.EQ.1) WRITE(7,771) ITECH,IP,IBY,
C    *   ACREDT(ITECH,IP,IBY),SEENA,XCESS,NCREDT(IBY)
C 771  FORMAT(3I4,4F10.4)
C
 37       CONTINUE
C
          WRITE(3,220,ERR=325)(NCREDT(IBY),IBY=1,24),CRDCOM
 220      FORMAT(24F5.3,A19)
C
 36     CONTINUE
C
 35   CONTINUE
C
C Go back to beginning of the data file to begin the search for the
C biennial Smart line corresponding to the above annual Smart line
C
      REWIND(2)
C
C Read current Smart line
C
 40   CONTINUE
C
C If old data, don't try to read the flags after the cutpoints
C
      IF (OLDFLG.EQ.1) THEN
        READ(2,112,END=330,ERR=310)(SMARK(ISMART),ISMART=1,4),CKUTHC,
     &                             CKUTCO,CKUTNO
 112    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1)
      ELSE
        READ(2,115,END=330,ERR=310)(SMARK(ISMART),ISMART=1,4),CKUTHC,
     &                             CKUTCO,CKUTNO,HYBFLG,IMFLG,ETCFLG
 115    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,3I1)
      ENDIF
C
C Reading a Smart line; looking biennial data
C
C If it is not the matching biennial Smart line, read the next Smart
C line
C
      IF ( (SMARK(1).NE.SMART(1)) .OR. (SMARK(2).NE.2) .OR.
     &     (SMARK(3).NE.SMART(3)) .OR. (SMARK(4).NE.SMART(4)) .OR.
     &     (CCUTHC  .NE.  CKUTHC) .OR. (CCUTCO  .NE.  CKUTCO) .OR.
     &     (CCUTNO  .NE.  CKUTNO) ) THEN
C       
        DO 38 IREC=1,54
          READ(2,100,END=20)
C100      FORMAT(1X)
 38     CONTINUE
C
        GO TO 40
      END IF
C
C Now that a match has been found, output new biennial results.  Write
C new biennial credit Smart line.
C
C Execute the following if OLDFLG is not 1; the following is for new
C data.
C
      IF (OLDFLG.NE.1) THEN
C
C But halt processing if the matching biennial Smart line has a value
C of IMFLG that is not one, because this means that the biennial
C data has already been changed due to RSD effects, and making more
C than one change on the same data would result in nonsense.
C
        IF ( (IMFLG.NE.1).AND.(IMFLG.NE.0) ) THEN
          GO TO 332
        END IF
C
C Found matching biennial data; writing new credits
C
        WRITE(3,235,ERR=335)(SMARK(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,HYBFLG,ETCFLG,OPTION,RSDD
 235    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,I1,'2',I1,1X,'New ',
     &         'biennial credits, Option = ',I1,', Program type = 5, ',
     &         'input data file ',A40)
      ELSE
C
C For old data, can't examine IMFLG--just write it as '2'; write HYBFLG
C and ETCFLG as blanks.
C
        WRITE(3,236,ERR=335)(SMARK(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,OPTION,RSDD
 236    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,' 2 ',1X,'New ',
     &         'biennial credits, Option = ',I1,', Program type = 5, ',
     &         'input data file ',A40)
      ENDIF
C
C Read the biennial credits.
C
      PRINT *,'Reading old biennial credits ... writing new biennial ',
     & 'credits'
C
C Loop for the 18 model years stored in the record.
C 1-5: 1981-1985
C 6-9: 1986-1989
C 10+: 1990+
C
      DO 45 ITECH=1,18
C
C Loop for the 3 pollutants (HC, CO, and NOX) in the record.
C
        DO 46 IP=1,3
C
C Read the 24 age credit values
C
          READ(2,120,END=340,ERR=345)(BCREDT(IBY),IBY=1,24),CRDCOM
 120      FORMAT(24F5.3,A19)
C
C Calculate the new biennial credit.
C
C Note:  new biennial credit = biennial credit -
C biennial credit * F * ( 1 - E )
C
          DO 48 IBY=1,24
C
C Determine which effectiveness to use for this model year
C
      IF(ITECH.LT.6) THEN
        XCESS=UEX3(IBY,IP)
        SEENB=NVSEEB(IBY)
        IF(CSSCEN(6).GT.4) SEENB=1.0
      END IF
      IF((ITECH.GT.5).AND.(ITECH.LT.10)) THEN
        XCESS=UEX4(IBY,IP)
        SEENB=NVSEEB(IBY)
        IF(CSSCEN(6).GT.4) SEENB=1.0
      END IF
      IF(ITECH.GT.9) THEN
        XCESS=UEX5(IBY,IP)
        SEENB=NVSEEB(IBY)
        IF(CSSCEN(6).GT.4) SEENB=1.0
      END IF
C
            NCREDT(IBY) = BCREDT(IBY) -
     & BCREDT(IBY) * SEENB * ( 1.0 - XCESS )
C
 48       CONTINUE
C
          WRITE(3,240,ERR=350)(NCREDT(IBY),IBY=1,24),CRDCOM
 240      FORMAT(24F5.3,A19)
C
 46     CONTINUE
C
 45   CONTINUE
C
C Now go back up to the procedure for finding the next annual Smart
C line that has not been processed yet.
C
      REWIND(2)
C
      GO TO 50
C
C --------------
C ERROR MESSAGES
C --------------
C
 300  CONTINUE
      WRITE(*,301)IN1981       
 301  FORMAT(/,  ' ERROR OPENING INPUT FILE ',A40)
      GO TO 55
C
 305  CONTINUE
      WRITE(*,306)OUT198       
 306  FORMAT(/,  ' ERROR OPENING OUTPUT FILE ',A40)
      GO TO 55
C
 310  CONTINUE
      WRITE(*,311)IN1981       
 311  FORMAT(/,  ' ERROR READING SMART LINE FROM INPUT ',
     &            'FILE ',A40)
      GO TO 55
C
 312  CONTINUE
      WRITE(*,313)OUT198       
 313  FORMAT(/,  ' ERROR WRITING ANNUAL SMART LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 55
C
 315  CONTINUE
      WRITE(*,316)IN1981       
 316  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING ',
     &            'ANNUAL CREDITS FROM INPUT FILE ',/,
     &           ' ',A40)
      GO TO 55
C
 320  CONTINUE
      WRITE(*,321)IN1981       
 321  FORMAT(/,  ' ERROR READING ANNUAL CREDITS FROM INPUT ',
     &            'FILE ',A40)
      GO TO 55
C
 325  CONTINUE
      WRITE(*,326)OUT198       
 326  FORMAT(/,  ' ERROR WRITING ANNUAL CREDIT LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 55
C
 330  CONTINUE
      WRITE(*,331)IN1981       
 331  FORMAT(/,  ' ERROR NO MATCHING BIENNIAL DATA IN ',
     &            'INPUT FILE ',A40)
      GO TO 55
C
 332  CONTINUE
      WRITE(*,333)       
 333  FORMAT(/,  ' ERROR CANNOT APPLY RSD EFFECTS TO DATA ',
     &            'THAT HAS ALREADY BEEN CHANGED ')
      GO TO 55
C
 335  CONTINUE
      WRITE(*,336)OUT198       
 336  FORMAT(/,  ' ERROR WRITING BIENNIAL SMART LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 55
C
 340  CONTINUE
      WRITE(*,341)IN1981       
 341  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING ',
     &            'BIENNIAL CREDITS FROM INPUT FILE ',/,
     &           ' ',A40)
      GO TO 55
C
 345  CONTINUE
      WRITE(*,346)IN1981       
 346  FORMAT(/,  ' ERROR READING BIENNIAL CREDIT FROM ',
     &            'INPUT FILE ',A40)
      GO TO 55
C
 350  CONTINUE
      WRITE(*,351)OUT198       
 351  FORMAT(/,  ' ERROR WRITING BIENNIAL CREDIT LINE TO ',
     &            'OUTPUT FILE ',A40)
C
C --------------
C END PROCEDURES
C --------------
C
 55   CONTINUE
      WRITE(*,355)       
 355  FORMAT(/,  ' CONVERSION ENDED ABNORMALLY',/)
      GO TO 60
C
 20   CONTINUE
      WRITE(*,245)       
 245  FORMAT(/,  ' Conversion ended normally',/)
C
 60   CONTINUE
C
      CLOSE (3)
      CLOSE (2)
C
      RETURN
      END
      SUBROUTINE TECH5(INT12,OUTT12,NVSEEA,UEX1,NVSEEB,UEX2,RSDD)
C
C TECH5 (Clean Screening)
C
C Calculates new sets of IM credits for
C IM programs using Remote Sensing Devices (RSD)
C from the existing Tech 1 & 2 credits
C
C Called by INPUT
C
C Calls no subroutines
C
C Input:
C by user:  none
C common block(s):  OP1
C data file(s):  file whose name is passed in INT12 
C subroutine arguments:  INT12, OUTT12, NVSEEA, UEXCE1, NVSEEB, UEXCE2,
C                        RSDD
C
C Output:
C by screen:  none
C common block(s):  none
C data file(s):  file whose name is passed in OUTT12
C subroutine arguments:  none
C
C Array subscripts:
C
C CR12CO(19,20,5,2) - CR12CO(IBY,IAGE1,ISTR,ITECH)
C CR12HC(19,20,5,2) - CR12HC(IBY,IAGE1,ISTR,ITECH)
C CUTS(4)           - CUTS(ITECH)
C EFF(3)            - EFF(IP)
C EXCESS(3,15,3)    - EXCESS(ITECH,cutpoint,pollutant)
C NVSEEA(25)        - NVSEEA(age of vehicle)
C NVSEEB(25)        - NVSEEB(age of vehicle)
C UEXCE1(3)         - UEXCE1(pollutant:  1=HC, 2=CO, & 3=NOx)
C UEXCE2(3)         - UEXCE2(pollutant:  1=HC, 2=CO, & 3=NOx)
C VMT(25)           - VMT(IBY)
C
C  Local variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C AGE     I   Age at which a veh. first becomes subject to RSD program
C ANNUAL  R   temporary Annual credit
C BIENNL  R   temporary Biennial credit
C CR12CO  R   Array of Tech 1 & 2 CO IM credits
C CR12HC  R   Array of Tech 1 & 2 HC IM credits
C CUTCO   R   Smart line original CO cutpoint
C CUTHC   R   Smart line original HC cutpoint
C CUTNO   R   Smart line original NO cutpoint
C CUTS    R   Array of RSD CO cutpoints by Tech type, 1, 2, and 4+
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C ETCFLG  I   An extra flag in IMDATA.FOR, in TECH12.FOR, it serves as the
C              IMLFG (see below) for Tech 2 data
C EXCESS  R   See routines R1 and R2
C HYBFLG  I   Hybrid program flag
C IAGE    I   Counter for age when first inspected 
C IBY     I   Counter for Benefit Years
C IBY     I   Counter for Benefit Years
C ILINE   I   Counter for Smart lines
C IMFLG   I   Tech 1 I/M flag:  1 if no RSD program modifications done on
C              Tech 1 part of TECH12.D; 2 if Tech 1 data was changed
C INT12   C   Character string name of the TECH12.D type input file
C ISMART  I   Counter for Smart strip
C ISTR    I   Counter for Stringency
C ITECH   I   Counter for Tech type
C NUMBER  I   Total number of veh. subject to inspection program
C NVSEEA  R   Fraction of vehicles seen by RSD, annual programs
C NVSEEB  R   Fraction of vehicles seen by RSD, biennial programs
C OLDFLG  I   If old data, OLDFLG=1, if new, 0.
C OPTION  I   Option--see RSDDRV
C OUTT12  C   Character string name of the TECDATA.D type output file
C RSDD    C   Char. string name of the input data file
C SCAN    I   Number of valid veh. measurements per month at RSD sites
C SMART   I   Array of the Smart strip values
C THREE   C   Character string name for the flags HYBFLG, IMFLG, and
C              ETCFLG if they exist, otherwise it contains part of the
C              comment line
C TIMES   I   Minimum number of times a vehicle must be scanned between
C              inspections to be eligible for targetting.
C UEXCE1  R   RSD effectiveness, Tech 1 vehicles
C UEXCE2  R   RSD effectiveness, Tech 2 vehicles
C VMT     I   Vehicle miles travelled by age
C
C
C Notes:  Annual and biennial information is stored in an upper and
C         lower triangular fashion.
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 22-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C
      CHARACTER INT12*40, OUTT12*40, RSDD*40, THREE*3
C
      INTEGER AGE, ETCFLG, HYBFLG, IAGE, IBY, IMFLG, ISMART, ISTR
      INTEGER ITECH, NUMBER, OLDFLG, OPTION, SCAN, SMART(4), TIMES
      INTEGER VMT(25)
      INTEGER CSSCEN(6), NEWPHS, NEWRSD
C
      REAL ANNUAL, BIENNL, CR12CO(19,20,5,2), CR12HC(19,20,5,2)
      REAL CUTCO, CUTHC, CUTNO, CUTS(4), EFF(3), EXCESS(3,15,3)
      REAL NVSEEA(25), NVSEEB(25)
C     REAL UEXCE1(3), UEXCE2(3)
      REAL UEX1(25,3), UEX2(25,3)
C     REAL UEX3(25,3), UEX4(25,3), UEX5(25,3)
      REAL CLEANX(3,4,3,2), CSCRN(25,4), VEPX(25,4,3), ACSCRN(25,4)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
      COMMON /PPEFF/ NEWPHS, NEWRSD, CSCRN, CLEANX, VEPX, ACSCRN, CSSCEN
C
C If old data, OLDFLG is set to 1; first initialize OLDFLG to 0
C
      OLDFLG=0
C
      WRITE(*,200)
 200  FORMAT(/,  ' Starting to alter 1974 and older model ',
     &            'years and 1975 through 1980 model years ',/,
     &           ' vehicles I/M credits to include Remote ',
     &            'Sensing Devices credits',/,
     &           ' ---------------------------------------',
     &            '---------------------------------------')
C
C Open filename in INT12 for input as unit 12
C Open filename in OUTT12 for output as unit 13
C
      OPEN(12,FILE=INT12, ERR=300,STATUS='OLD')
      OPEN(13,FILE=OUTT12,ERR=310)
C
 90   CONTINUE
C
      READ(12,100,END=97,ERR=320) (SMART(ISMART),ISMART=1,4),
     &     CUTHC,CUTCO,CUTNO,THREE
  100 FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,A3)
C
      READ(THREE,105,ERR=15) HYBFLG,IMFLG,ETCFLG
  105 FORMAT(3I1)
C
      GO TO 16
C
 15   CONTINUE
C
C When there is a misread of the flags, the data is of the old type;
C set OLDFLG to 1 and skip the check on IMFLG
C
      OLDFLG=1
      GO TO 17
C
 16   CONTINUE
C
C Reading a Smart line and associated data from the input file
C
C If IMFLG is not one, this means that Tech 1 or Tech 2 data has been
C changed using RSD effects.  Issue error and halt.
C
      IF ( (IMFLG.NE.1).AND.(IMFLG.NE.0) ) THEN
        GO TO 325
      END IF
C
 17   CONTINUE
C
C Read in Annual and Biennial credits for HC
C Loop for the two (2) ITECHs stored in the record.
C
      DO 10 ITECH=1,2
C
C Loop for the five (5) stringency values in the record.
C
        DO 12 ISTR=1,5
C
C Loop for the values in the record
C
          DO 14 IAGE1=1,20

            READ(12,110,END=330,ERR=335)
     & (CR12HC(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
  110       FORMAT(19F4.3)
  14      CONTINUE
C
  12    CONTINUE

  10  CONTINUE
C
C Read in Annual and Biennial credits for CO
C
      DO 20 ITECH=1,2
C
        DO 22 ISTR=1,5
C
          DO 24 IAGE1=1,20
            READ(12,110,END=340,ERR=345)
     & (CR12CO(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
 24       CONTINUE
C
 22     CONTINUE

 20   CONTINUE
C
C Process the data and then write it to the output file
C
      DO 30 ITECH=1,2
C
        DO 32 ISTR=1,5
C
          DO 34 IBY=1,19
C
            DO 36 IAGE=1,19
C
C Only let the benefit year counter IBY and the age at first
C inspection counter be in the upper triangular region of Annual
C data.  (Another way of looking at this is that the actual age of a
C vehicle is its age at first inspection plus the time elapsed since its
C first inspection--current benefit year minus first benefit year.
C The actual age is thus IAGE+IBY-1.  Since actual age cannot exceed 
C 19 years, IAGE+IBY-1 must be .LE. 19.)
C 
              IF ((IBY+IAGE).GT.20) THEN
                GO TO 34
              END IF
C
C HC credits
C
              ANNUAL=CR12HC(IBY,IAGE,ISTR,ITECH)
              BIENNL=CR12HC(20-IBY,21-IAGE,ISTR,ITECH)
C
              IF (ITECH.EQ.1) THEN
C
                SEENA=NVSEEA(IAGE+IBY-1)
                IF(CSSCEN(6).GT.4) SEENA=1.0
                CR12HC(IBY,IAGE,ISTR,ITECH) = ANNUAL -
     &             ANNUAL * SEENA * ( 1.0 - UEX1(IAGE,1) )
C
C Note:  new annual credit = annual credit -
C annual credit * F * ( 1 - E )
C
                SEENA=NVSEEB(IAGE+IBY-1)
                IF(CSSCEN(6).GT.4) SEENB=1.0
                CR12HC(20-IBY,21-IAGE,ISTR,ITECH) = BIENNL -
     &             BIENNL * SEENB * ( 1.0 - UEX1(IAGE,1) )
C
C Note:  new biennial credit = biennial credit -
C biennial credit * F * ( 1 - E )
C
              ELSE
C
C ITECH is 2
C
                SEENA=NVSEEA(IAGE+IBY-1)
                IF(CSSCEN(6).GT.4) SEENA=1.0
                CR12HC(IBY,IAGE,ISTR,ITECH) = ANNUAL -
     &             ANNUAL * SEENA * ( 1.0 - UEX2(IAGE,1) )
C
                SEENB=NVSEEB(IAGE+IBY-1)
                IF(CSSCEN(6).GT.4) SEENB=1.0
                CR12HC(20-IBY,21-IAGE,ISTR,ITECH) = BIENNL -
     &             BIENNL * SEENB * ( 1.0 - UEX2(IAGE,1) )
C
              END IF
C
C Note that NVSEEA and NVSEEB are functions of the actual age of
C the vehicle.  See above.
C
C CO credits
C
              ANNUAL=CR12CO(IBY,IAGE,ISTR,ITECH)
              BIENNL=CR12CO(20-IBY,21-IAGE,ISTR,ITECH)
C
              IF (ITECH.EQ.1) THEN
C
                SEENA=NVSEEA(IAGE+IBY-1)
                IF(CSSCEN(6).GT.4) SEENA=1.0
                CR12CO(IBY,IAGE,ISTR,ITECH) = ANNUAL -
     &             ANNUAL * SEENA * ( 1.0 - UEX1(IAGE,2) )
C
                SEENB=NVSEEB(IAGE+IBY-1)
                IF(CSSCEN(6).GT.4) SEENB=1.0
                CR12CO(20-IBY,21-IAGE,ISTR,ITECH) = BIENNL -
     &             BIENNL * SEENB * ( 1.0 - UEX1(IAGE,2) )
C
              ELSE
C
C ITECH is 2
C
                SEENA=NVSEEA(IAGE+IBY-1)
                IF(CSSCEN(6).GT.4) SEENA=1.0
                CR12CO(IBY,IAGE,ISTR,ITECH) = ANNUAL -
     &             ANNUAL * SEENA * ( 1.0 - UEX2(IAGE,2) )
C
                SEENB=NVSEEB(IAGE+IBY-1)
                IF(CSSCEN(6).GT.4) SEENB=1.0
                CR12CO(20-IBY,21-IAGE,ISTR,ITECH) = BIENNL -
     &             BIENNL * SEENB * ( 1.0 - UEX2(IAGE,2) )
C
              END IF
C
 36         CONTINUE
C
 34       CONTINUE
C
 32     CONTINUE
C
 30   CONTINUE
C
C Write processed data to the output file; first rewrite Smart line
C
C If OLDFLG is not 1, then the data is of the new type; output the
C following
C
      IF (OLDFLG.NE.1) THEN
        WRITE(13,240,ERR=350)(SMART(ISMART),ISMART=1,4),CUTHC,CUTCO,
     & CUTNO,HYBFLG,ETCFLG,OPTION,RSDD
  240   FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,I1,'2',I1,' New ',
     &         'credits, Option = ',I1,', Program type = 5, ',
     &         'input data file ',A40)
      ELSE
C
C Data is of the old type
C
        WRITE(13,245,ERR=350)(SMART(ISMART),ISMART=1,4),CUTHC,CUTCO,
     & CUTNO,OPTION,RSDD
  245  FORMAT(4I1,1X,F4.0,1X,F4.2,1X,F4.0,1X,' 2 ',' New ',
     &         'credits, Option = ',I1,', Program type = 5, ',
     &         'input data file ',A40)
      ENDIF
C
C Write the HC data
C
      DO 40 ITECH=1,2
C
        DO 42 ISTR=1,5
C
          DO 44 IAGE1=1,20
C
            WRITE(13,250,ERR=350)
     & (CR12HC(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
  250       FORMAT(19F4.3)
  44      CONTINUE
C
  42    CONTINUE

  40  CONTINUE
C
C Write the CO data
C
      DO 50 ITECH=1,2
C
        DO 52 ISTR=1,5
C
          DO 54 IAGE1=1,20
C
            WRITE(13,250,ERR=350)
     & (CR12CO(IBY,IAGE1,ISTR,ITECH),IBY=1,19)
 54       CONTINUE
C
 52     CONTINUE

 50   CONTINUE
C
C Loop back to the beginning to read next Smart line and associated data
C
      GO TO 90
C
C ---------------------------
C CONSOLIDATED ERROR MESSAGES
C ---------------------------
C
 300  CONTINUE
      WRITE(*,301)INT12
 301  FORMAT(/,  ' ERROR OPENING INPUT FILE ',A40)
      GOTO 96
C
 310  CONTINUE
      WRITE(*,311)OUTT12
 311  FORMAT(/,  ' ERROR OPENING OUTPUT FILE ',A40)
      GOTO 96
C
 320  CONTINUE
      WRITE(*,321)INT12
 321  FORMAT(/,  ' ERROR READING SMART LINE FROM INPUT ',
     &            'FILE ',A40)
      GOTO 96
C
 325  CONTINUE
      WRITE(*,326)
 326  FORMAT(/,  ' ERROR CANNOT APPLY RSD EFFECTS--DATA ',
     &            'HAVE ALREADY BEEN CHANGED')
      GOTO 96
C
 330  CONTINUE
      WRITE(*,331)INT12
 331  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING HC ',
     &            'CREDITS FROM INPUT FILE ',A40)
      GOTO 96
C
 335  CONTINUE
      WRITE(*,336)INT12
 336  FORMAT(/,  ' ERROR READING HC CREDITS FROM INPUT ',
     &            'FILE ',A40)
      GOTO 96
C
 340  CONTINUE
      WRITE(*,341)INT12
 341  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING CO ',
     &            'CREDITS FROM INPUT FILE ',A40)
      GOTO 96
C
 345  CONTINUE
      WRITE(*,346)INT12
 346  FORMAT(/,  ' ERROR READING CO CREDITS FROM INPUT ',
     &            'FILE ',A40)
      GOTO 96
C
 350  CONTINUE
      WRITE(*,351)OUTT12
 351  FORMAT(/,  ' ERROR WRITING TO OUTPUT FILE ',A40)
      GOTO 96
C
C ---------------------------------
C CLOSE DATA FILES AND EXIT PROGRAM
C ---------------------------------
C
 96   WRITE(*,'(A)')'0CONVERSION ENDED ABNORMALLY.'
      GOTO 98
C
 97   WRITE(*,'(A)')'0Conversion ended normally.'
C
 98   CONTINUE
C
      CLOSE (13)
      CLOSE (12)
C
      RETURN
      END
      SUBROUTINE DATA2(ACTION,RSDD,*)
C
C DATA2 reads in the information stored in file
C RSD.D, which supplies data needed to analyze any of the RSD options.
C
C Input: 
C by user:  none
C common blocks:  none
C data file(s):  file with name in RSDD
C subroutine arguments:  none
C
C Output:
C by screen:  none
C data file(s):  none
C common blocks:  FILES, OP1, OP2, OP3
C subroutine arguments:  ACTION
C
C Array subscripts:
C
C CFAIL(25)      - CFAIL(IBY)
C CUTS(4)        - CUTS(1:  Tech type 1, 2:  2, and 3:  4+)
C EFF(3)         - EFF(IP)
C EOPT3(3,15,3)  - EOPT3(Tech type, cutpoint, pollutant)
C EXCESS(3,15,3) - EXCESS(Tech type,ICUT,IP)
C RFAIL(25)      - RFAIL(IBY)
C SENT(25)       - SENT(IBY)
C TOTAL(25)      - TOTAL(IBY)
C VMT(25)        - VMT(IBY)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   ---- -  -   -    -     -      -       -        -         -
C AGE     I   Age at which a car first becomes subject to the program
C ACTION  I   Program Type 1, 2, 3, 4, or 5--see RSDDRV
C CARD    I   Three-digit card number from input file
C CFAIL   I   Current number of cars that have failed regular IM testing
C CHARS   C*40 Character data from input file
C CUTS    R   Array of RSD CO test cutpoints for vehicle groups
C              pre-1975, 1975-1980, and post-1980, Clean Screen NOx Cutpoint
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C EOPT3   R   E value for Option 3, set up the same way as EXCESS
C EXCESS  R   Array of user supplied RSD excess identified fractions
C              dependent upon Tech type, CO cut point, and pollutant,
C              used in Options 1 and 2
C NUMBER  I   Total number of vehicles subject to the inspection program
C OPTION  I   Option number 1, 2, or 3--see RSDDRV
C RFAIL   I   Number of cars expected to fail next years special IM
C              program for cars targetted by RSD
C RSDD    C   Name of input data file
C SCAN    I   Number of times a vehicle must be scanned to be eligible
C              for targetting
C SENT    I   Number of vehicles sent to special IM program via RSD
C TIMES   I   Times per month the RSD sites scanned valid vehicles.
C TOTAL   I   Total vehicles in RSD program, by age
C VMT     I   Vehicle miles travelled, by age
C
C
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 20-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 26-Feb-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C
C Declare variables
C
      CHARACTER CHARS*40, IN1981*40, IN198H*40, INT12*40, INT12H*40
      CHARACTER OUT198*40, OUT19H*40, OUTT12*40, OUTT1H*40, RSDD*40
      CHARACTER INPPEF*40, INPPEH*40, OUTPPE*40, OUTPPH*40
C
      INTEGER ACTION, AGE, CARD, CFAIL(25), NUMBER, OPTION
      INTEGER RFAIL(25), SCAN, SENT(25), TIMES, TOTAL(25), VMT(25)
C
      REAL CUTS(4), EFF(3), EOPT3(3,15,3), EXCESS(3,15,3)
      REAL CLEANX(3,4,3,2), CSCRN(25,4), VEPX(25,4,3), ACSCRN(25,4)
      INTEGER CSSCEN(6), NEWPHS, NEWRSD
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
      COMMON /OP2/SENT,TOTAL
      COMMON /OP3/CFAIL,RFAIL,EOPT3
      COMMON /FILES/IN1981,IN198H,INT12,INT12H,OUT198,OUT19H,OUTT12,
     &              OUTT1H, INPPEF, INPPEH, OUTPPE, OUTPPH
      COMMON /PPEFF/ NEWPHS, NEWRSD, CSCRN, CLEANX, VEPX, ACSCRN, CSSCEN
C
C First, place hard-coded default data into input data arrays
C
C INPUT/OUTPUT FILENAMES 
C (CARDS 005, 006, 007, 008, 015, 016, 017, 018)
C
      IN1981='IMDATA.D'
      IN198H='HYBRID.IMC'
      INT12= 'TECH12.D'
      INT12H='TECH12.D'
      OUT198='RSDDATA.D'
      OUT19H='RSDDATA.H'
      OUTT12='TECDATA.D'
      OUTT1H='TECDATA.H'
C
C Initialize user supplied RSD effectiveness flag
C
      NEWRSD=1
      NEWPHS=1
C
C Pressure/Purge Benefit INPUT/OUTPUT Filenames
C (CARDS 009, 010, 011, 012)
C
      INPPEF='PPEFFM5.D'
      INPPEH='PPEFF.D'
      OUTPPE='PPM5RSD.D'
      OUTPPH='PPHYRSD.D'
C
C GENERAL DATA AND OPTION 1 DATA (CARDS 021, 022, 023, 024, 031, 032,
C 033, 034, 041, 042, 043, 101 - 125)
C
      NUMBER=1000000
      SCAN=50000
      TIMES=1
      CUTS(1)=3.0
      CUTS(2)=3.0
      CUTS(3)=3.0
      CUTS(4)=1000.
      AGE=1
      EFF(1)=0.5
      EFF(2)=0.5
      EFF(3)=0.5
C
      VMT(1)=14390
      VMT(2)=12612
      VMT(3)=12875
      VMT(4)=12180
      VMT(5)=11522
      VMT(6)=10899
      VMT(7)=10310
      VMT(8)=9751
      VMT(9)=9225
      VMT(10)=8726
      VMT(11)=8254
      VMT(12)=7807
      VMT(13)=7386
      VMT(14)=6987
      VMT(15)=6608
      VMT(16)=6251
      VMT(17)=5913
      VMT(18)=5594
      VMT(19)=5291
      VMT(20)=5005
      VMT(21)=4735
      VMT(22)=4478
      VMT(23)=4237
      VMT(24)=4007
      VMT(25)=3790
C
C OPTION 2 DATA have no defaults
C
C OPTION 3 DATA total current failures and commitment to a number of
C failures values have no defaults.  E values for Option 3 are in CARDS
C 401 - 415, 501 - 515, 601 - 615
C
C Fortran first fastest convention for indices:   EOPT3(1,1,1), (2,1,1),
C (3,1,1), (1,2,1), ... , i.e., (Tech 1, 0.5%, HC), (Tech 2, 0.5%, HC),
C (Tech 4, 0.5%, HC), (Tech 1, 1.0%, HC), ...
C                  (1,1,1)  (2,1,1)  (3,1,1)  (1,2,1)  (2,2,1)  (3,2,1)
C HC
      EOPT3(1,1,1)=3.024
      EOPT3(2,1,1)=3.024
      EOPT3(3,1,1)=2.927
      EOPT3(1,2,1)=2.980
      EOPT3(2,2,1)=2.980
      EOPT3(3,2,1)=3.027
      EOPT3(1,3,1)=3.758
      EOPT3(2,3,1)=3.758
      EOPT3(3,3,1)=3.513
      EOPT3(1,4,1)=4.321
      EOPT3(2,4,1)=4.321
      EOPT3(3,4,1)=3.861
      EOPT3(1,5,1)=2.067
      EOPT3(2,5,1)=2.067
      EOPT3(3,5,1)=4.481
      EOPT3(1,6,1)=2.363
      EOPT3(2,6,1)=2.363
      EOPT3(3,6,1)=5.316
      EOPT3(1,7,1)=2.645
      EOPT3(2,7,1)=2.645
      EOPT3(3,7,1)=5.862
      EOPT3(1,8,1)=1.932
      EOPT3(2,8,1)=1.932
      EOPT3(3,8,1)=6.331
      EOPT3(1,9,1)=1.165
      EOPT3(2,9,1)=1.165
      EOPT3(3,9,1)=6.374
      EOPT3(1,10,1)=1.359
      EOPT3(2,10,1)=1.359
      EOPT3(3,10,1)=6.043
      EOPT3(1,11,1)=1.440
      EOPT3(2,11,1)=1.440
      EOPT3(3,11,1)=7.045
      EOPT3(1,12,1)=1.800
      EOPT3(2,12,1)=1.800
      EOPT3(3,12,1)=9.190
      EOPT3(1,13,1)=1.800
      EOPT3(2,13,1)=1.800
      EOPT3(3,13,1)=8.650
      EOPT3(1,14,1)=2.262
      EOPT3(2,14,1)=2.262
      EOPT3(3,14,1)=9.779
      EOPT3(1,15,1)=1.334
      EOPT3(2,15,1)=1.334
      EOPT3(3,15,1)=10.647
C CO
      EOPT3(1,1,2)=1.831
      EOPT3(2,1,2)=1.831
      EOPT3(3,1,2)=1.984
      EOPT3(1,2,2)=1.922
      EOPT3(2,2,2)=1.922
      EOPT3(3,2,2)=2.437
      EOPT3(1,3,2)=2.043
      EOPT3(2,3,2)=2.043
      EOPT3(3,3,2)=2.794
      EOPT3(1,4,2)=2.329
      EOPT3(2,4,2)=2.329
      EOPT3(3,4,2)=3.134
      EOPT3(1,5,2)=2.618
      EOPT3(2,5,2)=2.618
      EOPT3(3,5,2)=3.682
      EOPT3(1,6,2)=2.931
      EOPT3(2,6,2)=2.931
      EOPT3(3,6,2)=4.264
      EOPT3(1,7,2)=3.016
      EOPT3(2,7,2)=3.016
      EOPT3(3,7,2)=4.861
      EOPT3(1,8,2)=3.367
      EOPT3(2,8,2)=3.367
      EOPT3(3,8,2)=5.361
      EOPT3(1,9,2)=4.135
      EOPT3(2,9,2)=4.135
      EOPT3(3,9,2)=5.002
      EOPT3(1,10,2)=4.339
      EOPT3(2,10,2)=4.339
      EOPT3(3,10,2)=5.018
      EOPT3(1,11,2)=4.934
      EOPT3(2,11,2)=4.934
      EOPT3(3,11,2)=6.051
      EOPT3(1,12,2)=6.167
      EOPT3(2,12,2)=6.167
      EOPT3(3,12,2)=6.644
      EOPT3(1,13,2)=6.167
      EOPT3(2,13,2)=6.167
      EOPT3(3,13,2)=8.285
      EOPT3(1,14,2)=6.356
      EOPT3(2,14,2)=6.356
      EOPT3(3,14,2)=8.469
      EOPT3(1,15,2)=6.368
      EOPT3(2,15,2)=6.368
      EOPT3(3,15,2)=6.340
C NOx
      EOPT3(1,1,3)=0.927
      EOPT3(2,1,3)=0.927
      EOPT3(3,1,3)=0.920
      EOPT3(1,2,3)=0.991
      EOPT3(2,2,3)=0.991
      EOPT3(3,2,3)=0.915
      EOPT3(1,3,3)=0.887
      EOPT3(2,3,3)=0.887
      EOPT3(3,3,3)=0.866
      EOPT3(1,4,3)=0.922
      EOPT3(2,4,3)=0.922
      EOPT3(3,4,3)=0.838
      EOPT3(1,5,3)=0.780
      EOPT3(2,5,3)=0.780
      EOPT3(3,5,3)=0.786
      EOPT3(1,6,3)=0.599
      EOPT3(2,6,3)=0.599
      EOPT3(3,6,3)=0.873
      EOPT3(1,7,3)=0.471
      EOPT3(2,7,3)=0.471
      EOPT3(3,7,3)=0.946
      EOPT3(1,8,3)=0.361
      EOPT3(2,8,3)=0.361
      EOPT3(3,8,3)=0.733
      EOPT3(1,9,3)=0.457
      EOPT3(2,9,3)=0.457
      EOPT3(3,9,3)=0.761
      EOPT3(1,10,3)=0.503
      EOPT3(2,10,3)=0.503
      EOPT3(3,10,3)=0.427
      EOPT3(1,11,3)=0.496
      EOPT3(2,11,3)=0.496
      EOPT3(3,11,3)=0.576
      EOPT3(1,12,3)=0.000
      EOPT3(2,12,3)=0.000
      EOPT3(3,12,3)=0.305
      EOPT3(1,13,3)=0.000
      EOPT3(2,13,3)=0.000
      EOPT3(3,13,3)=0.457
      EOPT3(1,14,3)=0.000
      EOPT3(2,14,3)=0.000
      EOPT3(3,14,3)=0.610
      EOPT3(1,15,3)=0.000
      EOPT3(2,15,3)=0.000
      EOPT3(3,15,3)=0.915
C
C General RSD effectivenesses are in CARDS
C 701 - 715, 801 - 815, 901 - 915
C
C Fortran first fastest convention for indices:  UEXCES(1,1,1), (2,1,1),
C (3,1,1), (1,2,1), ... , i.e., (Tech 1, 0.5%, HC), (Tech 2, 0.5%, HC),
C (Tech 4, 0.5%, HC), (Tech 1, 1.0%, HC), ...
C                  (1,1,1)  (2,1,1)  (3,1,1)  (1,2,1)  (2,2,1)  (3,2,1)
C HC
      EXCESS(1,1,1)=0.543
      EXCESS(2,1,1)=0.543
      EXCESS(3,1,1)=0.570
      EXCESS(1,2,1)=0.487
      EXCESS(2,2,1)=0.487
      EXCESS(3,2,1)=0.433
      EXCESS(1,3,1)=0.487
      EXCESS(2,3,1)=0.487
      EXCESS(3,3,1)=0.387
      EXCESS(1,4,1)=0.487
      EXCESS(2,4,1)=0.487
      EXCESS(3,4,1)=0.348
      EXCESS(1,5,1)=0.272
      EXCESS(2,5,1)=0.272
      EXCESS(3,5,1)=0.319
      EXCESS(1,6,1)=0.272
      EXCESS(2,6,1)=0.272
      EXCESS(3,6,1)=0.262
      EXCESS(1,7,1)=0.262
      EXCESS(2,7,1)=0.262
      EXCESS(3,7,1)=0.217
      EXCESS(1,8,1)=0.184
      EXCESS(2,8,1)=0.184
      EXCESS(3,8,1)=0.182
      EXCESS(1,9,1)=0.110
      EXCESS(2,9,1)=0.110
      EXCESS(3,9,1)=0.150
      EXCESS(1,10,1)=0.110
      EXCESS(2,10,1)=0.110
      EXCESS(3,10,1)=0.109
      EXCESS(1,11,1)=0.095
      EXCESS(2,11,1)=0.095
      EXCESS(3,11,1)=0.071
      EXCESS(1,12,1)=0.095
      EXCESS(2,12,1)=0.095
      EXCESS(3,12,1)=0.060
      EXCESS(1,13,1)=0.095
      EXCESS(2,13,1)=0.095
      EXCESS(3,13,1)=0.046
      EXCESS(1,14,1)=0.088
      EXCESS(2,14,1)=0.088
      EXCESS(3,14,1)=0.039
      EXCESS(1,15,1)=0.022
      EXCESS(2,15,1)=0.022
      EXCESS(3,15,1)=0.028
C CO
      EXCESS(1,1,2)=0.945
      EXCESS(2,1,2)=0.945
      EXCESS(3,1,2)=0.596
      EXCESS(1,2,2)=0.899
      EXCESS(2,2,2)=0.899
      EXCESS(3,2,2)=0.499
      EXCESS(1,3,2)=0.758
      EXCESS(2,3,2)=0.758
      EXCESS(3,3,2)=0.442
      EXCESS(1,4,2)=0.751
      EXCESS(2,4,2)=0.751
      EXCESS(3,4,2)=0.396
      EXCESS(1,5,2)=0.676
      EXCESS(2,5,2)=0.676
      EXCESS(3,5,2)=0.352
      EXCESS(1,6,2)=0.662
      EXCESS(2,6,2)=0.662
      EXCESS(3,6,2)=0.278
      EXCESS(1,7,2)=0.584
      EXCESS(2,7,2)=0.584
      EXCESS(3,7,2)=0.213
      EXCESS(1,8,2)=0.489
      EXCESS(2,8,2)=0.489
      EXCESS(3,8,2)=0.178
      EXCESS(1,9,2)=0.467
      EXCESS(2,9,2)=0.467
      EXCESS(3,9,2)=0.133
      EXCESS(1,10,2)=0.420
      EXCESS(2,10,2)=0.420
      EXCESS(3,10,2)=0.107
      EXCESS(1,11,2)=0.398
      EXCESS(2,11,2)=0.398
      EXCESS(3,11,2)=0.072
      EXCESS(1,12,2)=0.398
      EXCESS(2,12,2)=0.398
      EXCESS(3,12,2)=0.053
      EXCESS(1,13,2)=0.398
      EXCESS(2,13,2)=0.398
      EXCESS(3,13,2)=0.044
      EXCESS(1,14,2)=0.308
      EXCESS(2,14,2)=0.308
      EXCESS(3,14,2)=0.034
      EXCESS(1,15,2)=0.205
      EXCESS(2,15,2)=0.205
      EXCESS(3,15,2)=0.017
C NOx
      EXCESS(1,1,3)=0.436
      EXCESS(2,1,3)=0.436
      EXCESS(3,1,3)=0.283
      EXCESS(1,2,3)=0.423
      EXCESS(2,2,3)=0.423
      EXCESS(3,2,3)=0.178
      EXCESS(1,3,3)=0.335
      EXCESS(2,3,3)=0.335
      EXCESS(3,3,3)=0.122
      EXCESS(1,4,3)=0.295
      EXCESS(2,4,3)=0.295
      EXCESS(3,4,3)=0.091
      EXCESS(1,5,3)=0.232
      EXCESS(2,5,3)=0.232
      EXCESS(3,5,3)=0.059
      EXCESS(1,6,3)=0.146
      EXCESS(2,6,3)=0.146
      EXCESS(3,6,3)=0.054
      EXCESS(1,7,3)=0.118
      EXCESS(2,7,3)=0.118
      EXCESS(3,7,3)=0.042
      EXCESS(1,8,3)=0.067
      EXCESS(2,8,3)=0.067
      EXCESS(3,8,3)=0.018
      EXCESS(1,9,3)=0.067
      EXCESS(2,9,3)=0.067
      EXCESS(3,9,3)=0.015
      EXCESS(1,10,3)=0.063
      EXCESS(2,10,3)=0.063
      EXCESS(3,10,3)=0.009
      EXCESS(1,11,3)=0.052
      EXCESS(2,11,3)=0.052
      EXCESS(3,11,3)=0.006
      EXCESS(1,12,3)=0.000
      EXCESS(2,12,3)=0.000
      EXCESS(3,12,3)=0.003
      EXCESS(1,13,3)=0.000
      EXCESS(2,13,3)=0.000
      EXCESS(3,13,3)=0.003
      EXCESS(1,14,3)=0.000
      EXCESS(2,14,3)=0.000
      EXCESS(3,14,3)=0.003
      EXCESS(1,15,3)=0.000
      EXCESS(2,15,3)=0.000
      EXCESS(3,15,3)=0.003
C
C Second, overwrite input data arrays with information obtained from
C the input data file
C
C Open the input data file
C
      OPEN(UNIT=2,FILE=RSDD,STATUS='OLD',ERR=350)
C
C Read data from the input data file
C
      WRITE(UNIT=*,FMT=200)RSDD
 200  FORMAT(/,  ' Now reading data from the input data file ',
     &       1X,A40,/)
C
C Start loop to sequentially examine every card
C
 10   CONTINUE
C
C Read current card (leave loop at eof; trap any read errors that
C  occur)
C
      READ(UNIT=2,FMT=210,END=99,ERR=352)CARD,CHARS
 210  FORMAT(I3,1X,A40)
C
C If current card is 000, a comment card, read next card
C
      IF (CARD.EQ.0) GO TO 10
C
      IF (CARD.LE.100) THEN
C
C Find control values, filenames, general information, and some
C Option 1 data
C
C               1  2  3  4  5  6  7  8  9  0  1  2  3  4  5  6  7  8  9
       GO TO ( 1, 2,20,20, 5, 6, 7, 8, 9,999,11,12,20,20,15,16,17,18,20,
     &      20,21,22,23,24,20,20,20,20,20,20,31,32,33,34,35,36,37,38,39,
     &      20,41,42,43,44) CARD
C            0  1  2  3  4  5  6  7  8  9  0  1  2  3
        GO TO 20
 1      READ(UNIT=CHARS(10:11),FMT=*,ERR=360)OPTION
        IF ( (OPTION.LT.1).OR.(OPTION.GT.3) ) GO TO 354
        GO TO 10
 2      READ(UNIT=CHARS(10:11),FMT=*,ERR=360)ACTION
        IF ( (ACTION.LT.1).OR.(ACTION.GT.5) ) GO TO 356
        GO TO 10
 5      IN1981=CHARS
        GO TO 10
 6      IN198H=CHARS
        GO TO 10
 7      INT12=CHARS
        GO TO 10
 8      INT12H=CHARS
        GO TO 10
 9      INPPEF=CHARS
        GO TO 10
 999    INPPEH=CHARS
        GO TO 10
 11     OUTPPE=CHARS
        GO TO 10
 12     OUTPPH=CHARS
        GO TO 10
 15     OUT198=CHARS
        GO TO 10
 16     OUT19H=CHARS
        GO TO 10
 17     OUTT12=CHARS
        GO TO 10
 18     OUTT1H=CHARS
        GO TO 10
 21     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)NUMBER
        GO TO 10
 22     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)SCAN
        GO TO 10
 23     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)TIMES
        IF ( (TIMES.LT.1).OR.(TIMES.GT.11) ) GO TO 362
        GO TO 10
 24     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)AGE
        IF ( (AGE.LT.1).OR.(AGE.GT.24) ) GO TO 362
        GO TO 10
 31     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)CUTS(1)
        IF ( ( (CUTS(1).LT.0.5).OR.(CUTS(1).GT.7.5) ).AND.
     &       (  CUTS(1).NE.99.9  ) ) GO TO 362
        GO TO 10
 32     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)CUTS(2)
        IF ( ( (CUTS(2).LT.0.5).OR.(CUTS(2).GT.7.5) ).AND.
     &       (  CUTS(2).NE.99.9  ) ) GO TO 362
        GO TO 10
 33     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)CUTS(3)
        IF ( ( (CUTS(3).LT.0.5).OR.(CUTS(3).GT.7.5) ).AND.
     &       (  CUTS(3).NE.99.9  ) ) GO TO 362
        GO TO 10
 34     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)CSSCEN(1)
        IF ( (CSSCEN(1).LT.1).OR.(CSSCEN(1).GT.2) ) GO TO 362
        GO TO 10
 35     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)CSSCEN(2)
        IF ( (CSSCEN(2).LT.1).OR.(CSSCEN(2).GT.2) ) GO TO 362
        GO TO 10
 36     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)CSSCEN(3)
        IF ( (CSSCEN(3).LT.1).OR.(CSSCEN(3).GT.2) ) GO TO 362
        GO TO 10
 37     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)CSSCEN(4)
        IF ( (CSSCEN(4).LT.1).OR.(CSSCEN(4).GT.2) ) GO TO 362
        GO TO 10
 38     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)CSSCEN(5)
        IF ( (CSSCEN(5).LT.1).OR.(CSSCEN(5).GT.2) ) GO TO 362
        GO TO 10
 39     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)CSSCEN(6)
        IF ( (CSSCEN(6).LT.1).OR.(CSSCEN(6).GT.8) ) GO TO 362
        GO TO 10
 41     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EFF(1)
        IF ( (EFF(1).LE.0.0).OR.(EFF(1).GT.1.0) ) GO TO 362
        GO TO 10
 42     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EFF(2)
        IF ( (EFF(2).LE.0.0).OR.(EFF(2).GT.1.0) ) GO TO 362
        GO TO 10
 43     READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EFF(3)
        IF ( (EFF(3).LE.0.0).OR.(EFF(3).GT.1.0) ) GO TO 362
        GO TO 10
 44     READ(UNIT=CHARS(1:11),FMT=*,ERR=360) NEWPHS
        IF ( (NEWPHS.LE.0).OR.(NEWPHS.GT.2) ) GO TO 362
        IF(NEWRSD.EQ.2) NEWPHS=1
        GO TO 10
      ELSE
C
C 101 =< CARD =< 125
C
        IF ( (CARD.GE.101).AND.(CARD.LE.125) ) THEN
C
C Find VMT data (for Option 1)
C
          READ(UNIT=CHARS(1:11),FMT=*,ERR=360)VMT(CARD-100)
          GO TO 10
        ELSE
C
C 201 =< CARD =< 225
C
          IF ( (CARD.GE.201).AND.(CARD.LE.225) ) THEN
C
C Find total vehicles by age and vehicles sent to I/M via RSD
C by age (for Option 2)
C
            READ(UNIT=CHARS(1:11),FMT=*,ERR=360)TOTAL(CARD-200)
            READ(UNIT=CHARS(12:22),FMT=*,ERR=360)SENT(CARD-200)
            IF ( SENT(CARD-200).GT.TOTAL(CARD-200) ) GO TO 364
            GO TO 10
          ELSE
C
C 301 =< CARD =< 325
C
            IF ( (CARD.GE.301).AND.(CARD.LE.325) ) THEN
C
C Find current RSD failures by age and the commitment to next
C year's I/M failures provided by RSD by age (for Option 3)
C
              READ(UNIT=CHARS(1:11),FMT=*,ERR=360)CFAIL(CARD-300)
              READ(UNIT=CHARS(12:22),FMT=*,ERR=360)RFAIL(CARD-300)
              IF ( RFAIL(CARD-300).GT.CFAIL(CARD-300) ) GO TO 366
              GO TO 10
            ELSE
C
C 401 =< CARD =< 415
C
              IF ( (CARD.GE.401).AND.(CARD.LE.415) ) THEN
C
C Find Option 3 E values for all Tech types and all cutpoints
C for HC
C
      READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EOPT3(1,CARD-400,1)
      READ(UNIT=CHARS(12:22),FMT=*,ERR=360)EOPT3(2,CARD-400,1)
      READ(UNIT=CHARS(23:33),FMT=*,ERR=360)EOPT3(3,CARD-400,1)
                GO TO 10
              ELSE
C
C 501 =< CARD =< 515
C
                IF ( (CARD.GE.501).AND.(CARD.LE.515) ) THEN
C
C Find Option 3 E values for all Tech types and all cutpoints
C for CO
C
      READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EOPT3(1,CARD-500,2)
      READ(UNIT=CHARS(12:22),FMT=*,ERR=360)EOPT3(2,CARD-500,2)
      READ(UNIT=CHARS(23:33),FMT=*,ERR=360)EOPT3(3,CARD-500,2)
                  GO TO 10
                ELSE
C
C 601 =< CARD =< 615
C
                  IF ( (CARD.GE.601).AND.(CARD.LE.615) ) THEN
C
C Find Option 3 E values for all Tech types and all cutpoints
C for NOx
C
      READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EOPT3(1,CARD-600,3)
      READ(UNIT=CHARS(12:22),FMT=*,ERR=360)EOPT3(2,CARD-600,3)
      READ(UNIT=CHARS(23:33),FMT=*,ERR=360)EOPT3(3,CARD-600,3)
                    GO TO 10
                  ELSE
C
C 621 =< CARD =< 645
C
                  IF ( (CARD.GE.621).AND.(CARD.LE.645) ) THEN
C
C Find ACTION=5 alternate clean screening fractions
C
      ICUT=CSSCEN(6)-4
      READ(UNIT=CHARS(1:10),FMT=*,ERR=360)ACSCRN(CARD-620,ICUT)
                    GO TO 10
                  ELSE
C
C 651 =< CARD =< 675
C
                  IF ( (CARD.GE.651).AND.(CARD.LE.675) ) THEN
C
C Find ACTION=5 alternate clean screening effectiveness (VEPX)
C
      ICUT=CSSCEN(6)-4
      READ(UNIT=CHARS(1:10),  FMT=*,ERR=360) VEPX(CARD-650,ICUT,1)
      READ(UNIT=CHARS(11:20), FMT=*,ERR=360) VEPX(CARD-650,ICUT,2)
      READ(UNIT=CHARS(21:30), FMT=*,ERR=360) VEPX(CARD-650,ICUT,3)
                    GO TO 10
                  ELSE
C
C 701 =< CARD =< 715
C
                    IF ( (CARD.GE.701).AND.(CARD.LE.715) ) THEN
C
C Find RSD effectivenesses for all Tech types and all cutpoints
C for HC (for Options 1 and 2)
C
      READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EXCESS(1,CARD-700,1)
      READ(UNIT=CHARS(12:22),FMT=*,ERR=360)EXCESS(2,CARD-700,1)
      READ(UNIT=CHARS(23:33),FMT=*,ERR=360)EXCESS(3,CARD-700,1)
                      GO TO 10
                    ELSE
C
C 801 =< CARD =< 815
C
                      IF ( (CARD.GE.801).AND.(CARD.LE.815) ) THEN
C
C Find RSD effectivenesses for all Tech types and all cutpoints
C for CO (for Options 1 and 2)
C
      READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EXCESS(1,CARD-800,2)
      READ(UNIT=CHARS(12:22),FMT=*,ERR=360)EXCESS(2,CARD-800,2)
      READ(UNIT=CHARS(23:33),FMT=*,ERR=360)EXCESS(3,CARD-800,2)
                        GO TO 10
                      ELSE
C
C 901 =< CARD =< 915
C
                        IF ( (CARD.GE.901).AND.(CARD.LE.915) ) THEN
C
C Find RSD effectivenesses for all Tech types and all cutpoints
C for NOx (for Options 1 and 2) CARD=901-915
C
      READ(UNIT=CHARS(1:11),FMT=*,ERR=360)EXCESS(1,CARD-900,3)
      READ(UNIT=CHARS(12:22),FMT=*,ERR=360)EXCESS(2,CARD-900,3)
      READ(UNIT=CHARS(23:33),FMT=*,ERR=360)EXCESS(3,CARD-900,3)
                          GO TO 10
                        ELSE
C
C 951 =< CARD =< 963
C
                          IF ((CARD.GE.951).AND.(CARD.LE.962)) THEN
C
C Find RSD clean screening effectiveness values by cutpoint and
C model year grouping and pollutant (ACTION=5) CARD=951-962.
C
      ICUT=1
      MYG=1
      IF ((CARD.GE.951).AND.(CARD.LE.953)) ICUT=1
      IF ((CARD.GE.954).AND.(CARD.LE.956)) ICUT=2
      IF ((CARD.GE.957).AND.(CARD.LE.959)) ICUT=3
      IF ((CARD.GE.960).AND.(CARD.LE.962)) ICUT=4
      IF(ICUT.EQ.1) MYG=CARD-950
      IF(ICUT.EQ.2) MYG=CARD-953
      IF(ICUT.EQ.3) MYG=CARD-956
      IF(ICUT.EQ.4) MYG=CARD-959
      READ(UNIT=CHARS(1:10), FMT=*,ERR=360)CLEANX(MYG,ICUT,1,1)
      READ(UNIT=CHARS(11:20),FMT=*,ERR=360)CLEANX(MYG,ICUT,2,1)
      READ(UNIT=CHARS(21:30),FMT=*,ERR=360)CLEANX(MYG,ICUT,3,1)
      NEWRSD=2
      NEWPHS=1
                          GO TO 10
                        ELSE
C
C 971 =< CARD =< 995
C
                          IF ((CARD.GE.971).AND.(CARD.LE.995)) THEN
C
C Find RSD clean screening fractions by age and cutpoint
C (ACTION=5) CARD=971-995
C
      READ(UNIT=CHARS(1:10), FMT=*,ERR=360)CSCRN(CARD-970,1)
      READ(UNIT=CHARS(11:20),FMT=*,ERR=360)CSCRN(CARD-970,2)
      READ(UNIT=CHARS(21:30),FMT=*,ERR=360)CSCRN(CARD-970,3)
      READ(UNIT=CHARS(31:40),FMT=*,ERR=360)CSCRN(CARD-970,4)
                          GO TO 10
                          END IF
                          END IF
                          END IF
                          END IF
                        END IF
C
                      END IF
C
                    END IF
C
                  END IF
C
                END IF
C
              END IF
C
            END IF
C
          END IF
C
        END IF
C
      END IF
C
 20   CONTINUE
C
C CARD number is invalid
C
      PRINT *,'CARD NUMBER ',CARD,' IS INVALID'
      GO TO 98
C
 350  PRINT *,'PROBLEM OPENING FILE ',RSDD
      GO TO 98
C
 352  PRINT *,'PROBLEM READING A RECORD FROM FILE ',RSDD
      GO TO 98
C
 354  PRINT *,'THIS OPTION IS NOT ALLOWED: ',OPTION,' IN CARD ',CARD
      GO TO 98
C
 356  PRINT *,'THIS PROGRAM TYPE NOT ALLOWED: ',ACTION,' IN CARD ',CARD
      GO TO 98
C
 362  PRINT *,'VARIABLE FROM CARD ',CARD,' IS OUT OF RANGE'
      GO TO 98
C
 364  PRINT *,'NO. OF VEHICLES SENT TO RSD > TOTAL VEH. IN MODEL YR., '
      PRINT *,'IN CARD ',CARD
      GO TO 98
C
 366  PRINT *,'RSD IM FAILURE COMMITMENT > PREVIOUS YEAR IM FAILURES, '
      PRINT *,'IN CARD ',CARD
      GO TO 98
C
 360  PRINT *,'ERROR WHEN READING VARIABLE(S) FROM CHAR STRING OF '
      PRINT *,'CARD: ',CARD,' IN FILE ',RSDD
      PRINT *,' '
C
 98   CONTINUE
      CLOSE(2)
      RETURN 1
C
 99   CONTINUE
C
      CLOSE(2)
      RETURN
      END
      SUBROUTINE CHRB(R,C)
C
C Converts real R into character*4, C; F4.2 if R .GE. 1., else F4.3
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C C       C*4 Character*4 variable
C R       R   Real number
C
C
C Notes:
C 22-Apr-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C
C Declare variables
C
      CHARACTER C*4
C
      INTEGER I, J, K, L
C
      REAL R
C
      IF (R.GE.1.) THEN
C
C If R is greater than 1, or equal to 1, convert to character*4
C suitable for reading as F4.2.
C Evaluate the integer values for the first four positions in R,
C for example, 1.234 <-> I.JKL where J, K, and L are single digit
C integers, but I might not be.
C
        I = INT(R)
C
C Check to see if I is greater than 9
C
        IF (I.GT.9) THEN
C
C Can't output a number greater than or equal to 10
C
          PRINT *, 'WARNING:  a credit was greater than or equal to ',
     & '10. and was replaced by 9.99'
          C='9.99'
          GO TO 99
        ENDIF
C
        J = INT( (R*10.  ) - INT(R     )*10 )
        K = INT( (R*100. ) - INT(R*10. )*10 )
        L = INT( (R*1000.) - INT(R*100.)*10 )
C
C Check to see if number in the thousandths place is
C between 0.0049999 and 0.0050000.
C For example, 1.235 is represented as 9.2349999..., which is a
C problem, since INT(9.235*1000.) -> 9234, but the above test will
C be used to set L to 5 if necessary and solve the problem.
C
        IF ( ( (R*100.-FLOAT(INT(R*100.))) .GT. 0.49999 ).AND.
     &       ( (R*100.-FLOAT(INT(R*100.))) .LE. 0.50000 ) ) L=5
C
C Note that the CHAR function has the following mapping:
C CHAR(48) -> '0', CHAR(49) -> '1', ... , CHAR(57) -> '9'
C
        C(1:1) = CHAR(I+48)
        C(2:2) = '.'
        C(3:3) = CHAR(J+48)
C
        IF (L.GE.5) THEN
C
C Round up
C
          IF (K.EQ.9) THEN
            C(4:4) = '0'
C
C And increment next position
C
            IF (J.EQ.9) THEN
              C(3:3) = '0'
C
C And increment next position
C
              IF (I.EQ.9) THEN
C
C Can't output a number greater than 9.99:
C
                PRINT *, 'WARNING:  a credit was greater than 9.99 ',
     & 'and was replaced by 9.99'
                C='9.99'
              ELSE
                C(1:1) = CHAR(I+48+1)
              ENDIF
C
            ELSE
              C(3:3) = CHAR(J+48+1)
            ENDIF
C
          ELSE
            C(4:4) = CHAR(K+48+1)
          ENDIF
C
        ELSE
C
C Don't round up
C
          C(4:4) = CHAR(K+48)
        ENDIF
C
      ELSE
C
C R is less than 1, so convert to character*4 suitable for reading as
C F4.3.  Evaluate the integer values for the first four positions in R,
C for example, .1234 <-> .IJKL where I, J, K, and L are single digit
C integers
C
        I = INT( (R*10.   ) - INT(R      )*10 )
        J = INT( (R*100.  ) - INT(R*10.  )*10 )
        K = INT( (R*1000. ) - INT(R*100. )*10 )
        L = INT( (R*10000.) - INT(R*1000.)*10 )
C
C Check to see if number in the ten-thousandths place is
C between 0.00049999 and 0.00050000.
C For example, 0.0565 is represented as 0.05649999..., which is a
C problem, since INT(0.0565*10000.) -> 564, but the above test will
C be used to set L to 5 if necessary and solve the problem.
C
CC        PRINT *,I,J,K,L
CC        PRINT *,INT(R),INT(R*10.),INT(R*100.),INT(R*1000.),INT(R*10000.)
CC        PRINT *,R,R*10.,R*100.,R*1000.,R*10000.
C
        IF ( ( (R*1000.-FLOAT(INT(R*1000.))) .GT. 0.49999 ).AND.
     &       ( (R*1000.-FLOAT(INT(R*1000.))) .LE. 0.50000 ) ) L=5
C
        C(1:1) = '.'
        C(2:2) = CHAR(I+48)
        C(3:3) = CHAR(J+48)
C
        IF (L.GE.5) THEN
C
C Round up
C
          IF (K.EQ.9) THEN
            C(4:4) = '0'
C
C And increment next position
C
            IF (J.EQ.9) THEN
              C(3:3) = '0'
C
C And increment next position
C
              IF (I.EQ.9) THEN
                C(1:1)='1'
                C(2:2)='.'
              ELSE
                C(2:2) = CHAR(I+48+1)
              ENDIF
C
            ELSE
              C(3:3) = CHAR(J+48+1)
            ENDIF
C
          ELSE
            C(4:4) = CHAR(K+48+1)
          ENDIF
C
        ELSE
C
C Don't round up
C
          C(4:4) = CHAR(K+48)
        ENDIF
C
      ENDIF
C
 99   CONTINUE
C
      RETURN
      END
      SUBROUTINE R5(UEX1,UEX2,UEX3,UEX4,UEX5)
C
C Subroutine R5 calculates the proper values of E (fraction of the total
C excess emissions identified by I/M from vehicles that are exempted from 
C the IM program by RSD clean screening.
C UEXCE1, UEXCE2, and UEXCE4 for option 1 or 2 (not allowed for option 3)
C
C Input: 
C by user:  none
C common blocks:  OP1, PPEFF
C data file(s): none
C subroutine arguments: none
C 
C Output:
C by screen:  none
C common blocks:  none
C data file(s):  none
C subroutine arguments:  UEXCE1, UEXCE2, UEXCE4
C
C Array subscripts:
C
C CUTS(4)         - CUTS(ITECH)
C EFF(3)          - EFF(IP)
C CLEANX(3,15,3)  - CLEANX(Model Year Group,ICUT,IP)
C UEXCE1(3)       - UEXCE1(IP)
C UEXCE2(3)       - UEXCE2(IP)
C UEXCE4(3)       - UEXCE4(IP)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C AGE     I   Age at which a veh. first becomes subject to RSD program
C CUTS    R   Array of RSD CO test cutpoints for vehicle groups 
C              pre-1975, 1975-1980, and post-1980, Clean Screen NOx Cutpoint
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C EXCESS  R   Sacramento Study data for HC, CO, and NOx fractions of IM
C              excess identified for a particular cutpoint of CO for a
C              particular Tech type:  EXCESS( Tech type, ICUT,IP) if
C              default from DATA2--otherwise, this is user provided
C              information
C ICUT    I   Index for clean screen cutpoint scenario (ICUT=1, 2, 3 or 4
C              corresponds to: 1: 0.5/200/1000 HC/CO/NOx
C                              2: 0.5/200/1500 HC/CO/NOx
C                              3: 0.5/200/2000 HC/CO/NOx
C                              4: 0.5/200/99.9 HC/CO/NOx (No NOx Cutpt)
C IP      I   Counter for pollutants (1:HC, 2:CO, 3:NOx)
C NUMBER  I   Total number of vehicles subject to the inspection program
C OPTION  I   Option--see RSDDRV
C SCAN    I   Number of times a vehicle must be scanned to be eligible
C              for targetting
C TIMES   I   Times per month the RSD sites scanned valid vehicles.
C UEXCE1  R   HC, CO, and NOx fractions of IM excess identified by RSD,
C              calculated from CLEANX using user-supplied RSD NOx test
C              cutpoints; used by TECH12 to modify pre-1975 data 
C UEXCE2  R   Like UEXCE1, but used by TECH12 to modify 1975-1980 data
C UEXCE4  R   Like UEXCE1, but used by IMDATA to modify post-1980 data
C
C
C 23-May-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 20-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 11-Feb-1998 @ EPA-djb
C
C
C Declare variables
C
      INTEGER AGE, IP, NUMBER, OPTION, SCAN, TIMES, VMT(25)
C
      REAL CUTS(4), EFF(3), EXCESS(3,15,3)
C     REAL UEXCE1(3), UEXCE2(3), UEXCE4(3), UEXCE5(3), UEXCE6(3)
      REAL CLEANX(3,4,3,2), CSCRN(25,4), VEPX(25,4,3), ACSCRN(25,4)
      INTEGER CSSCEN(6), NEWPHS, NEWRSD
      REAL UEX1(25,3), UEX2(25,3), UEX3(25,3), UEX4(25,3), UEX5(25,3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
      COMMON /PPEFF/ NEWPHS, NEWRSD, CSCRN, CLEANX, VEPX, ACSCRN, CSSCEN
C
C First evaluate pre-1975 (Tech 1) data,
C
      DO 81 IP=1,3
C
C If CSSCEN(1) = 1, fill the UEX1 array with 0. in order to
C indicate processing is to be skipped for pre-1975 (Tech 1) data
C
        DO 10 IAGE=1,25
C
        IF (CSSCEN(1).EQ.1) THEN
          UEX1(IAGE,IP)=1.0
          GO TO 10
        END IF
C
C Select appropriate benefit effect:
C
        IF(CSSCEN(6).LE.4) THEN
          UEX1(IAGE,IP)=CLEANX(1,CSSCEN(6),IP,NEWPHS)
        ELSE
          UEX1(IAGE,IP)=VEPX(IAGE,CSSCEN(6)-4,IP)
        END IF
C
 10     CONTINUE
C
 81   CONTINUE
C
C ... then evaluate Tech 2 data,
C
      DO 82 IP=1,3
C
C If CSSCEN(2) = 1, fill the UEX2 array with 0. in order to
C indicate processing is to be skipped for 1975-1980 (Tech 2) data
C
       DO 20 IAGE=1,25
C
        IF (CSSCEN(2).EQ.1) THEN
          UEX2(IAGE,IP)=1.0
          GO TO 20
        END IF
C
C Select appropriate benefit effect:
C
        IF(CSSCEN(6).LE.4) THEN
          UEX2(IAGE,IP)=CLEANX(1,CSSCEN(6),IP,NEWPHS)
        ELSE
          UEX2(IAGE,IP)=VEPX(IAGE,CSSCEN(6),IP)
        END IF
C
 20    CONTINUE
 82   CONTINUE
C
C ... and then evaluate 1981-1985 data.
C
      DO 84 IP=1,3
C
C If CSSCEN(3) = 1, fill the UEX3 array with 0. in order to
C indicate processing is to be skipped for 1981-1985 data
C
       DO 30 IAGE=1,25
C
        IF (CSSCEN(3).EQ.1) THEN
          UEX3(IAGE,IP)=1.0
          GO TO 30
        END IF
C
C Select appropriate benefit effect:
C
        IF(CSSCEN(6).LE.4) THEN
          UEX3(IAGE,IP)=CLEANX(1,CSSCEN(6),IP,NEWPHS)
        ELSE
          UEX3(IAGE,IP)=VEPX(IAGE,CSSCEN(6)-4,IP)
        END IF
C
 30    CONTINUE
C
 84   CONTINUE
C
C ... and then evaluate 1986-1989 data.
C
      DO 86 IP=1,3
C
C If CSSCEN(4) = 1, fill the UEX4 array with 0. in order to
C indicate processing is to be skipped for 1986-1989 data
C
       DO 40 IAGE=1,25
C
        IF (CSSCEN(4).EQ.1) THEN
          UEX4(IAGE,IP)=1.0
          GO TO 40
        END IF
C
C Select appropriate benefit effect:
C
        IF(CSSCEN(6).LE.4) THEN
          UEX4(IAGE,IP)=CLEANX(1,CSSCEN(6),IP,NEWPHS)
        ELSE
          UEX4(IAGE,IP)=VEPX(IAGE,CSSCEN(6)-4,IP)
        END IF
C
 40    CONTINUE
C
 86   CONTINUE
C
C ... and then evaluate 1990 and newer data.
C
      DO 88 IP=1,3
C
C If CSSCEN(5) = 1, fill the UEX5 array with 0. in order to
C indicate processing is to be skipped for 1990 and newere data
C
       DO 50 IAGE=1,25
C
        IF (CSSCEN(5).EQ.1) THEN
          UEX5(IAGE,IP)=1.0
          GO TO 50
        END IF
C
C Select appropriate benefit effect:
C
        IF(CSSCEN(6).LE.4) THEN
          UEX5(IAGE,IP)=CLEANX(1,CSSCEN(6),IP,NEWPHS)
        ELSE
          UEX5(IAGE,IP)=VEPX(IAGE,CSSCEN(6)-4,IP)
        END IF
C
 50    CONTINUE
C
 88   CONTINUE
C
      RETURN
      END
      SUBROUTINE PP5(INPPEF,OUTPPE,NVSEEA,NVSEEB)
C
C
C PP5 (Clean Screening effect on Pressure/Purge Evap Benefits)
C
C Calculates new sets of IM Pressure/Purge credits for
C IM programs using Remote Sensing Devices (RSD)
C from the existing credits.
C
C Called by INPUT
C
C Calls no subroutines
C
C Input:
C by user:  none
C common block(s):  OP1, PPEFF
C data file(s):  file whose name is passed in INPPEF 
C subroutine arguments:  INPPEF, OUTPPE, NVSEEA, NVSEEB
C
C Output:
C by screen:  none
C common block(s):  none
C data file(s):  file whose name is passed in OUTPPE
C subroutine arguments:  none
C
C Array subscripts:
C
C ACR(25)           - ACR(IAGE)
C ACSCRN(25,4)      - ACSCRN(IAGE,ICUT)
C BCR(25)           - BCR(IAGE)
C CUTS(4)           - CUTS(ITECH)
C CSCRN(25,4)       - CSCRN(IAGE,ICUT)
C EFF(3)            - EFF(IP)
C NVSEEA(25)        - NVSEEA(age of vehicle)
C NVSEEB(25)        - NVSEEB(age of vehicle)
C VMT(25)           - VMT(IBY)
C
C  Local variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C ACR     R   Annual Pressure/Purge benefits by age
C AGE     I   Age at which a veh. first becomes subject to RSD program
C BCR     R   Biennial Pressure/Purge benefits by age
C CUTS    R   Array of RSD CO cutpoints by Tech type, 1, 2, and 4+
C CSCRN   R   Array of Clean Screen fractions of vehicles in each age
C              exempted from inspection by RSD
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C IAGE    I   Counter for age
C ICUT    I   Counter for cutpoint array index (ICUT=1, 2, 3 or 4
C              corresponds to: 1: 0.5/200/1000 HC/CO/NOx
C                              2: 0.5/200/1500 HC/CO/NOx
C                              3: 0.5/200/2000 HC/CO/NOx
C                              4: 0.5/200/99.9 HC/CO/NOx (No NOx Cutpt)
C INPPEF  C   Character string name of the Pressure/Purge benefit input file
C NUMBER  I   Total number of veh. subject to inspection program
C NVSEEA  R   Fraction of vehicles seen by RSD, annual programs
C NVSEEB  R   Fraction of vehicles seen by RSD, biennial programs
C OPTION  I   Option--see RSDDRV
C OUTPPE  C   Character string name of the Presure/Purge benefit output file
C SCAN    I   Number of valid veh. measurements per month at RSD sites
C TIMES   I   Minimum number of times a vehicle must be scanned between
C              inspections to be eligible for targetting.
C VMT     I   Vehicle miles travelled by age
C
C
C 13-Feb-1998 @ EPA-djb (created)
C
      CHARACTER INPPEF*40, OUTPPE*40, JUNK*80, ADD*40
C
      INTEGER AGE, IAGE
      INTEGER NUMBER, OPTION, SCAN, TIMES
      INTEGER VMT(25)
C
      REAL ACR(25), BCR(25)
      REAL CUTS(4), EFF(3), EXCESS(3,15,3)
      REAL NVSEEA(25), NVSEEB(25)
      REAL CLEANX(3,4,3,2), CSCRN(25,4), VEPX(25,4,3), ACSCRN(25,4)
      INTEGER CSSCEN(6), NEWPHS, NEWRSD
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
      COMMON /PPEFF/ NEWPHS, NEWRSD, CSCRN, CLEANX, VEPX, ACSCRN, CSSCEN
C
      DATA ADD /' with RSD Clean Screen Effects.         '/
C
      WRITE(*,200)
 200  FORMAT(/,  ' Now altering Pressure/Purge benefit ',
     &            'array to reflect effect of clean screening. ',/,
     &           ' ---------------------------------------',
     &            '---------------------------------------')
C
C Determine user clean screening cutpoint choice:
C Always choose the user selection for the model year group that
C is least stringent (largest fraction of exempted vehicles).
C CSSCEN(6)>5 indicates alternate clean screening fractions option.
C
      ICUT=CSSCEN(6)
C
C Open filename in INPPEF for input as unit 12
C Open filename in OUTPPE for output as unit 13
C
      OPEN(12,FILE=INPPEF, ERR=300,STATUS='OLD')
      OPEN(13,FILE=OUTPPE, ERR=310)
C     OPEN( 7,FILE='AAA',  ERR=300)
C
C Read in the annual, then biennial pressure/purge benefits
C
      READ(12,101,END=97,ERR=320) JUNK
      READ(12,100,END=97,ERR=320) (ACR(IAGE),IAGE=1,25)
      READ(12,100,END=97,ERR=320) (BCR(IAGE),IAGE=1,25)
  100 FORMAT(25F5.3)
  101 FORMAT(A80)
C
C  Note:  new credit = credit * ( 1.0 -  F * E )
C Where:  credit: Reduction in the number of pressure/purge failures
C              F: Fraction of vehicles seen by RSD (NVSEE)
C              E: Fraction of vehicles seen by RSD that
C                 are exempted from inspection. (CSCRN)
C
C This assumes that evaporative pressure/purge failures are randomly
C distributed among RSD passing and failing vehicles.  This can be 
C adjusted by changing the fraction of vehicles exempted by RSD.
C
      IF(ICUT.LE.4) THEN
      DO 10 IAGE=1,25
        ACR(IAGE) = ACR(IAGE) * ( 1.0 - NVSEEA(IAGE)*CSCRN(IAGE,ICUT))
        BCR(IAGE) = BCR(IAGE) * ( 1.0 - NVSEEB(IAGE)*CSCRN(IAGE,ICUT))
C     WRITE(7,777) IAGE,ICUT,ACR(IAGE),NVSEEA(IAGE),
C    *                       BCR(IAGE),NVSEEB(IAGE),CSCRN(IAGE,ICUT)
C777  FORMAT(2I4,5F10.4)
   10 CONTINUE
      ELSE
      DO 20 IAGE=1,25
        ACR(IAGE) = ACR(IAGE) * ( 1.0 - ACSCRN(IAGE,ICUT-4) )
        BCR(IAGE) = BCR(IAGE) * ( 1.0 - ACSCRN(IAGE,ICUT-4) )
C     WRITE(7,777) IAGE,ICUT,ACR(IAGE),BCR(IAGE),ACSCRN(IAGE,ICUT-4)
   20 CONTINUE
      END IF
C
C Write processed data to the output file
C
        WRITE(13,102,ERR=350) JUNK, ADD
  102   FORMAT(A80,A40)
        WRITE(13,100,ERR=350) (ACR(IAGE),IAGE=1,25)
        WRITE(13,100,ERR=350) (BCR(IAGE),IAGE=1,25)
C
      GO TO 97
C
C ---------------------------
C CONSOLIDATED ERROR MESSAGES
C ---------------------------
C
 300  CONTINUE
      WRITE(*,301) INPPEF
 301  FORMAT(/,  ' ERROR OPENING INPUT FILE ',A40)
      GOTO 96
C
 310  CONTINUE
      WRITE(*,311) OUTPPE
 311  FORMAT(/,  ' ERROR OPENING OUTPUT FILE ',A40)
      GOTO 96
C
 320  CONTINUE
      WRITE(*,321) INPPEF
 321  FORMAT(/,  ' ERROR READING DATA FROM INPUT ',
     &            'FILE ',A40)
      GOTO 96
C
 350  CONTINUE
      WRITE(*,351) OUTPPE
 351  FORMAT(/,  ' ERROR WRITING TO OUTPUT FILE ',A40)
      GOTO 96
C
C ---------------------------------
C CLOSE DATA FILES AND EXIT PROGRAM
C ---------------------------------
C
 96   WRITE(*,'(A)')'0PP CONVERSION ENDED ABNORMALLY.'
      GOTO 98
C
 97   WRITE(*,'(A)')'0PP Conversion ended normally.'
C
 98   CONTINUE
C
      CLOSE (13)
      CLOSE (12)
C     CLOSE (7)
C
      RETURN
      END
      BLOCK DATA BD01
C
C
C Array subscripts:
C
C ACSCRN(25,4)      - ACSCRN(IAGE,ICUT)
C CLEANX(3,15,3)    - CLEANX(Model Year Group,ICUT,IP)
C CSCRN(25,4)       - CSCRN(IAGE,ICUT)
C CSSCEN(6)         - CSSCEN(ICUT)
C VEPX(25,4,3)      - VEPX(IAGE,ICUT,IP)
C
C
C  Local variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C ACSCRN  R   Array of alternate Clean Screen fractions.
C CLEANX  R   Array of Clean Screen effectiveness (i.e., Fraction of
C              benefit remaining after clean screening.)
C CSCRN   R   Array of Clean Screen fractions of vehicles in each age
C              exempted from inspection by RSD
C CSSCEN  R   Array which indicates the scenario chosen for each
C              model year grouping for clean screening.
C VEPX    R   Array of alternate Clean Screen effectiveness for
C              alternate (non-RSD) methods to exempt vehicles.
C
C
      REAL VEP1(25,4), VEP2(25,4), VEP3(25,4)
      REAL CLEAN1(3,4,3), CLEAN2(3,4,3)
      EQUIVALENCE
     * (VEPX(1,1,1),VEP1(1,1)),
     * (VEPX(1,1,2),VEP2(1,1)),
     * (VEPX(1,1,3),VEP3(1,1))
      EQUIVALENCE
     * (CLEANX(1,1,1,1),CLEAN1(1,1,1)),
     * (CLEANX(1,1,1,2),CLEAN2(1,1,1))
      REAL CLEANX(3,4,3,2), CSCRN(25,4), VEPX(25,4,3), ACSCRN(25,4)
      INTEGER CSSCEN(6), NEWPHS, NEWRSD
      COMMON /PPEFF/ NEWPHS, NEWRSD, CSCRN, CLEANX, VEPX, ACSCRN, CSSCEN
C
C
      DATA CSSCEN / 2, 2, 2, 2, 2, 8 /
C
C Fortran first fastest convention for indices:  CSCRN(1,1), (2,1),
C (3,1), (4,1), ..., (25,1), (1,2), (2,2)... , i.e., (1, 1000), (2, 1000),
C (3, 1000), (4, 1000), ..., (25, 1000),  (1, 1500), (2, 1500), ...
C
C Fraction of all vehicles exempted by inspection by clean screening by
C age and by cutpoint combination:  CSCRN(25,4)
C
      DATA CSCRN /
     * .614, .553, .492, .431, .370, .309, .248, .187, .157, .128,
     * .099, .069, .040, .025, .010, .010, .010, .010, .010, .010,
     * .010, .010, .010, .010, .010,
     * .694, .633, .572, .511, .450, .389, .328, .267, .237, .208,
     * .179, .149, .120, .105, .090, .075, .075, .075, .075, .075,
     * .075, .075, .075, .075, .075,
     * .724, .663, .602, .541, .480, .419, .358, .297, .267, .238,
     * .209, .179, .150, .135, .120, .105, .105, .105, .105, .105,
     * .105, .105, .105, .105, .105,
     * .834, .773, .712, .651, .590, .529, .468, .407, .377, .348,
     * .318, .289, .260, .245, .230, .215, .215, .215, .215, .215,
     * .215, .215, .215, .215, .215  /
C
C CLEANX is set up in the following way:
C
C Fortran first fastest convention for indices:  CLEANX(1,1,1), (2,1,1),
C (3,1,1), (1,2,1), ... , i.e., (MY82, 1000, HC), (MY86, 1000, HC),
C (MY90, 1000, HC), (MY82, 1500, HC), ...  (CLEANX(3,4,3,2)
C
C Set up clean screening excess emissions identified arrays:
C
      DATA CLEAN1 /
C
C                   Phase In IM240 Cutpoint Case     
C
C                     1982-85  1986-89  1990+
C            HC Effectiveness
     *                 0.98,    1.00,    1.00,
     *                 0.98,    1.00,    1.00,
     *                 0.98,    1.00,    0.82,
     *                 0.98,    1.00,    0.82,
C            CO Effectiveness
     *                 1.00,    1.00,    1.00,
     *                 1.00,    1.00,    1.00,
     *                 1.00,    1.00,    0.71,
     *                 1.00,    1.00,    0.71,
C            NOx Effectiveness
     *                 0.85,    0.88,    1.00,
     *                 0.85,    0.88,    0.92,
     *                 0.85,    0.85,    0.92,
     *                 0.85,    0.83,    0.69
     *       /
C
      DATA CLEAN2 /
C
C                     Final IM240 Cutpoint Case     
C
C                     1982-85  1986-89  1990+
C            HC Effectiveness
     *                 0.97,    0.95,    0.93,
     *                 0.97,    0.95,    0.90,
     *                 0.97,    0.95,    0.73,
     *                 0.96,    0.90,    0.59,
C            CO Effectiveness
     *                 1.00,    1.00,    0.95,
     *                 1.00,    1.00,    0.94,
     *                 1.00,    1.00,    0.73,
     *                 1.00,    0.91,    0.73,
C            NOx Effectiveness
     *                 0.86,    0.92,    1.00,
     *                 0.86,    0.92,    0.84,
     *                 0.86,    0.86,    0.83,
     *                 0.86,    0.78,    0.48
     *       /
C
C VEPX is set up in the following way:
C
C VEPX(IAGE,ICUT,IP) where IAGE=1,25 and ICUT=1,4 and IP=1,3
C ICUT = 1: Vehicle Emission Profile with 20% of vehicles exempted
C        2: Vehicle Emission Profile with 30% of vehicles exempted
C        3: Vehicle Emission Profile with 40% of vehicles exempted
C        4: Vehicle Emission Profile with 50% of vehicles exempted
C
C Set up alternate clean screening excess emissions identified arrays:
C
C HC Effectiveness
      DATA VEP1 /
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00 /
C
C CO Effectiveness
      DATA VEP2 /
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00 /
C
C NOx Effectiveness
      DATA VEP3 /
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00,
     * 1.00, 1.00, 1.00, 1.00, 1.00 /
C
C Fraction of vehicles exempted from inspection by alternate clean
C screening scenario by age and option:  ACSCRN(IAGE,ICUT)
C
      DATA ACSCRN /
     * .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000, .000, .000, .000, .000, .000,
     * .000, .000, .000, .000, .000  /
C
      END